/*------------------------------------------------------------------
Easy Digital Downloads Cart
-------------------------------------------------------------------*/
.current-shop-items-dropdown {
	position: absolute;
	top: 100%;
	right: -20px;
	background-color: #fff;
	z-index: 10000;
	border-top: 3px solid transparent;
	text-align: left;
	@include box-shadow( 0 2px 6px rgba(0, 0, 0, 0.1) );
	width: 350px;
	visibility: hidden;
	@include opacity( 0 );
	@include transition( all 0.25s ease-in-out );
	
	.widgettitle {
		display: none;
	}

	.edd-cart-number-of-items{
		display: none !important;
	}
}

.eddmenucart-toggle-drop_down:hover,
.show-cart .eddmenucart-toggle-drop_down {
	.current-shop-items-dropdown {
		visibility: visible;
		@include opacity( 1 );
	}
}

.owp-qv-open {
	overflow: hidden;
}

.boxed-layout .current-shop-items-dropdown {
	right: 0;
}

.edd-cart-empty{
	display: none;
}

.current-shop-items-dropdown{

	.widget_edd_cart_widget {

		padding: 10px;

		li {
			padding: 7px 10px;
			min-height: 100%;

			&.edd_total {
				border-width: 1px 0;
			    border-style: solid;
			    border-color: #e6e6e6;
			    margin: 10px 0;
			}

			&:first-child,
			&:last-child {
				min-height: 100%;
			}

			.edd-cart-item-title {
			    display: block;
				font-size: 14px;
			    font-weight: normal;
			    margin: 0;
			}

			.edd-cart-item-price {
				color: #b2b2b2;
				font-weight: normal;
			}

			.edd-cart-item-separator {
				display: none;
			}

			a.edd-remove-from-cart {
			    line-height: 30px;
			    color: #b3b3b3;
			    float: right;
				text-transform: capitalize;

				&:hover {
					color: $color-5;
					border-color: $color-5;
				}
			}
		}

		.edd_total {
			background-color: #fafafa;
			border-top-width: 0;
		    margin: 0;
			font-size: 12px;
			font-weight: normal;
			color: #797979;
			text-transform: uppercase;
			letter-spacing: 1px;
			
		    .cart-total {
		    	float: right;
			    font-size: 16px;
			    line-height: 1.3;
			    font-weight: 600;
			    letter-spacing: 1px;
		    }
	 
		    &:after {
			    content: '';
			    display: table;
			    clear: both;
			}
		}

		.edd_checkout{
			margin: 0;

			a {
				display: block;
				font-family: inherit;
				background-color: #13aff0;
				color: #fff;
				font-size: 12px;
				font-weight: 600;
				text-transform: uppercase;
				margin: 0;
				padding: 14px 20px;
				border: 0;
				cursor: pointer;
				text-align: center;
				letter-spacing: 0.1em;
				line-height: 1;
				-webkit-transition: all 0.3s ease;
				-moz-transition: all 0.3s ease;
				-ms-transition: all 0.3s ease;
				-o-transition: all 0.3s ease;
				transition: all 0.3s ease;
			}
		}

	}
}

/* Cart spacious style */
.eddmenucart-toggle-drop_down.spacious{
	.owp-mini-cart {
		padding: 20px;

		.widget_edd_cart_widget ul li{
			padding: 14px 20px;
		}

		.edd_total {
			padding:20px;
		}

		.edd_checkout a{
			padding: 14px 8px;		
		}
	}
}

.eddmenucart-details{
	margin-left: 8px;
}

/* Cart bag style */
.bag-style {
	position: relative;
    display: inline-block;
}

.eddmenucart-total {
	margin-right: 7px;

	span {
		color: $color-2;
	}
}

.eddmenucart-cart-icon {
	display: inline-block;

	.eddmenucart-container {
		position: relative;
	    display: inline-block;
	    min-width: 2em;
	    height: 2em;
	    font-size: 1em;
	    line-height: 1.7em;
	    font-weight: bold;
	    border: 2px solid $color-2;
	    color: $color-2;
	    padding: 0 3px;
	    vertical-align: middle;
	    text-align: center;
		@include transition( all .2s ease-in-out );

	    &:after {
		    content: '';
		    position: absolute;
		    bottom: 100%;
		    left: 50%;
		    width: 14px;
		    height: 8px;
		    margin-left: -7px;
		    margin-bottom: 0;
		    border: 2px solid $color-2;
		    border-top-left-radius: 100px;
		    border-top-right-radius: 100px;
		    border-bottom: 0;
			@include transition( all .2s ease-in-out );
	    }
	}
}

.simple-style.eddmenucart{
	.edd-cart-quantity.count{
		display: inline-block;
	    position: relative;
	    color: #fff;
	    font-size: 12px;
	    line-height: 1;
	    font-weight: 600;
	    padding: 3px 5px;
	    -webkit-border-radius: 2px;
	    -moz-border-radius: 2px;
	    -ms-border-radius: 2px;
	    border-radius: 2px;
	    background-color: #13aff0;

	    &:after{
			content: '';
			position: absolute;
			top: 0;
			left: -3px;
			width: 0;
			height: 0;
			margin-top: 4px;
			border-style: solid solid solid none;
			border-width: 5px 5px 5px medium;
			border-top-color: transparent !important;
			border-bottom-color: transparent !important;
			border-color: #13aff0;
	    }
	}
}

.bag-style:hover .eddmenucart-cart-icon .eddmenucart-container,
.show-cart .eddmenucart-cart-icon .eddmenucart-container {
	background-color: $color-5;
    color: $color-1;
	border-color: $color-5;

    &:after {
		border-color: $color-5;
    	height: 10px;
    }
}
/** Mobile Fixes **/
#mobile-fullscreen,
#mobile-dropdown{
	.owp-mini-cart{
		display: none;
	}
}

#mobile-dropdown{
	.edd-menu-icon{
		text-align: left;
		display: block;
	}
}

#sidr{
	.sidr-class-edd-cart-number-of-items{
		display: none;
	}

	.sidr-class-eddmenucart-container {
		position: relative;
	    display: inline-block;
	    min-width: 2em;
	    height: 2em;
	    font-size: 1em;
	    line-height: 1.7em;
	    font-weight: bold;
	    border: 2px solid $color-2;
	    color: $color-2;
	    padding: 0 3px;
	    vertical-align: middle;
	    text-align: center;
		@include transition( all .2s ease-in-out );

	    &:after {
		    content: '';
		    position: absolute;
		    bottom: 100%;
		    left: 50%;
		    width: 14px;
		    height: 8px;
		    margin-left: -7px;
		    margin-bottom: 0;
		    border: 2px solid $color-2;
		    border-top-left-radius: 100px;
		    border-top-right-radius: 100px;
		    border-bottom: 0;
			@include transition( all .2s ease-in-out );
	    }
	}
}