ul.meta {
	display: flex;
	flex-wrap: wrap;
	justify-content: flex-start;
	color: $color-18;
    font-size: 14px;
    line-height: 1.3;
    margin: 0 0 20px;
    padding: 0 0 10px;
    list-style: none;

	li {
		line-height: 1.5;
		align-self: flex-end;
		flex-wrap: nowrap;
		padding-bottom: 5px;

	    &:after {
			padding: 0 6px;
			font-weight: bold;
		}

	    &:last-child:after {
	    	display: none;
	    	padding: 0;
		}

		a {
			color: $color-18;

		    &:hover {
				color: $color-5;
			}
		}

		i {
			padding-right: 6px;
			font-size: 17px;
		}

		.owp-icon {
			margin-right: 8px;
		}

		svg.owp-icon {
			width: 18px;
			height: 18px;
		}

		.owp-sep {
			padding: 0 5px;
		}
	}
}

ul.obem-default li:after { content: '-'; }

ul.obem-modern li:after { content: '|'; }

ul.obem-stylish li:after { content: '//'; }

ul.obem-none li:after { content: ''; margin: 0 5px; }


/*------------------------------------*
	Single Post Styling
*------------------------------------*/
.single-post ul.meta {
	font-size: 14.5px;
	border-bottom: 1px solid $color-9;
	padding-bottom: 15px;

	li {

		&:after {
			padding: 0 8px;
		}

		i {
			padding-right: 9px;
		}

		.owp-icon {
			margin-right: 8px;
		}

		svg.owp-icon {
			width: 20px;
			height: 20px;
		}
	}
}

.single-post ul.ospm-default li:after { content: '-'; }

.single-post ul.ospm-modern li:after { content: '|'; }

.single-post ul.ospm-stylish li:after { content: '//'; }

.single-post ul.ospm-none li:after { content: ''; margin: 0 10px; }
