p { margin: 0 0 20px; }
img { max-width: 100%; height: auto; vertical-align: middle; }
pre { margin: 20px 0; padding: 20px; color: #2080ad; background-color: #fafafa; }
code, kbd, pre, samp { font-size: 16px; }
code, kbd, pre, samp { font-family: monospace, monospace; font-size: 1em; }
blockquote { font-style: italic; margin: 20px 40px; padding-left: 20px; border-width: 0 0 0 3px; border-style: solid; border-color: #13aff0; }