.notice-ocean-extra-plugin {
    position: relative;
    padding: 25px 20px;
    border-left-color: #00a0d2;
    font-family: 'Poppins', sans-serif;
}
.owp-ocean-extra-plugin-inner {
    display: flex;
}
.owp-ocean-extra-plugin-inner .owp-notification-icon {
    display: flex;
    align-items: center;
    justify-content: center;
    flex: 0 0 40px;
    width: 40px;
    height: 40px;
    margin-right: 20px;
}
.owp-ocean-extra-plugin-inner h2 {
    font-weight: 700;
    margin: 0 0 10px 0;
}
.owp-ocean-extra-plugin-inner .notice-subheading {
    font-size: 14px;
    font-weight: 500;
}
.owp-ocean-extra-plugin-inner p {
    padding: 0;
    margin: 0 0 1.5em 0;
    
}
.owp-ocean-extra-plugin-inner li {
    list-style: disc;
    margin-left: 40px;
}
.owp-ocean-extra-plugin-inner .notice-actions {
    display: flex;
    align-items: center;
}
.owp-ocean-extra-plugin-inner .notice-actions > * {
    display: flex;
    align-items: center;
}
.owp-ocean-extra-plugin-inner .notice-actions > *:first-child {
    margin-right: 10px;
}


