// Configuration
@import "config";

// Mixins
@import "mixins";

.editor-post-title__block .editor-post-title__input {
    font-size: 2rem;
    //font-family: $body-font-family;
    font-weight: $heading-font-weight;
}

.block-editor-block-list__layout {
    //font-family: $body-font-family;
    font-size: $font-size;
    line-height: $base-line-height;
    color: $body-font-color;
    overflow-wrap: break-word;
    word-wrap: break-word;
}

.block-editor-block-list__layout {
    h1,
    h2,
    h3,
    h4,
    h5,
    h6 {
        font-weight: $heading-font-weight;
        color: $heading-font-color;
        line-height: 1.4;
    }

    h1 {
        font-size: 23px;
    }

    h2 {
        font-size: 20px;
    }

    h3 {
        font-size: 18px;
    }

    h4 {
        font-size: 17px;
    }

    h5 {
        font-size: 15px;
    }

    h6 {
        font-size: 14px;
    }

    abbr[title],
    dfn[title] {
        cursor: help;
    }

    del {
        vertical-align: baseline;
        text-decoration: line-through;
        color: #aaa;
    }

    code,
    kbd,
    pre,
    samp {
        font-size: 16px;
    }

    pre {
        margin: 20px 0;
        padding: 20px;
        color: #2080ad;
        background-color: #fafafa;
    }

    code {
        color: #2080ad;
    }

    blockquote {
        font-style: italic;
        padding-left: 20px;
        border-left-width: 0.25em;
        border-style: solid;
        border-color: $color-5;

        cite {
            position: relative;
            display: block;
            padding: 10px 0 0 20px;
            color: #555;
            &:before {
                position: absolute;
                left: 0;
                content: "\2014";
            }
        }
    }

    q:before,
    q:after,
    blockquote:before,
    blockquote:after {
        content: "";
    }

    blockquote .wp-block-quote__citation {
        padding: 10px 0 0 20px;
    }

    blockquote .wp-block-quote__citation:before {
        position: absolute;
        left: 0;
        content: "\2014";
    }

    address {
        display: block;
    }

    ol {
        list-style-type: decimal;
    }

    ol ol {
        list-style: upper-alpha;
    }

    ol ol ol {
        list-style: lower-roman;
    }

    ol ol ol ol {
        list-style: lower-alpha;
    }

    li ul,
    li ol {
        margin: 0 0 0 25px;
    }

    dl {
        margin: 20px;
    }

    dt {
        font-weight: 700;
    }

    dd {
        margin-bottom: 20px;
    }
}

a {
    color: $link-color;
    cursor: pointer;
    text-underline-offset: 3px;
    text-decoration: underline;
    text-decoration-skip-ink: all;
    @include transition(all 0.3s ease);

    &:hover {
        color: $link-hover-color;
        text-decoration: underline;
        text-decoration-style: dotted;
        text-decoration-skip-ink: none;
        @include transition(all 0.3s ease);
    }

    &:focus:not(.wp-block-button__link):not(.wp-block-file__button) {
        /* Only visible in Windows High Contrast mode */
        outline: 2px solid transparent;
        text-decoration: underline 1px dotted $link-hover-color;
        text-decoration-skip-ink: none;
        background: rgba(255, 255, 255, 0.9);
        @include transition(all 0.3s ease);
    }
}

.editor-writing-flow {
    height: fit-content;
}

@media (min-width: 600px) {
    [data-align="full"] .wp-block-group > .wp-block {
        max-width: none;
    }
}
