/**
 * Top Bar Content
 */
#top-bar-content {
  strong {
    color: $color-2;
  }

  > a {
    color: $color-11;

    &:hover {
      color: $color-5;
    }
  }

  select {
    background-color: transparent;
    padding: 5px;
    color: rgba(0, 0, 0, 0.4);
    border-color: rgba(0, 0, 0, 0.2);
    min-width: 100px;
  }

  #lang_sel {
    position: relative;
    display: inline-block;
    top: 3px;
    margin-right: 10px;
    z-index: 99;
  }
}

#topbar-template {
  display: inline-block;
}

#top-bar-wrap #lang_sel ul ul {
  z-index: 99999;
}

.top-bar-right .polylang-switcher-shortcode {
  float: right;
  margin: 0;
  margin-left: 20px;
}

.top-bar-left .polylang-switcher-shortcode {
  float: left;
  margin: 0;
  margin-right: 20px;
}

/*------------------------------------*
  Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {

  #top-bar-content, #top-bar-social-alt {
    float: none;
    text-align: center;
  }

  #top-bar #lang_sel {
    text-align: left;
  }

  body.rtl #top-bar #lang_sel {
    text-align: right;
  }
  
}