/*
 * Slider Reverse
 */
.hamburger--slider-r .hamburger-inner {
  top: 1px;
}

.hamburger--slider-r .hamburger-inner::before {
  top: 7px;
  -webkit-transition-property: -webkit-transform, opacity;
          transition-property: transform, opacity;
  -webkit-transition-timing-function: ease;
          transition-timing-function: ease;
  -webkit-transition-duration: 0.15s;
          transition-duration: 0.15s;
}

.hamburger--slider-r .hamburger-inner::after {
  top: 14px;
}

.hamburger--slider-r.is-active .hamburger-inner {
  -webkit-transform: translate3d(0, 7px, 0) rotate(-45deg);
          transform: translate3d(0, 7px, 0) rotate(-45deg);
}

.hamburger--slider-r.is-active .hamburger-inner::before {
  -webkit-transform: rotate(45deg) translate3d(2.8571428571px, -5px, 0);
          transform: rotate(45deg) translate3d(2.8571428571px, -5px, 0);
  opacity: 0;
}

.hamburger--slider-r.is-active .hamburger-inner::after {
  -webkit-transform: translate3d(0, -14px, 0) rotate(90deg);
          transform: translate3d(0, -14px, 0) rotate(90deg);
}