/*!
 * Project   : OceanWP WordPress Theme
 * Purpose   : WooCommerce Tweaks
 * Author    : OceanWP
 */
.woocommerce .added_to_cart.disabled,
.woocommerce .added_to_cart:disabled,
.woocommerce .button.disabled,
.woocommerce .button:disabled,
.woocommerce button.disabled,
.woocommerce button:disabled,
.woocommerce input[type=button].disabled,
.woocommerce input[type=button]:disabled,
.woocommerce input[type=reset].disabled,
.woocommerce input[type=reset]:disabled,
.woocommerce input[type=submit].disabled,
.woocommerce input[type=submit]:disabled {
  opacity: 0.5 !important;
  cursor: not-allowed;
}
.woocommerce .button:focus {
  background-color: #0b7cac;
  color: #fff;
}
.woocommerce button.button {
  padding: 12px 20px;
}
.woocommerce button.button.loading {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce button.button.loading:after {
  display: inline-block;
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  content: "\f110";
  position: inherit;
  top: auto;
  right: auto;
  margin-left: 6px;
  vertical-align: top;
  font-weight: 400;
  -webkit-animation: spin 2s infinite linear;
  -moz-animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  -o-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
  color: inherit;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce button.disabled {
  background-color: #777;
}
.woocommerce button.alt:disabled {
  background-color: #777;
}
.woocommerce ul {
  list-style: none;
  margin: 0;
  padding: 0;
}
.woocommerce ul.products {
  margin: 0 -10px;
}
.woocommerce ul.products li.product .product-entry-slider {
  opacity: 0;
  visibility: hidden;
  height: 0;
}
.woocommerce ul.products li.product .product-entry-slider .oceanwp-slider-slide,
.woocommerce ul.products li.product .product-entry-slider .oceanwp-slider-slide a,
.woocommerce ul.products li.product .product-entry-slider .oceanwp-slider-slide img {
  display: block;
  position: relative;
  width: 100%;
  margin-bottom: 0;
}
.woocommerce ul.products li.product .product-entry-slider .flickity-button {
  width: 30px;
  height: 36px;
  border-radius: 0;
  background-color: rgba(0, 0, 0, 0.6);
  display: flex;
  justify-content: center;
  align-items: center;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  visibility: hidden;
  transition: opacity 0.3s ease;
}
.woocommerce ul.products li.product .product-entry-slider .flickity-button:hover {
  background-color: rgba(0, 0, 0, 0.8);
}
.woocommerce ul.products li.product .product-entry-slider .flickity-button:disabled {
  pointer-events: unset;
}
.woocommerce ul.products li.product .product-entry-slider .flickity-button svg {
  fill: #fff;
  width: 12px;
  height: auto;
  position: static;
}
.woocommerce ul.products li.product .product-entry-slider:hover .flickity-button {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
  visibility: visible;
}
.woocommerce ul.products li.product .added_to_cart {
  padding: 12px 20px;
}
.woocommerce ul.products li.product .added_to_cart:after {
  font-family: "simple-line-icons";
  font-weight: normal;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  content: "\e035";
  margin-left: 6px;
  vertical-align: bottom;
}
.woocommerce ul.products li.product .woo-entry-inner {
  margin: 0;
}
.woocommerce ul.products li.product .woo-entry-inner li {
  margin-bottom: 12px;
  line-height: 1;
}
.woocommerce ul.products li.product .woo-entry-inner li:last-child {
  margin-bottom: 0;
}
.woocommerce ul.products li.product .woo-entry-inner li.image-wrap {
  margin-bottom: 20px;
  position: relative;
}
.woocommerce ul.products li.product .woo-entry-inner li.image-wrap .woo-entry-image,
.woocommerce ul.products li.product .woo-entry-inner li.image-wrap .product-entry-slider-wrap {
  display: block;
}
.woocommerce ul.products li.product .woo-entry-image,
.woocommerce ul.products li.product .product-entry-slider-wrap {
  display: none;
}
.woocommerce ul.products li.product .product-entry-slider-wrap {
  position: relative;
}
.woocommerce ul.products li.product .product-entry-slider-wrap .owp-icon {
  margin-right: 9px;
}
.woocommerce ul.products li.product .product-entry-slider-wrap .owp-icon use {
  stroke: #fff;
}
.woocommerce ul.products li.product .woo-entry-image-swap {
  position: relative;
  overflow: hidden;
}
.woocommerce ul.products li.product .woo-entry-image-swap img {
  -webkit-transition: opacity 0.25s ease-in-out;
  -moz-transition: opacity 0.25s ease-in-out;
  -ms-transition: opacity 0.25s ease-in-out;
  -o-transition: opacity 0.25s ease-in-out;
  transition: opacity 0.25s ease-in-out;
  width: 100%;
  overflow: hidden;
}
.woocommerce ul.products li.product .woo-entry-image-swap .woo-entry-image-main {
  position: relative;
  margin-bottom: 0 !important;
  z-index: 2;
}
.woocommerce ul.products li.product .woo-entry-image-swap .woo-entry-image-secondary {
  position: absolute;
  top: 0;
  left: 0;
  overflow: hidden;
  height: 100%;
  z-index: 1;
}
.woocommerce ul.products li.product .woo-entry-image-swap:hover .woo-entry-image-main {
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
}
.woocommerce ul.products li.product .product-entry-slider {
  display: none;
}
.woocommerce ul.products li.product .product-entry-slider.slick-slider {
  display: none;
}
.woocommerce ul.products li.product .product-entry-slider .slick-arrow {
  position: absolute;
  top: 50%;
  display: block;
  visibility: hidden;
  width: 26px;
  height: 100px;
  margin: -50px 0 0;
  font-size: 22px;
  line-height: 100px;
  background-color: transparent;
  color: #333;
  padding: 0;
  text-align: center;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  cursor: pointer;
  z-index: 999;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products li.product .product-entry-slider .slick-arrow:hover {
  background-color: rgba(0, 0, 0, 0.05);
}
.woocommerce ul.products li.product .product-entry-slider .slick-arrow.slick-prev {
  left: 0;
}
.woocommerce ul.products li.product .product-entry-slider .slick-arrow.slick-next {
  right: 0;
}
.woocommerce ul.products li.product .product-entry-slider:hover .slick-arrow {
  visibility: visible;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce ul.products li.product.outofstock .outofstock-badge {
  position: absolute;
  top: 20px;
  left: 20px;
  min-height: 0;
  min-width: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: rgba(63, 195, 135, 0.8);
  color: #fff;
  padding: 8px 12px;
  text-transform: uppercase;
  font-size: 12px;
  line-height: 1;
  font-weight: 300;
  z-index: 9;
  background-color: rgba(0, 0, 0, 0.8);
}
.woocommerce ul.products li.product.outofstock .onsale {
  display: none;
}
.woocommerce ul.products li.product li.category {
  display: block;
  font-size: 12px;
  font-weight: 300;
  line-height: 1;
  font-style: italic;
  margin-bottom: 8px;
  text-overflow: ellipsis;
  white-space: normal;
}
.woocommerce ul.products li.product li.category a {
  color: #999;
}
.woocommerce ul.products li.product li.inner {
  display: block;
  position: relative;
  margin: 5px 0 18px;
  line-height: 1;
}
.woocommerce ul.products li.product li.woo-desc {
  display: none;
  line-height: 1.6;
  margin-bottom: 20px;
}
.woocommerce ul.products li.product li.btn-wrap {
  display: block;
}
.woocommerce ul.products li.product li.title h2, .woocommerce ul.products li.product li.title a {
  display: inline-block;
  font-family: inherit;
  font-size: 14px;
  line-height: 1.5;
  color: #333;
}
.woocommerce ul.products li.product li.owp-woo-cond-notice {
  display: inline-block;
  margin-bottom: 10px;
  font-family: inherit;
  font-size: 16px;
  text-transform: capitalize;
  font-weight: 600;
  line-height: 1;
  letter-spacing: 1;
}
.woocommerce ul.products li.product li.owp-woo-cond-notice span,
.woocommerce ul.products li.product li.owp-woo-cond-notice a {
  color: #333;
}
.woocommerce ul.products li.product li.owp-woo-cond-notice a:hover {
  color: #52a7fe;
}
.woocommerce ul.products li.product .price {
  font-size: 18px;
  text-align: center;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products li.product .price .amount {
  color: #57bf6d;
}
.woocommerce ul.products li.product .price del {
  display: inline-block;
  font-weight: normal;
}
.woocommerce ul.products li.product .price del .amount {
  color: #666;
  font-size: 14px;
  text-decoration: line-through;
}
.woocommerce ul.products li.product .price ins {
  display: inline-block;
  font-weight: normal;
}
.woocommerce ul.products li.product.has-rating .product-inner:hover .inner .price {
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  visibility: hidden;
}
.woocommerce ul.products li.product.has-rating .product-inner:hover .inner .star-rating {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
  visibility: visible;
}
.woocommerce ul.products li.product.has-rating li.inner .star-rating {
  position: absolute;
  top: 50%;
  left: 0;
  right: 0;
  margin: -8px auto 0 auto;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  visibility: hidden;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products li.product .button {
  float: none;
  display: inline-block;
  background-color: transparent;
  color: #848494;
  padding: 5px 12px;
  border: 3px double #e4e4e4;
  font-size: 12px;
  line-height: 1.5;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-transform: none;
}
.woocommerce ul.products li.product .button:hover {
  background-color: transparent;
  color: #13aff0;
  border-color: #13aff0;
}
.woocommerce ul.products li.product .button.added {
  display: none;
}
.woocommerce ul.products li.product h3 {
  font-size: 16px;
  color: inherit;
  margin: 0;
}
.woocommerce ul.products li.product .product-inner .added_to_cart {
  float: none;
  display: inline-block;
  background-color: transparent;
  color: #848494;
  padding: 5px 12px;
  border: 3px double #e4e4e4;
  font-size: 12px;
  line-height: 1.5;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-transform: none;
}
.woocommerce ul.products li.product .product-inner .added_to_cart:hover {
  background-color: transparent;
  color: #13aff0;
  border-color: #13aff0;
}
.woocommerce ul.products li.product li.category a:hover {
  color: #13aff0;
}
.woocommerce ul.products li.product-category.product .woo-entry-image {
  display: block;
  margin-bottom: 20px;
}
.woocommerce ul.products li.product-category.product .woo-entry-inner a {
  padding-top: 10px;
}
.woocommerce ul.products li.product-category.product .woo-entry-inner a .woocommerce-loop-category__title {
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products li.product-category.product .woo-desc {
  display: none;
  line-height: 1.6;
  margin-bottom: 20px;
}
.woocommerce ul.products.list .woostore-product-excerpt {
  display: none;
}
.woocommerce ul.products.list .woostore-category-description {
  display: none;
}
.woocommerce ul.products.list .product-inner {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
  -webkit-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-align-items: center;
  align-items: center;
  text-align: left;
}
.woocommerce ul.products.list li.product {
  display: block;
  float: none;
  width: 100% !important;
  border-bottom: 1px solid #eaeaea;
}
.woocommerce ul.products.list li.product .woo-entry-inner {
  width: 65%;
}
.woocommerce ul.products.list li.product .woo-entry-inner li.image-wrap {
  display: none;
}
.woocommerce ul.products.list li.product .woo-entry-image,
.woocommerce ul.products.list li.product .product-entry-slider-wrap {
  display: block;
  position: relative;
  width: 32%;
  margin: 0 3% 0 0;
}
.woocommerce ul.products.list li.product .product-entry-slider-wrap .woo-entry-image {
  width: 100%;
  margin: 0;
}
.woocommerce ul.products.list li.product li.woo-desc {
  display: block;
}
.woocommerce ul.products.list li.product li.title a {
  font-size: 28px;
}
.woocommerce ul.products.list li.product.has-rating li.inner .star-rating {
  left: 0;
  right: 0;
  margin-left: auto;
  margin-right: auto;
  text-align: center;
}
.woocommerce ul.products.list li.product-category.product .woo-desc {
  display: block;
}
.woocommerce ul.cart_list li::after {
  clear: both;
}
.woocommerce ul.cart_list li .star-rating {
  display: block;
  margin: 5px 0;
}
.woocommerce ul.cart_list li dl {
  display: none;
}
.woocommerce ul.product_list_widget {
  list-style: none;
  margin: 0;
  padding: 0;
}
.woocommerce ul.product_list_widget li::after {
  clear: both;
}
.woocommerce ul.product_list_widget li {
  position: relative;
  border-bottom: 1px solid;
  clear: both;
  padding: 10px 0 10px 94px;
  margin: 0;
  min-height: 100px;
  border-color: #eaeaea;
}
.woocommerce ul.product_list_widget li a:after {
  content: "";
  display: block;
  visibility: hidden;
  clear: both;
  zoom: 1;
  height: 0;
}
.woocommerce ul.product_list_widget li a.remove {
  display: inline-block;
  position: absolute;
  top: 50%;
  right: 0;
  font-size: 14px;
  margin-top: -10px;
  color: #777;
  border: 1px solid;
  height: 20px;
  width: 20px;
  line-height: 18px;
  text-align: center;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  z-index: 20;
}
.woocommerce ul.product_list_widget li a.remove:hover {
  color: #333;
}
.woocommerce ul.product_list_widget li:first-child {
  padding-top: 0;
  min-height: 90px;
  border-color: #eaeaea;
}
.woocommerce ul.product_list_widget li:first-child img {
  top: 0;
}
.woocommerce ul.product_list_widget li:last-child {
  border-bottom: 0;
  padding-bottom: 0;
  min-height: 90px;
}
.woocommerce ul.product_list_widget li.empty {
  min-height: auto !important;
  margin: 0;
  border: 0;
  padding: 0 !important;
  text-align: center;
}
.woocommerce ul.product_list_widget li img {
  position: absolute;
  top: 10px;
  left: 0;
  width: 80px;
  height: 80px;
  margin: 0;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.product_list_widget li img:hover {
  -moz-opacity: 0.8;
  -webkit-opacity: 0.8;
  opacity: 0.8;
}
.woocommerce ul.product_list_widget li .quantity {
  display: block;
  float: none;
  margin: 5px 0 0;
  color: #bcbcbc;
  line-height: 1em;
}
.woocommerce ul.product_list_widget li .star-rating {
  display: block;
  margin: 5px 0;
}
.woocommerce ul.product_list_widget li dl {
  display: none;
}
.woocommerce ul.order_details {
  border: 1px solid;
  padding: 20px;
  margin: 0 0 20px;
  border-color: #eaeaea;
  border-color: #eaeaea;
}
.woocommerce ul.order_details li {
  border-color: #ddd;
}
.woocommerce .summary ul,
.woocommerce #tab-description ul {
  list-style: disc;
  margin: 20px 0 0 20px;
}
.woocommerce .form-row-first {
  float: left;
  width: 48%;
  margin-right: 4%;
}
.woocommerce .form-row-last {
  float: right;
  width: 48%;
}
.woocommerce form .form-row {
  padding: 3px 0;
}
.woocommerce form .form-row label {
  display: inline-block;
  margin: 0 0 5px;
}
.woocommerce form .form-row label[for=createaccount] {
  margin: 0;
  vertical-align: middle;
}
.woocommerce form .form-row-wide {
  clear: both;
}
.woocommerce form .form-row::after {
  clear: both;
}
.woocommerce form.login .lost_password {
  margin: 0;
}
.woocommerce ul.products ul {
  margin: 0 -10px;
}
.woocommerce ul.products .product {
  position: relative;
  overflow: hidden;
  padding-bottom: 20px;
}
.woocommerce ul.products .product-inner {
  position: relative;
}
.woocommerce ul.products li.owp-content-left .product-inner {
  text-align: left;
}
.woocommerce ul.products li.owp-content-left.product.has-rating .woo-entry-inner .star-rating {
  margin-left: 0;
}
.woocommerce ul.products li.owp-content-center .product-inner {
  text-align: center;
}
.woocommerce ul.products li.owp-content-center.product.has-rating .woo-entry-inner .star-rating {
  margin-left: auto;
  margin-right: auto;
}
.woocommerce ul.products li.owp-content-right .product-inner {
  text-align: right;
}
.woocommerce ul.products li.owp-content-right.product.has-rating .woo-entry-inner .star-rating {
  margin-right: 0;
}
.woocommerce ul.products.archives-col-1 .product {
  clear: both;
}
.woocommerce ul.products.archives-col-2 .product:nth-child(2n+1) {
  clear: both;
}
.woocommerce ul.products.archives-col-3 .product:nth-child(3n+1) {
  clear: both;
}
.woocommerce ul.products.archives-col-4 .product:nth-child(4n+1) {
  clear: both;
}
.woocommerce ul.products.archives-col-5 .product:nth-child(5n+1) {
  clear: both;
}
.woocommerce ul.products.archives-col-6 .product:nth-child(6n+1) {
  clear: both;
}
.woocommerce ul.products.archives-col-7 .product:nth-child(7n+1) {
  clear: both;
}
.woocommerce .cart-collaterals {
  width: 100%;
}
.woocommerce .cart-collaterals .shipping_calculator::after {
  clear: both;
}
.woocommerce .cart-collaterals p {
  margin: 0 0 5px;
  color: #525252;
}
.woocommerce .cart-collaterals:after {
  content: " ";
  display: table;
  clear: both;
}
.woocommerce .cart-collaterals:before {
  content: " ";
  display: table;
}
.woocommerce .cart-collaterals .related {
  width: 30.75%;
  float: left;
}
.woocommerce .cart-collaterals .cross-sells {
  width: 48%;
  float: left;
  padding: 0 20px;
  border-width: 1px;
  border-style: solid;
  border-color: #eaeaea;
}
.woocommerce .cart-collaterals tr th {
  font-size: 16px;
  letter-spacing: 0.8px;
  text-transform: capitalize;
}
.woocommerce .cart-collaterals .shipping_calculator {
  width: 48%;
  clear: right;
  float: right;
}
.woocommerce .cart-collaterals .shipping_calculator:after {
  content: " ";
  display: table;
  clear: both;
}
.woocommerce .cart-collaterals .shipping_calculator:before {
  content: " ";
  display: table;
}
.woocommerce .cart-collaterals .shipping_calculator .col2-set .col-1 {
  width: 47%;
}
.woocommerce .cart-collaterals .shipping_calculator .col2-set .col-2 {
  width: 47%;
}
.woocommerce .cart-collaterals .cart_totals {
  float: right;
  width: 48%;
  padding: 0 20px 20px;
  border-width: 1px;
  border-style: solid;
  border-color: #eaeaea;
}
.woocommerce .cart-collaterals h2 {
  background-color: #f7f7f7;
  border-bottom: 1px solid;
  margin: 0 -20px 20px;
  padding: 0.8em 20px;
  font-size: 14px;
  text-transform: uppercase;
  letter-spacing: 1px;
  font-weight: 600;
  color: #444;
  text-align: center;
  border-color: #eaeaea;
}
.woocommerce .cart-collaterals .products .product {
  margin-bottom: 0;
}
.woocommerce del {
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
}
.woocommerce ins {
  text-decoration: none;
}
.woocommerce .category-image {
  margin: 0 0 20px;
}
.woocommerce .category-image img {
  width: 100%;
}
.woocommerce .oceanwp-toolbar {
  display: block;
  padding: 10px 0;
  border-top: 1px solid #eaeaea;
  border-bottom: 1px solid #eaeaea;
  margin-bottom: 20px;
}
.woocommerce .oceanwp-grid-list {
  float: left;
  margin: 0 20px 0 0;
}
.woocommerce .oceanwp-grid-list a {
  display: inline-block;
  width: 34px;
  height: 34px;
  line-height: 34px;
  color: #999;
  border: 1px solid #eaeaea;
  text-align: center;
}
.woocommerce .oceanwp-grid-list a:last-child {
  margin-left: 10px;
}
.woocommerce .oceanwp-grid-list a.active {
  color: #13aff0;
  border-color: #13aff0;
}
.woocommerce .oceanwp-grid-list a:hover {
  color: #13aff0;
  border-color: #13aff0;
}
.woocommerce .oceanwp-grid-list .owp-icon {
  vertical-align: inherit;
}
.woocommerce .woocommerce-ordering {
  float: left;
}
.woocommerce .woocommerce-ordering select {
  font-size: 13px;
  min-height: 34px;
  line-height: 34px;
  padding: 0 15px;
  border-color: #ddd;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  margin: 0;
  vertical-align: top;
}
.woocommerce .woocommerce-ordering .theme-select {
  font-size: 13px;
  color: #999;
}
.woocommerce .woocommerce-ordering .orderby {
  width: auto;
  min-width: 166px;
}
.woocommerce .woocommerce-ordering .orderby span {
  width: auto;
  min-width: 166px;
}
.woocommerce .result-count {
  float: right;
  font-size: 12px;
  line-height: 34px;
  text-transform: uppercase;
  list-style: none;
  margin: 0;
  padding: 0;
}
.woocommerce .result-count li {
  float: left;
}
.woocommerce .result-count li.view-title {
  margin-right: 6px;
  color: #555;
  letter-spacing: 0.6px;
}
.woocommerce .result-count li.view-title:after {
  display: none;
}
.woocommerce .result-count li:after {
  content: "/";
  color: #999;
  margin: 0 3px;
}
.woocommerce .result-count li a {
  color: #999;
}
.woocommerce .result-count li a:hover {
  color: #555;
}
.woocommerce .result-count li a.active {
  color: #555;
}
.woocommerce .result-count li:last-child:after {
  display: none;
}
.woocommerce table.shop_attributes {
  text-align: left;
  width: 100%;
  border-top: 1px solid #e4e4e4;
}
.woocommerce table.shop_attributes tr {
  padding: 0;
  margin: 0;
}
.woocommerce table.shop_attributes p {
  margin: 0;
}
.woocommerce table.shop_attributes th {
  color: #000;
  font-weight: bold;
  font-weight: 600;
  text-align: left;
  border-right: 1px solid #e4e4e4;
  border-bottom: 1px solid #e4e4e4;
  padding: 5px 15px;
  text-align: left;
  margin: 0;
}
.woocommerce table.shop_attributes td {
  border-bottom: 1px solid #e4e4e4;
  padding: 5px 15px;
  text-align: left;
  margin: 0;
}
.woocommerce table.shop_table {
  border-width: 1px;
  border-style: solid;
  margin: 0 -1px 24px 0;
  text-align: left;
  width: 100%;
  border-collapse: separate;
  border-color: #eaeaea;
}
.woocommerce table.shop_table th {
  padding: 0.8em;
  vertical-align: middle;
}
.woocommerce table.shop_table td {
  padding: 0.8em;
  vertical-align: middle;
  text-transform: capitalize;
  border-color: #eaeaea;
}
.woocommerce table.shop_table dl {
  margin: 10px 0 0;
}
.woocommerce table.shop_table dl p {
  margin: 0 0 8px;
}
.woocommerce table.shop_table thead {
  background-color: #f7f7f7;
}
.woocommerce table.shop_table thead th {
  color: #444;
  font-weight: 600;
}
.woocommerce table.shop_table .product-remove {
  text-align: center !important;
}
.woocommerce table.shop_table tfoot td {
  border-color: #eaeaea;
}
.woocommerce table.shop_table tfoot th {
  border-color: #eaeaea;
  font-size: 14.5px;
  letter-spacing: 0.8px;
}
.woocommerce table.shop_table tfoot tr.order-total td span.woocommerce-Price-amount.amount {
  font-size: 15px;
  letter-spacing: 0.5px;
}
.woocommerce table.shop_table a.remove {
  display: inline-block;
  font-size: 18px;
  width: 25px;
  height: 25px;
  line-height: 23px;
  font-weight: 400;
  color: #bbb;
  border: 1px solid;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
.woocommerce table.shop_table a.remove:hover {
  background-color: transparent;
  color: #333;
}
.woocommerce table.shop_table tbody th {
  border-color: #eaeaea;
}
.woocommerce #reviews h3 {
  margin: 10px 0;
  font-size: 20px;
  font-weight: normal;
  font-weight: 400;
}
.woocommerce #reviews #comments {
  margin-top: 0;
  padding-top: 0;
  border-top: 0;
  overflow: hidden;
}
.woocommerce #reviews #comments h2 {
  clear: none;
}
.woocommerce #reviews #comments .add_review:after {
  content: "";
  display: block;
  clear: both;
}
.woocommerce #reviews #comments ol.commentlist {
  width: 100%;
  background: none;
  list-style: none;
  padding: 0;
  margin: 0;
}
.woocommerce #reviews #comments ol.commentlist li {
  margin: 0 0 20px;
  position: relative;
  background: 0;
  border: 0;
}
.woocommerce #reviews #comments ol.commentlist li .meta {
  color: #777;
  font-size: 0.75em;
}
.woocommerce #reviews #comments ol.commentlist li .comment_container {
  position: relative;
  border-bottom: 1px solid;
  margin-bottom: 15px;
  font-size: 90%;
  min-height: 85px;
  padding-left: 90px;
  border-color: #eaeaea;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta {
  margin: 0 0 5px;
  font-size: 1em;
  line-height: 1;
  border: 0;
  padding: 0;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text .meta strong {
  font-weight: bold;
  font-weight: 600;
  color: #222;
}
.woocommerce #reviews #comments ol.commentlist li img.avatar {
  position: absolute;
  left: 0;
  top: -5px;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.woocommerce #reviews #comments .commentlist > li:before {
  content: "";
}
.woocommerce #reviews #respond {
  margin: 0;
  border: 0;
  padding: 0;
}
.woocommerce #reviews #comment {
  height: 100px;
}
.woocommerce #reviews .comment-form-rating {
  clear: both;
}
.woocommerce #reviews .star-rating {
  display: inline-block;
  vertical-align: top;
  float: right;
}
.woocommerce #reviews div[itemprop=description] {
  border: 0;
  padding: 5px 0 20px;
}
.woocommerce #reviews h2 small {
  float: right;
  color: #777;
  font-size: 15px;
  line-height: 21px;
  margin: 10px 0 0;
}
.woocommerce #reviews h2 small a {
  text-decoration: none;
  color: #777;
}
.woocommerce #reviews p.meta {
  display: inline-block;
  vertical-align: top;
}
.woocommerce .term-description {
  margin-bottom: 40px;
}
.woocommerce .term-description p:last-child {
  margin-bottom: 0;
}
.woocommerce .widget_price_filter .price_slider {
  margin-bottom: 15px;
}
.woocommerce .widget_price_filter .ui-slider {
  position: relative;
  text-align: left;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
  position: absolute;
  z-index: 2;
  outline: none;
  top: -4px;
  margin-left: -6px;
  width: 14px;
  height: 14px;
  cursor: pointer;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: #13aff0;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-range {
  position: absolute;
  top: 2px;
  bottom: 2px;
  z-index: 1;
  background-color: #13aff0;
}
.woocommerce .widget_price_filter .price_label {
  font-size: 11px;
  color: #898989;
  text-transform: uppercase;
  letter-spacing: 1px;
  font-weight: 400;
}
.woocommerce .widget_price_filter .price_slider_amount {
  text-align: left;
  height: 22px;
  line-height: 22px;
}
.woocommerce .widget_price_filter .price_slider_amount .button {
  float: right;
  height: 22px;
  line-height: 22px;
  padding: 0 12px;
}
.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
  height: 9px;
  position: relative;
  padding: 0 2px;
  border: 1px solid #d0d0d0;
  cursor: pointer;
}
.woocommerce .woocommerce-checkout #customer_details h3 {
  font-size: 14px;
  position: relative;
  margin: 0 0 20px;
  padding-bottom: 8px;
  border-bottom-width: 1px;
  border-bottom-style: solid;
  text-transform: uppercase;
  letter-spacing: 0.6px;
  border-color: #eaeaea;
}
.woocommerce .woocommerce-checkout #customer_details h3 input[type=checkbox] {
  float: right;
  margin: 0 !important;
}
.woocommerce .woocommerce-checkout #customer_details p.form-row label {
  margin: 0 0 5px;
  display: block;
}
.woocommerce .woocommerce-checkout #customer_details p.form-row label.checkbox {
  display: inline-block;
}
.woocommerce .woocommerce-checkout h3#order_review_heading {
  font-size: 14px;
  position: relative;
  margin: 0 0 20px;
  padding-bottom: 8px;
  border-bottom-width: 1px;
  border-bottom-style: solid;
  text-transform: uppercase;
  letter-spacing: 0.6px;
  border-color: #eaeaea;
}
.woocommerce .woocommerce-checkout h3#ship-to-different-address label {
  display: block;
  cursor: pointer;
  margin: 0;
}
.woocommerce .woocommerce-checkout .select2-container--default .select2-selection--single {
  height: 40px;
  padding: 6px 12px 2px 6px;
  background-color: transparent;
  border-color: #ddd;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  border-radius: 3px;
}
.woocommerce .woocommerce-checkout .select2-container--default .select2-selection--single .select2-selection__arrow {
  height: 40px;
}
.woocommerce .shop_table.order_details tfoot th {
  border-right: 1px solid;
  background-color: #f7f7f7;
  font-weight: 600;
  color: #444;
  border-color: #eaeaea;
  border-color: #eaeaea;
}
.woocommerce .shop_table.customer_details th {
  border-right: 1px solid;
  background-color: #f7f7f7;
  font-weight: 600;
  color: #444;
  border-color: #eaeaea;
  border-color: #eaeaea;
}
.woocommerce .order_details {
  border-color: #eaeaea;
}
.woocommerce a.button.loading {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce a.button.loading:after {
  display: inline-block;
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  content: "\f110";
  position: inherit;
  top: auto;
  right: auto;
  margin-left: 6px;
  vertical-align: top;
  font-weight: 400;
  -webkit-animation: spin 2s infinite linear;
  -moz-animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  -o-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
  color: inherit;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce input.button {
  padding: 12px 20px;
}
.woocommerce input.button.loading {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce input.button.loading:after {
  display: inline-block;
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  content: "\f110";
  position: inherit;
  top: auto;
  right: auto;
  margin-left: 6px;
  vertical-align: top;
  font-weight: 600;
  -webkit-animation: spin 2s infinite linear;
  -moz-animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  -o-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
  color: inherit;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce div.product {
  position: relative;
  float: none;
}
.woocommerce div.product div.images {
  position: relative;
  float: left;
  width: 52%;
  margin-bottom: 0;
}
.woocommerce div.product div.summary {
  float: right;
  width: 44%;
  margin-bottom: 36px;
}
.woocommerce div.product div.summary .price ins {
  text-decoration: none;
}
.woocommerce div.product div.summary .price del {
  font-size: 20px;
  color: #ababab;
}
.woocommerce div.product div.summary table.group_table tr td.price del {
  font-size: 13px;
}
.woocommerce div.product div.summary table.group_table tr td p.in-stock {
  margin: 0;
  line-height: 1;
}
.woocommerce div.product div.summary p.in-stock {
  margin-bottom: 20px;
  color: #77a464;
}
.woocommerce div.product div.woocommerce-product-details__short-description {
  margin-top: 20px;
}
.woocommerce div.product div.woocommerce-product-details__short-description p:last-child {
  margin: 0;
}
.woocommerce div.product .woocommerce-product-gallery {
  position: relative;
}
.woocommerce div.product .woocommerce-product-gallery .zoomImg {
  background-color: #fff;
}
.woocommerce div.product .woocommerce-product-gallery .woocommerce-product-gallery__trigger {
  position: absolute;
  top: 10px;
  right: 10px;
  display: block;
  height: 32px;
  width: 32px;
  background-color: #eeeeee;
  color: #333;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  border-radius: 3px;
  z-index: 99;
  text-align: center;
  text-indent: -999px;
  overflow: hidden;
}
.woocommerce div.product .woocommerce-product-gallery .woocommerce-product-gallery__trigger:before {
  display: inline-block;
  font-family: "Font Awesome 5 Free";
  font-size: inherit;
  font-weight: 900;
  text-rendering: auto;
  display: block;
  content: "\f002";
  line-height: 32px;
  text-indent: 0;
}
.woocommerce div.product .woocommerce-product-gallery .woocommerce-product-gallery__trigger img {
  display: none !important;
}
.woocommerce div.product .woocommerce-product-gallery img {
  margin: 0;
}
.woocommerce div.product .woocommerce-product-gallery .flex-viewport {
  margin-bottom: 20px;
}
.woocommerce div.product .woocommerce-product-gallery .flex-control-thumbs {
  margin: 0;
  padding: 0;
}
.woocommerce div.product .woocommerce-product-gallery .flex-control-thumbs:before {
  content: "";
  display: table;
}
.woocommerce div.product .woocommerce-product-gallery .flex-control-thumbs:after {
  content: "";
  display: table;
  clear: both;
}
.woocommerce div.product .woocommerce-product-gallery .flex-control-thumbs li {
  list-style: none;
  margin-bottom: 15px;
  cursor: pointer;
}
.woocommerce div.product .woocommerce-product-gallery .flex-control-thumbs li img {
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  -o-transition: all 0.2s ease;
  transition: all 0.2s ease;
}
.woocommerce div.product .woocommerce-product-gallery .flex-control-thumbs li img.flex-active {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce div.product .woocommerce-product-gallery .flex-control-thumbs li:hover img {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-2 .flex-control-thumbs li {
  width: 48%;
  float: left;
  margin-right: 4%;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-2 .flex-control-thumbs li:nth-child(2n) {
  margin-right: 0;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-2 .flex-control-thumbs li:nth-child(2n+1) {
  clear: both;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-3 .flex-control-thumbs li {
  width: 30.65%;
  float: left;
  margin-right: 4%;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-3 .flex-control-thumbs li:nth-child(3n) {
  margin-right: 0;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-3 .flex-control-thumbs li:nth-child(3n+1) {
  clear: both;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-4 .flex-control-thumbs li {
  width: 22%;
  float: left;
  margin-right: 4%;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-4 .flex-control-thumbs li:nth-child(4n) {
  margin-right: 0;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-4 .flex-control-thumbs li:nth-child(4n+1) {
  clear: both;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-5 .flex-control-thumbs li {
  width: 16.76%;
  float: left;
  margin-right: 4%;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-5 .flex-control-thumbs li:nth-child(5n) {
  margin-right: 0;
}
.woocommerce div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-5 .flex-control-thumbs li:nth-child(5n+1) {
  clear: both;
}
.woocommerce div.product .product_title {
  font-size: 24px;
  margin: 0 0 10px;
}
.woocommerce div.product .product_title + .woocommerce-product-rating {
  margin-top: 0;
}
.woocommerce div.product .woocommerce-product-rating {
  display: inline-block;
  width: 100%;
  font-size: 12px;
  margin-top: 20px;
}
.woocommerce div.product .woocommerce-product-rating .star-rating {
  float: left;
  margin-right: 10px;
  margin-top: 3px;
}
.woocommerce div.product p.price {
  font-size: 36px;
  line-height: 30px;
  font-weight: 400;
  margin: 20px 0 0;
}
.woocommerce div.product p.stock {
  margin: 0;
  font-weight: 600;
  color: #fe5252;
}
.woocommerce div.product .woocommerce-tabs {
  padding-top: 30px;
  clear: both;
}
.woocommerce div.product .woocommerce-tabs .panel {
  margin: 1.5em 0 0;
}
.woocommerce div.product .woocommerce-tabs .panel h2:first-child {
  margin: 20px 0;
  font-size: 18px;
  font-weight: 400;
}
.woocommerce div.product .woocommerce-tabs ul.tabs {
  display: block;
  position: relative;
  width: 100%;
  border-top: 1px solid;
  border-bottom: 1px solid;
  margin-bottom: 20px;
  text-align: center;
  border-color: #eaeaea;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li {
  display: inline-block;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a {
  display: inline-block;
  color: #999;
  border-top: 2px solid transparent;
  border-bottom: 2px solid transparent;
  margin-top: -1px;
  margin-bottom: -1px;
  font-weight: 600;
  text-transform: uppercase;
  font-size: 90%;
  padding: 10px;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a:hover {
  color: #13aff0;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active a {
  color: #13aff0;
  border-color: #13aff0;
}
.woocommerce div.product form.cart {
  padding: 20px 0;
  border-top: 1px solid;
  border-bottom: 1px solid;
  margin-top: 20px;
  border-color: #eaeaea;
}
.woocommerce div.product form.cart .variations {
  margin-bottom: 20px;
}
.woocommerce div.product form.cart .variations .reset_variations {
  display: block;
  float: left;
  margin-top: 10px;
  font-size: 13px;
  color: #999;
  font-weight: normal;
  border: 2px solid #eeeeee;
  padding: 3px 10px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  border-radius: 3px;
  text-decoration: none;
  visibility: hidden;
}
.woocommerce div.product form.cart .variations .reset_variations:before {
  display: inline-block;
  font-family: "simple-line-icons";
  font-weight: normal;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  content: "\e082";
  margin-right: 5px;
  color: red;
  vertical-align: top;
}
.woocommerce div.product form.cart .variations label {
  color: #333;
  font-weight: 600;
}
.woocommerce div.product form.cart .variations td.label {
  padding: 15px 0 15px;
  width: 20%;
}
.woocommerce div.product form.cart .variations td.value {
  position: relative;
  padding: 15px 0 15px;
}
.woocommerce div.product form.cart .variations tr:first-child td.label {
  padding-top: 0;
}
.woocommerce div.product form.cart .variations tr:first-child td.value {
  padding-top: 0;
}
.woocommerce div.product form.cart:after {
  content: "";
  display: block;
  visibility: hidden;
  clear: both;
  zoom: 1;
  height: 0;
}
.woocommerce div.product form.cart div.quantity {
  float: left;
  margin-right: 10px;
}
.woocommerce div.product form.cart + .product_meta {
  margin-top: -1px;
}
.woocommerce div.product .summary .added_to_cart {
  font-size: 12px;
  font-weight: 600;
  padding-bottom: 1px;
  border-bottom: 2px solid;
  margin-left: 6px;
  text-transform: uppercase;
  letter-spacing: 0.6px;
}
.woocommerce div.product .summary .added_to_cart i {
  margin-left: 3px;
}
.woocommerce div.product .swatch-control .theme-select {
  display: none !important;
}
.woocommerce div.product table.group_table {
  width: auto;
  margin-bottom: 20px;
}
.woocommerce div.product table.group_table tbody {
  display: inline-block;
  width: 100%;
  border: 1px solid #eaeaea;
}
.woocommerce div.product table.group_table tr td {
  padding: 10px;
  border-top: 1px solid #eaeaea;
  border-bottom: 0;
  vertical-align: middle;
}
.woocommerce div.product table.group_table tr:first-child td {
  border-top: 0;
}
.woocommerce #respond input#submit {
  padding: 12px 20px;
}
.woocommerce #respond input#submit.loading {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce #respond input#submit.loading:after {
  display: inline-block;
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  content: "\f110";
  position: inherit;
  top: auto;
  right: auto;
  margin-left: 6px;
  vertical-align: top;
  font-weight: 400;
  -webkit-animation: spin 2s infinite linear;
  -moz-animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  -o-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
  color: inherit;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce nav.woocommerce-pagination ul {
  border: none;
  text-align: right;
}
.woocommerce.content-full-width div.product div.images {
  width: 42%;
}
.woocommerce.content-full-width div.product div.summary {
  width: 54%;
}
.woocommerce.woo-left-tabs div.product .woocommerce-tabs ul.tabs {
  text-align: left;
}
.woocommerce.woo-right-tabs div.product .woocommerce-tabs ul.tabs {
  text-align: right;
}
.woocommerce .related.products {
  margin-top: 70px;
}
.woocommerce .related.products h2 {
  margin: 0 0 15px;
}
.woocommerce .related.products .product {
  padding-bottom: 0;
}
.woocommerce .upsells.products {
  margin-top: 70px;
}
.woocommerce .upsells.products h2 {
  margin: 0 0 15px;
}
.woocommerce .upsells.products .product {
  padding-bottom: 0;
}
.woocommerce td.product-name dl.variation dt {
  font-weight: 600;
  color: #444;
  padding-bottom: 0;
}
.woocommerce td.product-name dl.variation dd {
  margin-bottom: 0;
  padding-bottom: 0;
}
.woocommerce #order_review table.shop_table {
  margin: 0 0 40px;
  border: none;
}
.woocommerce #order_review table.shop_table th {
  border: none;
  padding: 16px 20px;
}
.woocommerce #order_review table.shop_table td {
  border: none;
  padding: 16px 20px;
  text-align: right;
}
.woocommerce #order_review table.shop_table tfoot td {
  font-weight: 600;
  color: #444;
  font-weight: normal;
}
.woocommerce #order_review table.shop_table tfoot th {
  font-weight: 600;
  color: #444;
}
.woocommerce #order_review table.shop_table thead th {
  font-size: 15px;
  letter-spacing: 1px;
  padding: 20px;
}
.woocommerce #order_review table.shop_table thead th.product-total {
  text-align: right;
}
.woocommerce #order_review table.shop_table tbody td {
  background-color: #fdfdfd;
}
.woocommerce #order_review table.shop_table tbody td.product-name {
  max-width: 376px;
  text-align: left;
}
.woocommerce #order_review table.shop_table label {
  display: contents;
}
.woocommerce #order_review table tfoot th {
  text-transform: capitalize;
}
.woocommerce .col-1.address {
  padding: 20px;
  border-width: 2px;
  border-style: solid;
  border-color: #eaeaea;
}
.woocommerce .col-1.address h3 {
  font-size: 14px;
  position: relative;
  margin: 0 0 20px;
  padding-bottom: 8px;
  text-transform: uppercase;
  border-bottom: 1px solid #ddd;
}
.woocommerce .col-1.address address {
  margin: 0;
}
.woocommerce .col-2.address {
  padding: 20px;
  border-width: 2px;
  border-style: solid;
  border-color: #eaeaea;
}
.woocommerce .col-2.address h3 {
  font-size: 14px;
  position: relative;
  margin: 0 0 20px;
  padding-bottom: 8px;
  text-transform: uppercase;
  border-bottom: 1px solid #ddd;
}
.woocommerce .col-2.address address {
  margin: 0;
}

.woocommerce .owp-account-links {
  margin-bottom: 35px;
  text-align: center;
}
.woocommerce .owp-account-links li {
  display: inline-block;
}
.woocommerce .owp-account-links li .owp-account-link {
  font-size: 50px;
  color: #333;
  line-height: 1;
  font-weight: bold;
  -moz-opacity: 0.6;
  -webkit-opacity: 0.6;
  opacity: 0.6;
}
.woocommerce .owp-account-links li .owp-account-link.current, .woocommerce .owp-account-links li .owp-account-link:hover {
  opacity: 1;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce .owp-account-links li.or {
  display: inline-block;
  width: 36px;
  height: 36px;
  line-height: 32px;
  color: #333;
  border: 2px solid;
  font-size: 14px;
  font-weight: 600;
  text-transform: uppercase;
  margin: 0 16px;
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  vertical-align: text-bottom;
}

.woocommerce #customer_login > div {
  padding: 20px;
  border-width: 2px;
  border-style: solid;
  border-color: #eaeaea;
}
.woocommerce #customer_login label {
  cursor: pointer;
}

.account-original-style .woocommerce #customer_login h2 {
  display: none;
}
.account-original-style .woocommerce #customer_login > div {
  float: none;
  width: 560px;
  max-width: 100%;
  margin: 0 auto;
}
.account-original-style .woocommerce #customer_login .col-2 {
  display: none;
}
.account-original-style .woocommerce #customer_login .col-2 button {
  width: 100%;
  padding-top: 16px;
  padding-bottom: 16px;
}
.account-original-style .woocommerce #customer_login .col-1 p:nth-last-child(2) {
  margin: 0;
}
.account-original-style .woocommerce #customer_login .col-1 p:last-child {
  margin: 0;
}
.account-original-style .woocommerce #customer_login .col-1 .form-row {
  display: inline-block;
}
.account-original-style .woocommerce #customer_login .col-1 .form-row.form-row-wide {
  width: 100%;
}
.account-original-style .woocommerce #customer_login .form-row label.woocommerce-form__label {
  margin: 0 0 0 15px;
}
.account-original-style .woocommerce #customer_login .lost_password {
  float: right;
  line-height: 42px;
}
.account-original-style .woocommerce #customer_login form.register p:last-child {
  margin: 0;
}
.account-original-style .woocommerce #customer_login .woocommerce-privacy-policy-text {
  margin-bottom: 15px;
}

.account-side-style .woocommerce #customer_login h2 {
  font-size: 14px;
  position: relative;
  margin: 0 0 20px;
  padding-bottom: 8px;
  text-transform: uppercase;
  border-bottom: 1px solid #ddd;
}
.account-side-style .woocommerce #customer_login > div {
  float: left;
  width: 48%;
}
.account-side-style .woocommerce #customer_login .col-2 {
  display: block;
  float: right;
}
.account-side-style .woocommerce #customer_login .woocommerce-form__label .woocommerce-form__input {
  margin: -3px 6px 0 15px !important;
}

.woocommerce .oceanwp-loginform-wrap h2 {
  display: none;
}
.woocommerce .oceanwp-loginform-wrap form {
  width: 560px;
  max-width: 100%;
  margin: 0 auto;
  padding: 20px;
  border-width: 2px;
  border-style: solid;
  border-color: #eaeaea;
}
.woocommerce .oceanwp-loginform-wrap p:nth-last-child(2) {
  margin: 0;
}
.woocommerce .oceanwp-loginform-wrap p:last-child {
  margin: 0;
}
.woocommerce .oceanwp-loginform-wrap .form-row {
  display: block;
}
.woocommerce .oceanwp-loginform-wrap .form-row.form-row-wide {
  width: 100%;
}
.woocommerce .oceanwp-loginform-wrap .form-row label.woocommerce-form__label {
  display: block;
  float: left;
  clear: both;
  width: 100%;
  padding-bottom: 15px;
}
.woocommerce .oceanwp-loginform-wrap .form-row button.woocommerce-button.button.woocommerce-form-login__submit {
  width: 70%;
  display: block;
  margin: auto;
  padding-top: 15px;
}
.woocommerce .oceanwp-loginform-wrap .lost_password {
  line-height: 42px;
  padding-top: 15px;
  text-align: center;
}
.woocommerce .oceanwp-loginform-wrap input:focus {
  outline: -webkit-focus-ring-color 1px solid;
}

.woocommerce .lost_reset_password {
  width: 480px;
  max-width: 100%;
  margin: 0 auto;
}
.woocommerce .lost_reset_password .form-row-first,
.woocommerce .lost_reset_password .form-row-last {
  width: 100%;
  margin-right: 0;
  margin-left: 0;
}
.woocommerce .lost_reset_password button {
  width: 100%;
  padding-top: 16px;
  padding-bottom: 16px;
}

.wcmenucart i {
  position: relative;
  padding: 0;
}
.wcmenucart:after {
  display: none;
}

.wcmenucart-details {
  margin-left: 8px !important;
}
.wcmenucart-details.count {
  display: inline-block;
  position: relative;
  color: #fff;
  font-size: 12px;
  line-height: 1;
  font-weight: 600;
  padding: 3px 5px;
  margin-left: 8px;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -ms-border-radius: 2px;
  border-radius: 2px;
  background-color: #13aff0;
}
.wcmenucart-details.count:before {
  content: "";
  position: absolute;
  top: 0;
  left: -3px;
  width: 0;
  height: 0;
  margin-top: 4px;
  border-style: solid solid solid none;
  border-width: 5px 5px 5px medium;
  border-top-color: transparent !important;
  border-bottom-color: transparent !important;
  border-color: #13aff0;
}

#site-navigation-wrap .dropdown-menu > li > a.wcmenucart-hide,
#mobile-fullscreen ul li a.wcmenucart-hide,
.wcmenucart-hide {
  display: none;
}

.col2-set {
  width: 100%;
  width: 100%;
}
.col2-set:after {
  content: "";
  display: block;
  height: 0;
  clear: both;
  visibility: hidden;
  zoom: 1;
}
.col2-set .col-1 {
  float: left;
  width: 48%;
}
.col2-set .col-2 {
  float: right;
  width: 48%;
}

@media only screen and (min-width: 481px) and (max-width: 768px) {
  .tablet-col .col.first {
    clear: none;
  }
  .woocommerce .products.oceanwp-row.tablet-col .col {
    clear: none;
  }
  .woocommerce .products.oceanwp-row.tablet-1-col .product {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.tablet-2-col .product:nth-child(2n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.tablet-3-col .product:nth-child(3n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.tablet-4-col .product:nth-child(4n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.tablet-5-col .product:nth-child(5n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.tablet-6-col .product:nth-child(6n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.tablet-7-col .product:nth-child(7n+1) {
    clear: both;
  }
  .woocommerce .products.tablet-1-col .product {
    width: 100% !important;
  }
  .woocommerce .products.tablet-2-col .product {
    width: 50% !important;
  }
  .woocommerce .products.tablet-3-col .product {
    width: 33.33% !important;
  }
  .woocommerce .products.tablet-4-col .product {
    width: 25% !important;
  }
  .woocommerce .products.tablet-5-col .product {
    width: 20% !important;
  }
  .woocommerce .products.tablet-6-col .product {
    width: 16.66% !important;
  }
  .woocommerce .products.tablet-7-col .product {
    width: 14.28% !important;
  }
}
@media only screen and (max-width: 480px) {
  .mobile-col .col.first {
    clear: none;
  }
  .woocommerce .products.oceanwp-row.mobile-col .col {
    clear: none;
  }
  .woocommerce .products.oceanwp-row.mobile-1-col .product {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.mobile-2-col .product:nth-child(2n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.mobile-3-col .product:nth-child(3n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.mobile-4-col .product:nth-child(4n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.mobile-5-col .product:nth-child(5n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.mobile-6-col .product:nth-child(6n+1) {
    clear: both;
  }
  .woocommerce .products.oceanwp-row.mobile-7-col .product:nth-child(7n+1) {
    clear: both;
  }
  .woocommerce .products.mobile-1-col .product {
    width: 100% !important;
  }
  .woocommerce .products.mobile-2-col .product {
    width: 50% !important;
  }
  .woocommerce .products.mobile-3-col .product {
    width: 33.33% !important;
  }
  .woocommerce .products.mobile-4-col .product {
    width: 25% !important;
  }
  .woocommerce .products.mobile-5-col .product {
    width: 20% !important;
  }
  .woocommerce .products.mobile-6-col .product {
    width: 16.66% !important;
  }
  .woocommerce .products.mobile-7-col .product {
    width: 14.28% !important;
  }
}
.clear {
  clear: both;
}

.nobr {
  white-space: nowrap;
}

.woocommerce-page .cart-collaterals {
  width: 100%;
}
.woocommerce-page .cart-collaterals .shipping_calculator::after {
  clear: both;
}
.woocommerce-page .cart-collaterals:after {
  content: " ";
  display: table;
  clear: both;
}
.woocommerce-page .cart-collaterals:before {
  content: " ";
  display: table;
}
.woocommerce-page .cart-collaterals .related {
  width: 30.75%;
  float: left;
}
.woocommerce-page .cart-collaterals .cross-sells {
  width: 48%;
  float: left;
  padding: 0 20px;
  border-width: 1px;
  border-style: solid;
  border-color: #eaeaea;
}
.woocommerce-page .cart-collaterals .shipping_calculator {
  width: 48%;
  clear: right;
  float: right;
}
.woocommerce-page .cart-collaterals .shipping_calculator:after {
  content: " ";
  display: table;
  clear: both;
}
.woocommerce-page .cart-collaterals .shipping_calculator:before {
  content: " ";
  display: table;
}
.woocommerce-page .cart-collaterals .shipping_calculator .col2-set .col-1 {
  width: 47%;
}
.woocommerce-page .cart-collaterals .shipping_calculator .col2-set .col-2 {
  width: 47%;
}
.woocommerce-page .cart-collaterals .cart_totals {
  float: right;
  width: 48%;
  padding: 0 20px 20px;
  border-width: 1px;
  border-style: solid;
  border-color: #eaeaea;
}
.woocommerce-page form .form-row-wide {
  clear: both;
}
.woocommerce-page form .form-row::after {
  clear: both;
}
.woocommerce-page ul.cart_list li::after {
  clear: both;
}
.woocommerce-page ul.product_list_widget li::after {
  clear: both;
}

.price {
  color: #57bf6d;
}
.price del {
  color: #555;
}

.amount {
  color: #57bf6d;
}

.select2-drop-active {
  border-color: #bbb;
}

.select2-container-active .select2-choice {
  border-color: #bbb;
}
.select2-container-active .select2-choices {
  border-color: #bbb;
}

.select2-container--open {
  z-index: 99999;
}

@-webkit-keyframes spin {
  25% {
    -webkit-transform: rotate(270deg);
  }
  50% {
    -webkit-transform: rotate(90deg);
  }
  75% {
    -webkit-transform: rotate(360deg);
  }
  100% {
    -webkit-transform: rotate(180deg);
  }
}
@-moz-keyframes spin {
  25% {
    -moz-transform: rotate(270deg);
  }
  50% {
    -moz-transform: rotate(90deg);
  }
  75% {
    -moz-transform: rotate(360deg);
  }
  100% {
    -moz-transform: rotate(180deg);
  }
}
@-ms-keyframes spin {
  25% {
    -ms-transform: rotate(270deg);
  }
  50% {
    -ms-transform: rotate(90deg);
  }
  75% {
    -ms-transform: rotate(360deg);
  }
  100% {
    -ms-transform: rotate(180deg);
  }
}
@-o-keyframes spin {
  25% {
    -o-transform: rotate(270deg);
  }
  50% {
    -o-transform: rotate(90deg);
  }
  75% {
    -o-transform: rotate(360deg);
  }
  100% {
    -o-transform: rotate(180deg);
  }
}
@keyframes spin {
  25% {
    transform: rotate(270deg);
  }
  50% {
    transform: rotate(90deg);
  }
  75% {
    transform: rotate(360deg);
  }
  100% {
    transform: rotate(180deg);
  }
}
.woocommerce-message {
  display: inline-block;
  width: 100%;
  font-size: 14px;
  font-weight: 400;
  color: #777;
  border: 1px solid #ddd;
  margin: 0 0 30px;
  padding: 10px 15px;
  text-align: left;
}
.woocommerce-message a {
  float: right;
  min-height: 10%;
  padding: 6px 18px;
  font-size: 12px;
  font-weight: 600;
  line-height: 1;
  color: #fff;
  letter-spacing: 1px;
  text-transform: uppercase;
  background-color: #13aff0;
}
.woocommerce-message a:hover {
  background-color: #0b7cac;
  color: #fff;
}
.woocommerce-message a:focus {
  background-color: #0b7cac;
  color: #fff;
}
.woocommerce-message:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  margin-right: 10px;
  content: "\f00c";
  color: #ddd;
}

.woocommerce-error {
  display: inline-block;
  width: 100%;
  font-size: 12px;
  font-weight: 400;
  color: #777;
  border: 1px solid #ddd;
  margin: 0 0 30px;
  padding: 10px 15px;
  text-align: left;
  text-transform: uppercase;
  border-color: #fdc1b1;
}
.woocommerce-error a {
  float: right;
  min-height: 10%;
  padding: 6px 18px;
  font-size: 12px;
  font-weight: 600;
  line-height: 1;
  color: #fff;
  letter-spacing: 1px;
  text-transform: uppercase;
  background-color: #13aff0;
}
.woocommerce-error a:hover {
  background-color: #0b7cac;
  color: #fff;
}
.woocommerce-error:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  margin-right: 10px;
  content: "\f00d";
  color: #ffc4b7;
}

.woocommerce-info {
  display: inline-block;
  width: 100%;
  font-size: 12px;
  font-weight: 400;
  color: #777;
  border: 1px solid #ddd;
  margin: 0 0 30px;
  padding: 10px 15px;
  text-align: left;
  text-transform: uppercase;
  border-color: #b1befd;
}
.woocommerce-info a {
  float: right;
  min-height: 10%;
  padding: 6px 18px;
  font-size: 12px;
  font-weight: 600;
  line-height: 1;
  color: #fff;
  letter-spacing: 1px;
  text-transform: uppercase;
  background-color: #13aff0;
}
.woocommerce-info a:hover {
  background-color: #0b7cac;
  color: #fff;
}
.woocommerce-info:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  margin-right: 10px;
  content: "\f129";
  color: #b1befd;
}

ul.woocommerce-error {
  background-color: #e2401c;
  color: #fff;
  border: none;
  border-left: 10px solid rgba(0, 0, 0, 0.15);
  font-size: 14px;
  padding: 15px 20px;
  margin-bottom: 25px;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -ms-border-radius: 2px;
  border-radius: 2px;
  text-transform: none;
}
ul.woocommerce-error:before {
  display: none;
}
ul.woocommerce-error li:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  margin-right: 10px;
  content: "\f00d";
  color: #ffc4b7;
}
ul.woocommerce-message:before {
  display: none;
}
ul.woocommerce-message li:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  margin-right: 10px;
  content: "\f00c";
  color: #ddd;
}
ul.woocommerce-info:before {
  display: none;
}
ul.woocommerce-info li:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  margin-right: 10px;
  content: "\f129";
  color: #b1befd;
}
ul.order_details {
  position: relative;
  margin: 3.631em 0;
}
ul.order_details:before {
  content: "";
  display: block;
  position: absolute;
  top: -16px;
  left: 0;
  width: 100%;
  height: 16px;
  background-size: 0 100%, 16px 16px, 16px 16px;
}
ul.order_details:after {
  content: "";
  display: block;
  position: absolute;
  top: -16px;
  left: 0;
  width: 100%;
  height: 16px;
  background-size: 0 100%, 16px 16px, 16px 16px;
  top: auto;
  bottom: -16px;
  -webkit-transform: rotate(180deg);
  -moz-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  -o-transform: rotate(180deg);
  transform: rotate(180deg);
}
ul.order_details li {
  padding: 1em 1.618em;
  font-size: 0.8em;
  text-transform: uppercase;
}
ul.order_details li:first-child {
  padding-top: 1.618em;
}
ul.order_details li:last-child {
  border: 0;
  padding-bottom: 1.618em;
}
ul.order_details li strong {
  display: block;
  font-size: 1.387em;
  text-transform: none;
}

.woocommerce-checkout .woocommerce-info {
  padding: 10px 0;
  text-align: center;
  border-width: 1px 0;
  border-color: #eaeaea;
}
.woocommerce-checkout .woocommerce-info:before {
  color: #ddd;
}
.woocommerce-checkout .woocommerce-info a {
  font-size: 12px;
  float: none;
  padding: 0;
  letter-spacing: 0;
  background-color: transparent;
  color: #13aff0;
}
.woocommerce-checkout .woocommerce-info a:hover {
  color: #333;
  background-color: transparent !important;
}
.woocommerce-checkout form.login {
  max-width: 600px;
  margin: 0 auto 30px auto;
  padding: 20px;
  border: 1px solid;
  border-color: #eaeaea;
}
.woocommerce-checkout form.login .lost_password {
  line-height: 46px;
  float: right;
  margin: 0;
}
.woocommerce-checkout form.login p.form-row {
  display: inline-block;
  margin: 0;
}
.woocommerce-checkout form.login p.form-row.form-row-first,
.woocommerce-checkout form.login p.form-row.form-row-last {
  margin: 0 0 20px;
}
.woocommerce-checkout form.login label.inline {
  padding-left: 10px;
}
.woocommerce-checkout form.login .wc-social-login {
  display: block !important;
  margin-top: 20px;
}
.woocommerce-checkout form.checkout_coupon {
  display: block;
  border: 3px dashed rgba(84, 84, 84, 0.15);
  padding: 28px;
  width: 695px;
  margin: 0 auto 30px;
  text-align: center;
}
.woocommerce-checkout form.checkout_coupon p {
  margin: 0;
}
.woocommerce-checkout form.checkout_coupon p:last-child {
  margin: 0;
}
.woocommerce-checkout form.checkout_coupon .form-row-first {
  float: left;
  width: 74%;
}
.woocommerce-checkout form.checkout_coupon .form-row-last {
  float: right;
  width: 25%;
}
.woocommerce-checkout form.checkout_coupon input {
  line-height: 36px;
  width: 100%;
  height: 36px;
  min-height: 36px;
  padding: 0 15px;
  padding-top: 0;
  padding-bottom: 0;
  margin: 0;
}
.woocommerce-checkout form.checkout {
  display: inline-block;
  width: 100%;
  margin-top: 30px;
}
.woocommerce-checkout h3#order_review_heading,
.woocommerce-checkout #order_review {
  float: right;
  width: 48%;
}
.woocommerce-checkout .e-checkout__order_review h3#order_review_heading,
.woocommerce-checkout .e-checkout__order_review #order_review {
  float: none;
  width: 100%;
}
.woocommerce-checkout .woocommerce-account-fields {
  display: inline-block;
  width: 100%;
}
.woocommerce-checkout .woocommerce-account-fields input {
  margin-bottom: 0;
}
.woocommerce-checkout #payment ul.payment_methods {
  padding-bottom: 20px;
}
.woocommerce-checkout #payment ul.payment_methods .wc_payment_method > label {
  display: block;
  font-size: 16px;
  font-weight: 600;
  padding: 20px;
  cursor: pointer;
  margin: 0;
  letter-spacing: 0.4px;
}
.woocommerce-checkout #payment ul.payment_methods .wc_payment_method > label:before {
  font-family: "Font Awesome 5 Free";
  text-rendering: auto;
  display: inline-block;
  font-size: inherit;
  content: "\f111";
  color: #333;
  font-weight: 400;
  margin-right: 10px;
  -webkit-transition: color 0.2s ease;
  -moz-transition: color 0.2s ease;
  -ms-transition: color 0.2s ease;
  -o-transition: color 0.2s ease;
  transition: color 0.2s ease;
}
.woocommerce-checkout #payment ul.payment_methods .wc_payment_method > input[type=radio]:first-child {
  position: absolute !important;
  clip: rect(1px 1px 1px 1px);
  clip: rect(1px, 1px, 1px, 1px);
}
.woocommerce-checkout #payment ul.payment_methods .wc_payment_method > input[type=radio]:first-child:checked + label:before {
  content: "\f192";
  color: #13aff0;
}
.woocommerce-checkout #payment ul.payment_methods li {
  background-color: #fafafa;
  text-align: left;
  margin-bottom: 1px;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce-checkout #payment ul.payment_methods li:hover {
  background-color: #f5f5f5;
}
.woocommerce-checkout #payment ul.payment_methods li img {
  float: right;
  border: 0;
  padding: 0;
  max-height: 28px;
}
.woocommerce-checkout #payment ul.payment_methods .woocommerce_error li {
  background-color: transparent;
  color: #fff;
}
.woocommerce-checkout #payment div.payment_box {
  position: relative;
  width: 100%;
  padding: 1.4em;
  font-size: 0.92em;
  line-height: 1.5;
  background-color: #fff;
  color: #555;
}
.woocommerce-checkout #payment div.payment_box p {
  margin: 0;
}
.woocommerce-checkout #payment .payment_method_paypal .about_paypal {
  color: #13aff0;
  font-size: 16px;
  margin-left: 6px;
}
.woocommerce-checkout #place_order {
  width: 100%;
  font-size: 15px;
  line-height: 1.6;
  padding: 16px 20px;
}
.woocommerce-checkout .woocommerce form.login {
  margin-top: 0;
  margin-bottom: 30px;
}
.woocommerce-checkout .woocommerce form.register {
  margin-top: 0;
  margin-bottom: 30px;
}
.woocommerce-checkout > .col2-set {
  float: left;
  width: 48%;
}
.woocommerce-checkout > .col2-set > .col-1 {
  float: none;
  width: 100%;
  margin-bottom: 30px;
}
.woocommerce-checkout > .col2-set > .col-1:after {
  content: "";
  display: block;
  visibility: hidden;
  clear: both;
  zoom: 1;
  height: 0;
}
.woocommerce-checkout > .col2-set > .col-2 {
  float: none;
  width: 100%;
}
.woocommerce-checkout > .col2-set > .col-2:after {
  content: "";
  display: block;
  visibility: hidden;
  clear: both;
  zoom: 1;
  height: 0;
}
.woocommerce-checkout .place-order .terms {
  margin: 0 0 8px;
}
.woocommerce-checkout .form-row.place-order {
  margin: 0;
}

.woocommerce-cart .wc-proceed-to-checkout {
  padding-bottom: 0;
}
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button {
  display: block;
  margin-bottom: 0;
  text-align: center;
}
.woocommerce-cart .woocommerce ul.products li.product .button.added {
  display: inline-block;
}
.woocommerce-cart table.cart img {
  width: auto;
  max-width: 60px;
}
.woocommerce-cart table.cart td.actions {
  border-bottom: 0;
}
.woocommerce-cart table.cart td.actions input {
  padding-top: 0;
  padding-bottom: 0;
  height: 32px;
  line-height: 32px;
  padding: 0 1.5em;
}
.woocommerce-cart table.cart td.actions .coupon {
  float: left;
}
.woocommerce-cart table.cart td.actions .coupon .input-text {
  display: inline-block;
  float: none;
  width: auto;
  min-height: 32px;
  line-height: 32px;
  padding: 0 0.8em;
  margin: 0 8px 0 0;
  border-color: #ddd;
}
.woocommerce-cart table.cart td.actions .coupon .input-text:focus {
  border-color: #bbb;
}
.woocommerce-cart table.cart td.actions .coupon label {
  display: none;
}
.woocommerce-cart table.cart td.actions button[name=update_cart] {
  float: right;
}
.woocommerce-cart .cart-collaterals .cart_totals table {
  width: 100%;
  margin-bottom: 20px;
  border: 0;
}
.woocommerce-cart .cart-collaterals .cart_totals table td {
  padding: 0.8em;
  vertical-align: top;
  line-height: 1.5em;
}
.woocommerce-cart .cart-collaterals .cart_totals table th {
  padding: 0.8em;
  vertical-align: top;
  line-height: 1.5em;
  border-right-style: solid;
  border-right-width: 1px;
  width: 40%;
  font-weight: 600;
  color: #444;
  text-transform: none;
}
.woocommerce-cart .cart-collaterals .cart_totals table select {
  width: 100%;
  min-height: 34px;
}
.woocommerce-cart .cart-collaterals .cart_totals table tr:first-child td {
  padding-top: 0;
}
.woocommerce-cart .cart-collaterals .cart_totals table tr:first-child th {
  padding-top: 0;
}
.woocommerce-cart .cart-collaterals .cart_totals table .theme-select .theme-selectInner {
  width: 100% !important;
}
.woocommerce-cart .cart-collaterals .cart_totals .order-total th {
  border-bottom: 1px solid;
  border-color: #eaeaea;
}
.woocommerce-cart .cart-collaterals .cart_totals .order-total td {
  border-bottom: 1px solid;
  border-color: #eaeaea;
}
.woocommerce-cart .cart-collaterals .cart_totals .order-total td span.woocommerce-Price-amount.amount {
  font-size: 15px;
  vertical-align: middle;
  padding-top: 0.8em;
  letter-spacing: 0.5px;
}
.woocommerce-cart .cart-collaterals .cart_totals .shipping-calculator-button {
  display: inline-block;
  font-size: 12px;
  line-height: 1.5;
  font-weight: 900;
  padding-bottom: 3px;
  border-bottom: 1px solid;
  margin-top: 13px;
  text-transform: uppercase;
  letter-spacing: 0.9px;
}
.woocommerce-cart .cart-collaterals .cart_totals .shipping-calculator-form {
  margin-top: 15px;
}
.woocommerce-cart .cart-collaterals .cart_totals .button[name=calc_shipping] {
  width: 100%;
  margin-top: 10px;
  margin-bottom: 5px;
}
.woocommerce-cart .cart-collaterals .cart_totals tr td {
  border-color: #eaeaea;
}
.woocommerce-cart .cart-collaterals .cart_totals tr th {
  border-color: #eaeaea;
}

.single_variation {
  display: block;
  float: left;
  margin-bottom: 10px;
}

.variations_button {
  clear: both;
}

div.owp-woo-single-cond-notice {
  display: inline-block;
  margin-top: 10px;
  padding-top: 20px;
  border-top: 1px solid;
  border-color: #eaeaea;
  width: 100%;
  text-align: center;
  font-family: inherit;
  font-size: 18px;
  font-weight: 600;
  line-height: 2;
  letter-spacing: 1.5;
  text-transform: capitalize;
}
div.owp-woo-single-cond-notice span,
div.owp-woo-single-cond-notice a {
  color: #333333;
}
div.owp-woo-single-cond-notice a:hover {
  color: #52a7fe;
}

.product_meta {
  clear: both;
  font-size: 13px;
  border-top: 1px solid;
  border-bottom: 1px solid;
  margin-top: -1px;
  padding: 20px 0;
  color: #787878;
  margin-top: 20px;
  border-color: #eaeaea;
}
.product_meta span {
  display: block;
}
.product_meta span.sku {
  display: inline;
}
.product_meta .posted_in {
  color: #333;
  font-weight: 600;
}
.product_meta .posted_in a {
  color: #ababab;
  font-weight: 400;
}
.product_meta .posted_in a:hover {
  color: #13aff0;
}
.product_meta .tagged_as {
  color: #333;
  font-weight: 600;
}
.product_meta .tagged_as a {
  color: #ababab;
  font-weight: 400;
}
.product_meta .tagged_as a:hover {
  color: #13aff0;
}

.sku_wrapper {
  color: #333;
  font-weight: 600;
}
.sku_wrapper span {
  display: inline;
  color: #555;
  font-weight: 400;
}

.woocommerce-product-search label {
  display: none;
}
.woocommerce-product-search button[type=submit] {
  float: right;
  margin-top: 15px;
}

@-webkit-keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
  }
}
@keyframes fa-spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.product-quantity {
  font-weight: normal;
}

.woocommerce-MyAccount-content h2 {
  font-size: 2em;
  font-weight: 600;
}
.woocommerce-MyAccount-content .addresses {
  margin-top: 40px;
}
.woocommerce-MyAccount-content .addresses .woocommerce-Address .title {
  background-color: #f7f7f7;
  padding: 15px 25px;
  position: relative;
  border-bottom: 1px solid #fff;
}
.woocommerce-MyAccount-content .addresses .woocommerce-Address .title h3 {
  font-size: 20px;
  font-weight: 400;
  margin: 0;
}
.woocommerce-MyAccount-content .addresses .woocommerce-Address .title a {
  position: absolute;
  top: 10px;
  right: 10px;
  padding: 6px 15px;
  background-color: #fff;
  color: #898989;
}
.woocommerce-MyAccount-content .addresses .woocommerce-Address .title a:hover {
  background-color: #f8f8f8;
  color: #555;
}
.woocommerce-MyAccount-content .addresses .woocommerce-Address address {
  background-color: #f7f7f7;
  padding: 15px 25px;
  color: #898989;
}
.woocommerce-MyAccount-content #payment .payment_methods {
  margin-bottom: 1.618em !important;
}
.woocommerce-MyAccount-content #payment .payment_methods li .payment_box {
  background-color: rgba(0, 0, 0, 0.05);
}

p.stars span a {
  border-color: #eaeaea;
}

@media (min-width: 768px) {
  .woocommerce-MyAccount-tabs {
    float: left;
    width: 18%;
    margin-right: 6%;
  }
  .woocommerce-MyAccount-content {
    float: right;
    width: 76%;
  }
}
.current-shop-items-dropdown {
  border-top-color: #13aff0;
}

.return-to-shop .button.wc-backward:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  content: "\f104";
  margin-right: 8px;
}

#site-navigation-wrap .dropdown-menu > li > a.wcmenucart {
  letter-spacing: 0;
}

body a.wcmenucart.wcmenucart-empty-cart i {
  margin-right: 0;
}

.custom-col .col.first {
  clear: none;
}

.form-row .required {
  color: #e42234;
  border: 0;
}

del .amount {
  color: #555;
}

.select2-container .select2-choice {
  line-height: 40px;
  height: 40px;
  border-color: #ddd;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  border-radius: 3px;
}
.select2-container .select2-choice .select2-arrow {
  width: 30px;
}
.select2-container .select2-choice .select2-arrow b {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  font-size: 15px;
  line-height: 40px;
  text-align: center;
}
.select2-container .select2-choice .select2-arrow b:before {
  content: "\f107";
}
.select2-container .select2-choice .select2-arrow b:after {
  display: none;
}
.select2-container .select2-choice abbr {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  font-size: 15px;
  line-height: 40px;
  text-align: center;
}

.select2-dropdown-open.select2-drop-above .select2-choice {
  border-color: #bbb;
}
.select2-dropdown-open.select2-drop-above .select2-choices {
  border-color: #bbb;
}

.select2-drop.select2-drop-above.select2-drop-active {
  border-color: #bbb;
}

#review_form #respond {
  position: static;
  margin: 0;
  width: auto;
  padding: 0;
  background: transparent none;
  border: 0;
}
#review_form #respond:after {
  content: "";
  display: block;
  clear: both;
}
#review_form #respond p {
  text-align: left;
}
#review_form #respond p.comment-form-author {
  width: 50%;
  float: left;
  padding-right: 10px;
}
#review_form #respond p.comment-form-author input {
  width: 100%;
}
#review_form #respond p.comment-form-email {
  width: 50%;
  float: right;
  padding-left: 10px;
}
#review_form #respond p.comment-form-email input {
  width: 100%;
}
#review_form #respond p label {
  display: block;
  margin-bottom: 7px;
}
#review_form #respond input {
  width: auto;
}
#review_form #respond textarea {
  width: 100%;
}
#review_form #respond .form-submit input {
  left: auto;
  left: auto;
}

/**
 * WooCommerce Sales Badge
 */
.woocommerce span.onsale {
  position: absolute;
  top: 1.25rem;
  left: 1.25rem;
  background-color: rgba(63, 195, 135, 0.8);
  color: #fff;
  padding: 8px 12px;
  text-transform: uppercase;
  font-size: 12px;
  line-height: 1;
  font-weight: 600;
  letter-spacing: 0.4px;
  z-index: 9;
}
.woocommerce .circle-sale span.onsale {
  padding: 0;
  width: 50px;
  height: 50px;
  line-height: 50px;
  text-align: center;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}

.woocommerce .owp-thumbs-layout-vertical span.onsale {
  left: 15% !important;
}

/* Sales Badge Responsive */
@media only screen and (max-width: 1080px) {
  .woocommerce .has-product-nav span.onsale {
    top: 3.5rem;
  }
}
@media only screen and (max-width: 767px) {
  .woocommerce .has-product-nav span.onsale {
    top: 7rem !important;
  }
  .woocommerce span.onsale {
    left: 15%;
    top: 2rem;
  }
}
@media only screen and (max-width: 660px) {
  .woocommerce span.onsale {
    left: 10% !important;
  }
}
@media only screen and (max-width: 240px) {
  .woocommerce .has-product-nav span.onsale {
    top: 8rem !important;
  }
}
.products .product-category {
  text-align: center;
}
.products .product-category img {
  display: block;
  margin: 0 auto;
}
.products .product-category mark {
  background: none;
  color: inherit;
}

.woocommerce-checkout-review-order-table tfoot th {
  background-color: #f7f7f7;
}

form.checkout {
  position: static !important;
}
form.checkout > .blockUI {
  position: fixed !important;
}

.blockUI.blockOverlay {
  background: rgba(250, 250, 250, 0.6) !important;
}

.blockUI:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  content: "\f110";
  -webkit-animation: fa-spin 0.75s infinite linear;
  -moz-animation: fa-spin 0.75s infinite linear;
  -ms-animation: fa-spin 0.75s infinite linear;
  -o-animation: fa-spin 0.75s infinite linear;
  animation: fa-spin 0.75s infinite linear;
  height: 30px;
  width: 30px;
  line-height: 30px;
  font-size: 30px;
  position: absolute;
  top: 50%;
  left: 50%;
  margin-left: -15px;
  margin-top: -15px;
}

.woocommerce-MyAccount-tabs .oceanwp-user-profile {
  display: table;
  width: 100%;
  table-layout: auto;
  margin-bottom: 40px;
}
.woocommerce-MyAccount-tabs .oceanwp-user-profile .image {
  display: table-cell;
  vertical-align: middle;
  width: 64px;
  height: 64px;
}
.woocommerce-MyAccount-tabs .oceanwp-user-profile .image img {
  width: 100%;
  height: auto;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.woocommerce-MyAccount-tabs .oceanwp-user-profile .user-info {
  display: table-cell;
  vertical-align: middle;
  padding-left: 15px;
}
.woocommerce-MyAccount-tabs .oceanwp-user-profile .user-info .name {
  display: block;
  font-size: 18px;
  line-height: 1;
  margin-bottom: 5px;
  color: #333;
}
.woocommerce-MyAccount-tabs .oceanwp-user-profile .user-info .logout {
  font-size: 13px;
}

.woocommerce-MyAccount-navigation ul {
  list-style: none;
  margin: 15px 0;
  padding: 0;
  border-top: 1px solid #eaeaea;
}
.woocommerce-MyAccount-navigation ul li {
  list-style: none;
  border-bottom: 1px solid #eaeaea;
  position: relative;
}
.woocommerce-MyAccount-navigation ul li a {
  padding: 12px 0;
  display: block;
}
.woocommerce-MyAccount-navigation ul li a:before {
  display: inline-block;
  font-family: "simple-line-icons";
  font-weight: normal;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  font-size: inherit;
  text-rendering: auto;
  content: "\e085";
  color: #13aff0;
  line-height: 22px;
  margin-left: 8px;
  width: 20px;
  text-align: right;
  float: right;
  -moz-opacity: 0.45;
  -webkit-opacity: 0.45;
  opacity: 0.45;
  -webkit-transition: opacity 0.3s ease;
  -moz-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  -o-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.woocommerce-MyAccount-navigation ul li a:hover:before {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce-MyAccount-navigation ul li.is-active a:before {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--dashboard a:before {
  content: "\e007";
}
.woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--orders a:before {
  content: "\e04d";
}
.woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--downloads a:before {
  content: "\e083";
}
.woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--edit-address a:before {
  content: "\e069";
}
.woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--payment-methods a:before {
  content: "\e025";
}
.woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--edit-account a:before {
  content: "\e005";
}
.woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--customer-logout a:before {
  content: "\e065";
}
.woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--subscriptions a:before {
  content: "\e098";
}

.my_account_orders .button.view:after,
.woocommerce-MyAccount-downloads .button:after {
  font-family: "simple-line-icons";
}

.my_account_orders .button {
  padding: 0.618em 0.857em;
  font-size: 0.857em;
  margin-right: 0.236em;
}
.my_account_orders .button.view:after {
  content: "\e087";
  margin-left: 8px;
}

.woocommerce-MyAccount-downloads .button {
  padding: 0.618em 0.857em;
  font-size: 0.857em;
  margin-right: 0.236em;
}
.woocommerce-MyAccount-downloads .button:after {
  content: "\e083";
  margin-left: 8px;
}

.no-top-border .current-shop-items-dropdown {
  border-top: none;
}

.woocommerce a.button.loading:after,
.woocommerce button.button.loading:after,
.woocommerce input.button.loading:after,
.woocommerce ul.products li.product .added_to_cart:after,
.return-to-shop .button.wc-backward:before,
.woocommerce .widget_shopping_cart_content .buttons .button:after,
.woocommerce div.product form.cart .variations .reset_variations:before,
.wcmenucart i {
  font-style: normal;
  letter-spacing: normal;
  font-weight: 600;
  text-rendering: auto;
}

.distraction-free .medium-header .col-1,
.distraction-free .medium-header .col-3,
.distraction-free .top-header .header-top,
.distraction-free .vertical-header #site-header-inner .oceanwp-social-menu,
.distraction-free .vertical-header #vertical-searchform,
.distraction-free .oceanwp-social-menu,
.distraction-free #site-description,
.distraction-free .center-header .left-menu,
.distraction-free .center-header .right-menu,
.distraction-free .full_screen-header #site-navigation-wrap {
  display: none;
}

.distraction-free #site-logo {
  float: none;
  margin: auto;
}

.distraction-free #site-logo #site-logo-inner {
  text-align: center;
}

.distraction-free .center-header .navigation {
  justify-content: center;
  min-height: 60px;
}

.distraction-free .vertical-header #site-header-inner {
  display: flex;
  justify-content: center;
}

@media screen and (min-width: 960px) {
  .distraction-free .vertical-header #site-header-inner {
    flex-direction: column;
  }
}
.quick-view-plugin-active ul.products li.product li.btn-wrap {
  position: relative;
}

@media (min-width: 769px) {
  .woocommerce div.product.owp-thumbs-layout-vertical span.onsale {
    left: 12%;
  }
  .woocommerce div.product.owp-thumbs-layout-vertical.has-no-thumbnails span.onsale {
    left: 20px;
  }
  .woocommerce div.product.owp-thumbs-layout-vertical div.images .flex-viewport {
    float: right;
    width: 75%;
  }
  .woocommerce div.product.owp-thumbs-layout-vertical div.images .flex-control-thumbs {
    float: left;
    width: calc(25% - 1em);
    overflow-x: hidden;
  }
  .woocommerce div.product.owp-thumbs-layout-vertical div.images .flex-control-thumbs li {
    width: 100%;
  }
}
@media (min-width: 769px) {
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs {
    display: inline-block;
    width: 100%;
  }
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs ul.tabs {
    float: left;
    width: 20%;
    margin: 0;
    border: none;
  }
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs ul.tabs li {
    display: block;
    border-top: 1px solid #eaeaea;
  }
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs ul.tabs li:first-child {
    border-top: 0;
  }
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs ul.tabs li a {
    display: block;
    position: relative;
    text-align: left;
    border-width: 0;
  }
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs ul.tabs li a:after {
    content: "";
    position: absolute;
    top: 0;
    right: -2px;
    width: 3px;
    height: 100%;
    background-color: #13aff0;
    opacity: 0;
    z-index: 1;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    transition: all 0.3s ease;
  }
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs ul.tabs li.active a:after {
    opacity: 1;
  }
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs .panel {
    float: right;
    width: 80%;
    border-left-width: 1px;
    border-style: solid;
    border-color: #eaeaea;
    padding: 20px;
    margin: 0;
  }
  .woocommerce div.product.owp-tabs-layout-vertical .woocommerce-tabs .panel > h2:first-child {
    margin-top: 0;
  }
}
.woocommerce div.product.owp-tabs-layout-section .woocommerce-tabs ul.tabs {
  display: none;
}
.woocommerce div.product.owp-tabs-layout-section .panel {
  display: block !important;
  margin-top: 80px;
}
.woocommerce div.product.owp-tabs-layout-section .panel#tab-description {
  margin-top: 0;
}
.woocommerce div.product.owp-tabs-layout-section .panel h2:first-child {
  font-size: 28px;
  margin-top: 0;
}

.woocommerce .owp-btn-big .summary form button.button {
  width: 55%;
}
.woocommerce .owp-btn-very-big .summary form button.button {
  font-size: 16px;
  min-height: 50px;
  width: 100%;
  margin-top: 15px;
}

.demo_store {
  position: fixed;
  left: 0;
  bottom: 0;
  right: 0;
  margin: 0;
  padding: 15px 20px;
  background-color: #3d9cd2;
  color: #fff;
  z-index: 999;
}
.demo_store a {
  color: #fff;
  font-weight: 400;
  text-decoration: underline;
  display: block;
}
.demo_store a:hover {
  text-decoration: none;
}
.demo_store:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  font-style: normal;
  letter-spacing: normal;
  text-rendering: auto;
  margin-right: 10px;
  content: "\f05a";
}

@media (min-width: 768px) {
  .demo_store a {
    background: rgba(0, 0, 0, 0.1);
    float: right;
    display: inline-block;
    margin: -15px -20px -15px 0;
    padding: 15px 20px;
  }
  .demo_store a:before {
    font-family: "Font Awesome 5 Free";
    font-weight: 600;
    font-style: normal;
    letter-spacing: normal;
    text-rendering: auto;
    content: "\f057";
    margin-right: 10px;
  }
}
.owp-cart-overlay {
  display: none;
  background: rgba(0, 0, 0, 0.5);
  position: fixed;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 99;
  cursor: pointer;
}

/* WooCommerce Germanized ___________>> OceanWP */
li.wc-gzd {
  margin-bottom: 5px !important;
}
li.wc-gzd .price.price-unit.smaller.wc-gzd-additional-info,
li.wc-gzd .wc-gzd-additional-info.product-units-wrapper.product-units,
li.wc-gzd .wc-gzd-additional-info.shipping-costs-info {
  display: inline-block;
  width: 100%;
  text-align: center;
  margin: 0 0 5px;
  padding: 5px 0;
  line-height: 1;
  letter-spacing: 1;
}
li.wc-gzd .price.price-unit.smaller.wc-gzd-additional-info {
  font-size: 16px;
}

.wc-gzd-single .wc-gzd-additional-info.product-units-wrapper.product-units,
.wc-gzd-single .wc-gzd-additional-info.shipping-costs-info,
.wc-gzd-single p.price.price-unit.smaller.wc-gzd-additional-info {
  display: inline-block;
  width: 100%;
  margin: 0 0 5px;
  padding: 5px 0;
  line-height: 1.5;
  letter-spacing: 1;
}
.wc-gzd-single p.price.price-unit.smaller.wc-gzd-additional-info {
  font-size: 24px;
}

.wc-gzd-single,
.wc-gzd-single-meta,
li.wc-gzd {
  display: block;
  padding: 2px 0;
}

.wc-gzd-single-meta p.wc-gzd-additional-info {
  display: inline-block;
  width: 100%;
}
.wc-gzd-single-meta p.wc-gzd-additional-info {
  font-size: 14px;
}

.woocommerce.single-product .legal-price-info {
  margin-top: 10px;
}

/*.product_meta {
	.tagged_as::before {
		@include font-awesome();
		content: '\f02c';
		margin-right: 5px;
	}
}*/
/* WooCommerce My Account -> Add Payment Method */
.woocommerce-MyAccount-content #payment ul.payment_methods > li {
  background-color: #fafafa;
}
.woocommerce-MyAccount-content #payment ul.payment_methods .woocommerce-PaymentMethod > input[type=radio]:first-child {
  position: absolute !important;
  clip: rect(1px, 1px, 1px, 1px);
}
.woocommerce-MyAccount-content #payment ul.payment_methods .woocommerce-PaymentMethod > label {
  display: block;
  font-size: 16px;
  font-weight: 600;
  padding: 20px;
  cursor: pointer;
  margin: 0;
  letter-spacing: 0.4px;
}
.woocommerce-MyAccount-content #payment ul.payment_methods .woocommerce-PaymentMethod > label:before {
  font-family: "Font Awesome 5 Free";
  text-rendering: auto;
  display: inline-block;
  font-size: inherit;
  content: "\f111";
  color: #333;
  font-weight: 400;
  margin-right: 10px;
  -webkit-transition: color 0.2s ease;
  -moz-transition: color 0.2s ease;
  -ms-transition: color 0.2s ease;
  -o-transition: color 0.2s ease;
  transition: color 0.2s ease;
}
.woocommerce-MyAccount-content #payment ul.payment_methods .woocommerce-PaymentMethod > label:after {
  content: "";
  clear: both;
  display: table;
}
.woocommerce-MyAccount-content #payment ul.payment_methods .woocommerce-PaymentMethod > input[type=radio]:first-child:checked + label:before {
  content: "\f192";
  color: #13aff0;
}
.woocommerce-MyAccount-content #payment #payment div.woocommerce-PaymentBox {
  position: relative;
  width: 100%;
  padding: 1.4em;
  font-size: 0.92em;
  line-height: 1.5;
  background-color: #fff;
  color: #555;
}
.woocommerce-MyAccount-content #payment #payment div.woocommerce-PaymentBox p {
  margin: 0;
}
.woocommerce-MyAccount-content #add_payment_method .woocommerce-PaymentMethod label {
  margin-left: 0;
}
.woocommerce-MyAccount-content #place_order {
  width: 100%;
  font-size: 15px;
  line-height: 1.6;
  padding: 16px 20px;
}

ul#shipping_method {
  padding-bottom: 20px;
}
ul#shipping_method li {
  padding-bottom: 10px;
}
ul#shipping_method li label {
  padding-left: 10px;
  font-weight: bold;
  vertical-align: middle;
  color: #525252;
  cursor: pointer;
  font-size: 14.5px;
  letter-spacing: 0.5px;
}
ul#shipping_method li input[type=radio] {
  vertical-align: middle;
  cursor: pointer;
}

.woocommerce #order_review table.shop_table ul#shipping_method.woocommerce-shipping-methods {
  padding-bottom: 20px;
  text-align: left;
}
.woocommerce #order_review table.shop_table ul#shipping_method.woocommerce-shipping-methods li {
  padding-bottom: 10px;
}
.woocommerce #order_review table.shop_table ul#shipping_method.woocommerce-shipping-methods li label {
  display: inline;
  padding-left: 10px;
  font-weight: bold;
  vertical-align: middle;
  color: #525252;
  cursor: pointer;
  font-size: 14.5px;
  letter-spacing: 0.5px;
}
.woocommerce #order_review table.shop_table ul#shipping_method.woocommerce-shipping-methods li input[type=radio] {
  vertical-align: middle;
  cursor: pointer;
}

#order-review table tfoot tr.woocommerce-shipping-totals.shipping td ul#shipping_method {
  padding-bottom: 20px;
  display: block;
}
#order-review table tfoot tr.woocommerce-shipping-totals.shipping td ul#shipping_method li {
  padding-bottom: 10px;
}
#order-review table tfoot tr.woocommerce-shipping-totals.shipping td ul#shipping_method li label {
  padding-left: 10px;
  font-weight: bold;
  vertical-align: middle;
  color: #525252;
  cursor: pointer;
  font-size: 14.5px;
  letter-spacing: 0.5px;
}
#order-review table tfoot tr.woocommerce-shipping-totals.shipping td ul#shipping_method li input[type=radio] {
  vertical-align: middle;
  cursor: pointer;
  display: inline-block;
}

.woocommerce.woo-variation-swatches-stylesheet-enabled .variable-items-wrapper {
  margin: 0;
}

/* Product title background for cross-sell on cart page */
.woocommerce .cross-sells li.title h2 {
  background-color: transparent !important;
  border-bottom: none;
}

/* Product variation on Elementor pages */
.woocommerce div.product.elementor form.cart table.variations td.value:before {
  content: none;
}

.woocommerce div.product.elementor form.cart table.variations td {
  display: block !important;
  line-height: inherit !important;
}

.widget_product_categories li,
.widget_layered_nav li {
  position: relative;
  margin-bottom: 10px;
}
.widget_product_categories li a,
.widget_layered_nav li a {
  position: relative;
  display: block;
  font-size: 13px;
  line-height: 1.6;
  padding-left: 22px;
  text-transform: capitalize;
}
.widget_product_categories li a:before,
.widget_layered_nav li a:before {
  content: "";
  position: absolute;
  top: 50%;
  left: 0;
  margin-top: -7px;
  width: 14px;
  height: 14px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}
.widget_product_categories li a:hover ~ .count,
.widget_layered_nav li a:hover ~ .count {
  background-color: transparent;
  color: #13aff0;
  border-color: #13aff0;
}
.widget_product_categories .count,
.widget_layered_nav .count {
  background-color: rgba(84, 84, 84, 0.05);
  position: absolute;
  top: 0;
  right: 0;
  font-size: 12px;
  line-height: 18px;
  padding: 0 10px;
  text-align: center;
  min-width: 10px;
  border: 1px solid transparent;
  border-radius: 10px;
  -webkit-transition: all 0.3s ease-in-out;
  -moz-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  -o-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}

.woocommerce .widget_product_categories li a:before {
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.woocommerce .widget_product_categories li.current-cat > a {
  font-weight: bold;
}
.woocommerce .widget_product_categories li.current-cat > a:before {
  background-color: #13aff0;
  border-color: #13aff0;
}
.woocommerce .widget_product_categories li.current-cat > a ~ .count {
  background-color: #13aff0;
  color: #fff;
  border-color: #13aff0;
}
.woocommerce .widget_product_categories li ul.children {
  margin: 8px 0 0 30px;
}
.woocommerce .widget_product_categories li ul.children li {
  font-size: 12px;
  line-height: 1.3;
  margin-bottom: 5px;
}
.woocommerce .widget_product_categories li ul.children li a {
  padding-left: 0;
}
.woocommerce .widget_product_categories li ul.children li a:before {
  display: none;
}
.woocommerce .widget_product_categories li ul.children .count {
  line-height: 18px;
}
.woocommerce .widget_product_categories li ul a {
  font-weight: 400;
  text-transform: none;
  border-bottom: 0;
}

.woocommerce .widget_layered_nav li a:before {
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -ms-border-radius: 2px;
  border-radius: 2px;
}
.woocommerce .widget_layered_nav li.chosen a {
  font-weight: bold;
}
.woocommerce .widget_layered_nav li.chosen a:before {
  background-color: #13aff0;
  border-color: #13aff0;
  text-align: center;
  content: "\f00c";
  color: #fff;
  font: normal normal 900 14px/1 "Font Awesome 5 free";
  font-size: 10px;
  line-height: 10px;
  text-rendering: auto;
}
.woocommerce .widget_layered_nav li.chosen a:hover:before {
  content: "\f00d";
}
.woocommerce .widget_layered_nav li.chosen a ~ .count {
  background-color: #13aff0;
  color: #fff;
  border-color: #13aff0;
}

/* Dropdown style */
.woo-dropdown-cat .widget_product_categories li {
  position: relative;
}
.woo-dropdown-cat .widget_product_categories li a {
  display: block;
  font-size: 12px;
  line-height: 1.6;
  font-weight: 600;
  text-transform: uppercase;
  padding: 10px 22px 10px 0;
  border-bottom: 1px solid #eaeaea;
}
.woo-dropdown-cat .widget_product_categories li a:before {
  display: none;
}
.woo-dropdown-cat .widget_product_categories li .open-this {
  position: absolute;
  left: 0;
  width: 40px;
  height: 40px;
  line-height: 40px;
  font-size: 14px;
  text-align: center;
  cursor: pointer;
  z-index: 10;
}
.woo-dropdown-cat .widget_product_categories li.cat-parent .open-this {
  left: auto;
  right: 0;
}
.woo-dropdown-cat .widget_product_categories li ul.children {
  display: none;
  margin: 0 0 0 16px;
}
.woo-dropdown-cat .widget_product_categories li.current-cat-parent > ul.children {
  display: block;
}
.woo-dropdown-cat .widget_product_categories li ul a {
  font-weight: 400;
  text-transform: none;
  border-bottom: 0;
}
.woo-dropdown-cat .widget_product_categories .count {
  position: absolute;
  top: 0;
  right: 40px;
  border: 0;
  padding: 10px 0 0;
  z-index: 10;
}
.woo-dropdown-cat .widget_product_categories .count,
.woo-dropdown-cat .widget_product_categories li.current-cat > a ~ .count {
  background-color: transparent !important;
  color: #999;
}

/*------------------------------------------------------------------
Woo Mobile Mini Cart Sidebar
-------------------------------------------------------------------*/
#oceanwp-cart-sidebar-wrap {
  display: none;
  visibility: hidden;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  -webkit-transition: all 0.25s ease-in-out;
  -moz-transition: all 0.25s ease-in-out;
  -ms-transition: all 0.25s ease-in-out;
  -o-transition: all 0.25s ease-in-out;
  transition: all 0.25s ease-in-out;
}
#oceanwp-cart-sidebar-wrap,
#oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar-overlay {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 9999;
}
#oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar-overlay {
  background-color: rgba(0, 0, 0, 0.5);
  cursor: pointer;
}
#oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar {
  position: absolute;
  top: 0;
  right: -100%;
  background-color: #fff;
  width: 325px;
  height: 100%;
  padding: 20px 0 0;
  overflow: auto;
  z-index: 10000;
  -webkit-box-shadow: 0 0 12px 0 rgba(0, 0, 0, 0.4);
  -moz-box-shadow: 0 0 12px 0 rgba(0, 0, 0, 0.4);
  box-shadow: 0 0 12px 0 rgba(0, 0, 0, 0.4);
  -webkit-transition: all 0.3s ease-in-out;
  -moz-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  -o-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}
#oceanwp-cart-sidebar-wrap .owp-cart-title {
  font-size: 18px;
  font-weight: 600;
  color: #555;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0 20px;
  margin: 0;
  text-align: center;
}
#oceanwp-cart-sidebar-wrap .divider {
  display: block;
  width: 30px;
  height: 2px;
  background-color: rgba(0, 0, 0, 0.1);
  margin: 10px auto 20px;
}
#oceanwp-cart-sidebar-wrap .oceanwp-cart-close {
  position: absolute;
  top: 0;
  right: 0;
  color: #333;
  opacity: 0.5;
  font-weight: 300;
  font-size: 40px;
  width: 40px;
  height: 40px;
  line-height: 40px;
  text-align: center;
  z-index: 1001;
}
#oceanwp-cart-sidebar-wrap .oceanwp-cart-close:hover {
  opacity: 1;
}
#oceanwp-cart-sidebar-wrap .widget_shopping_cart ul.cart_list li:first-child {
  border-top-width: 1px;
}
#oceanwp-cart-sidebar-wrap .woocommerce-mini-cart__empty-message {
  padding: 0 20px 20px;
  margin: 0;
}
#oceanwp-cart-sidebar-wrap .spacious .owp-mini-cart {
  padding-top: 0;
}
#oceanwp-cart-sidebar-wrap .spacious .owp-mini-cart .widget_shopping_cart ul.cart_list li:first-child {
  padding-top: 10px;
}

.admin-bar #oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar {
  top: 32px;
  height: -webkit-calc(100% - 32px);
  height: calc(100% - 32px);
}

@media screen and (max-width: 782px) {
  .admin-bar #oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar {
    top: 46px;
    height: -webkit-calc(100% - 46px);
    height: calc(100% - 46px);
  }
}
@media screen and (max-width: 600px) {
  .admin-bar #oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar {
    top: 0;
    height: 100%;
  }
}
.show-cart #oceanwp-cart-sidebar-wrap,
.show-cart-sidebar #oceanwp-cart-sidebar-wrap {
  visibility: visible;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.show-cart #oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar,
.show-cart-sidebar #oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar {
  right: 0;
}

@media only screen and (max-width: 959px) {
  #oceanwp-cart-sidebar-wrap {
    display: block;
  }
}
/*------------------------------------------------------------------
Woo Off Canvas Filter
-------------------------------------------------------------------*/
.woocommerce .oceanwp-off-canvas-filter {
  float: left;
  height: 34px;
  font-size: 14px;
  font-weight: 600;
  line-height: 34px;
  padding: 0 14px;
  color: #999;
  border: 1px solid #eaeaea;
  margin: 0 20px 0 0;
  text-align: center;
}
.woocommerce .oceanwp-off-canvas-filter:hover {
  color: #13aff0;
  border-color: #13aff0;
}
.woocommerce .oceanwp-off-canvas-filter i {
  margin-right: 6px;
}
.woocommerce .oceanwp-off-canvas-filter .owp-icon {
  vertical-align: inherit;
  margin-right: 5px;
}

#oceanwp-off-canvas-sidebar-wrap {
  visibility: hidden;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  -webkit-transition: all 0.25s ease-in-out;
  -moz-transition: all 0.25s ease-in-out;
  -ms-transition: all 0.25s ease-in-out;
  -o-transition: all 0.25s ease-in-out;
  transition: all 0.25s ease-in-out;
}
#oceanwp-off-canvas-sidebar-wrap,
#oceanwp-off-canvas-sidebar-wrap .oceanwp-off-canvas-overlay {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 9999;
}
#oceanwp-off-canvas-sidebar-wrap .oceanwp-off-canvas-overlay {
  background-color: rgba(0, 0, 0, 0.5);
  cursor: pointer;
}
#oceanwp-off-canvas-sidebar-wrap .oceanwp-off-canvas-sidebar {
  position: absolute;
  top: 0;
  left: -100%;
  background-color: #fff;
  width: 325px;
  height: 100%;
  padding: 35px;
  overflow: auto;
  z-index: 99999;
  -webkit-box-shadow: 0 0 12px 0 rgba(0, 0, 0, 0.4);
  -moz-box-shadow: 0 0 12px 0 rgba(0, 0, 0, 0.4);
  box-shadow: 0 0 12px 0 rgba(0, 0, 0, 0.4);
  -webkit-transition: all 0.3s ease-in-out;
  -moz-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  -o-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}
#oceanwp-off-canvas-sidebar-wrap .sidebar-box {
  border-bottom: 1px solid rgba(84, 84, 84, 0.15);
  margin-bottom: 0;
  padding-top: 50px;
  padding-bottom: 50px;
}
#oceanwp-off-canvas-sidebar-wrap .sidebar-box:first-child {
  padding-top: 0;
}
#oceanwp-off-canvas-sidebar-wrap .sidebar-box:last-child {
  border-bottom: 0;
  padding-bottom: 0;
}

.admin-bar #oceanwp-off-canvas-sidebar-wrap .oceanwp-off-canvas-sidebar {
  top: 32px;
  height: -webkit-calc(100% - 32px);
  height: calc(100% - 32px);
}

@media screen and (max-width: 782px) {
  .admin-bar #oceanwp-off-canvas-sidebar-wrap .oceanwp-off-canvas-sidebar {
    top: 46px;
    height: -webkit-calc(100% - 46px);
    height: calc(100% - 46px);
  }
}
@media screen and (max-width: 600px) {
  .admin-bar #oceanwp-off-canvas-sidebar-wrap .oceanwp-off-canvas-sidebar {
    top: 0;
    height: 100%;
  }
}
.off-canvas-enabled #oceanwp-off-canvas-sidebar-wrap {
  visibility: visible;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.off-canvas-enabled #oceanwp-off-canvas-sidebar-wrap .oceanwp-off-canvas-sidebar {
  left: 0;
}

.oceanwp-off-canvas-close {
  position: absolute;
  top: 15px;
  right: 15px;
  width: 30px;
  height: 30px;
  background-color: transparent;
  border: 0;
  margin: 0;
  padding: 0;
  text-align: center;
  z-index: 1000;
}
.oceanwp-off-canvas-close svg {
  fill: #333;
  -webkit-transition: all 0.3s ease-in-out;
  -moz-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  -o-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}
.oceanwp-off-canvas-close:hover svg {
  fill: #777;
}

/*------------------------------------------------------------------
Woo Quantity Buttons
-------------------------------------------------------------------*/
.quantity {
  position: relative;
  float: left;
  overflow: hidden;
  zoom: 1;
  min-width: 110px;
}
.quantity .qty,
.quantity .minus,
.quantity .plus {
  display: block;
  float: left;
  width: 36px;
  min-height: 36px;
  background-color: transparent;
  border: 1px solid #e4e4e4;
  margin: 0;
  padding: 0;
  text-align: center;
  vertical-align: middle;
  font-size: 12px;
  color: #777;
  -moz-appearance: textfield; /* hack firefox */
  -webkit-appearance: none;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.quantity .minus,
.quantity .plus {
  font-size: 13px;
  line-height: 34px;
}
.quantity .minus {
  border-right-width: 0;
}
.quantity .plus {
  border-left-width: 0;
}
.quantity input::-webkit-outer-spin-button {
  display: none;
}
.quantity input::-webkit-inner-spin-button {
  display: none;
}

.woocommerce form input[type=number] {
  max-width: 58px;
  min-height: 36px;
}

.woocommerce form input.qty[type=number] {
  -moz-appearance: textfield; /* hack firefox */
}

/*------------------------------------------------------------------
Woo Product Navigation
-------------------------------------------------------------------*/
@media (min-width: 1080px) {
  .owp-product-nav-wrap {
    position: absolute;
    top: 0;
    right: 0;
  }
}
.owp-product-nav-wrap {
  text-align: right;
  z-index: 1;
}

.owp-product-nav {
  position: relative;
  display: inline-block;
}
.owp-product-nav li {
  display: inline-block;
  margin-left: 3px;
}
.owp-product-nav li:first-child {
  margin-left: 0;
}
.owp-product-nav li a.owp-nav-link {
  display: inline-block;
  width: 28px;
  height: 28px;
  line-height: 24px;
  border: 2px solid #e9e9e9;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  text-align: center;
}
.owp-product-nav li a.owp-nav-link i {
  line-height: 1.2;
}
.owp-product-nav li a.owp-nav-link .owp-icon {
  display: inline-block;
  height: 100%;
  width: 100%;
  padding: 6px;
}
.owp-product-nav li a.owp-nav-link .owp-icon:hover use {
  stroke: #fff;
}
.owp-product-nav li a.owp-nav-link:hover {
  background-color: #13aff0;
  color: #fff;
  border-color: #13aff0;
}
.owp-product-nav li a.owp-nav-text {
  display: none;
  font-size: 12px;
}
.owp-product-nav li a.owp-nav-text.next-text {
  padding-right: 5px;
}
.owp-product-nav li a.owp-nav-text.prev-text {
  padding-left: 5px;
}
.owp-product-nav li .owp-nav-thumb {
  position: absolute;
  top: 100%;
  left: -99999px;
  display: inline-block;
  width: 90px;
  opacity: 0;
  -webkit-transition: opacity 0.25s ease-in-out;
  -moz-transition: opacity 0.25s ease-in-out;
  -ms-transition: opacity 0.25s ease-in-out;
  -o-transition: opacity 0.25s ease-in-out;
  transition: opacity 0.25s ease-in-out;
  -webkit-box-shadow: 1px 1px 15px rgba(0, 0, 0, 0.15);
  -moz-box-shadow: 1px 1px 15px rgba(0, 0, 0, 0.15);
  box-shadow: 1px 1px 15px rgba(0, 0, 0, 0.15);
  z-index: 100;
}
.owp-product-nav li:hover > .owp-nav-thumb {
  opacity: 1;
  left: 50%;
  -webkit-transform: translateX(-50%);
  transform: translateX(-50%);
}

@media only screen and (max-width: 767px) {
  .owp-product-nav-wrap {
    margin-bottom: 15px;
  }
  .owp-product-nav {
    display: block;
  }
  .owp-product-nav li.next-li {
    float: right;
    display: flex;
    align-items: center;
  }
  .owp-product-nav li.prev-li {
    float: left;
    display: flex;
    align-items: center;
  }
  .owp-product-nav li {
    position: relative;
  }
  .owp-product-nav li a.owp-nav-text {
    display: inline-block;
  }
}
/*------------------------------------------------------------------
Woo Responsive
-------------------------------------------------------------------*/
.sidr-class-woo-menu-icon {
  display: none;
}

.sidr-class-woocommerce {
  display: none;
}

@media only screen and (max-width: 1280px) {
  .woocommerce div.product .product-thumbnails {
    width: 275px;
  }
}
@media only screen and (max-width: 992px) {
  .woocommerce #customer_login .lost_password {
    float: none;
    margin-top: 10px !important;
    line-height: 1;
  }
  .woocommerce #customer_login .form-row label[for=rememberme] {
    margin: 0 0 0 4px;
  }
  .woocommerce .oceanwp-loginform-wrap .lost_password {
    float: none;
    margin-top: 10px !important;
    line-height: 1;
  }
  .woocommerce .oceanwp-loginform-wrap .form-row label[for=rememberme] {
    margin: 0 0 0 4px;
  }
}
@media only screen and (max-width: 959px) {
  body.account-side-style .woocommerce #customer_login > div,
body.account-side-style .woocommerce #customer_login .col-2 {
    float: none;
    width: 100%;
  }
  body.account-side-style .woocommerce #customer_login .col-2 {
    margin-top: 20px;
  }
  .woocommerce-checkout #order_review {
    float: none;
    width: 100%;
  }
  .woocommerce-checkout > .col2-set {
    float: none;
    width: 100%;
  }
  .woocommerce-checkout h3#order_review_heading {
    float: none;
    width: 100%;
  }
  .woocommerce-checkout form.checkout_coupon {
    width: 100%;
    margin-bottom: 20px;
  }
  .woocommerce-checkout form.checkout_coupon .form-row-first,
.woocommerce-checkout form.checkout_coupon .form-row-last {
    float: none;
    width: 100%;
    margin: 0;
  }
  .woocommerce-checkout form.checkout_coupon .form-row-last {
    margin-top: 10px;
  }
  .woocommerce-checkout form.checkout {
    margin-top: 10px;
  }
}
@media only screen and (max-width: 767px) {
  .woocommerce ul.products.list li.product .woo-entry-image,
.woocommerce ul.products.list li.product .product-entry-slider-wrap {
    float: none;
    width: 100%;
    margin: 0 0 20px;
  }
  .woocommerce ul.products.list li.product .woo-entry-inner {
    float: none;
    width: 100%;
  }
  .woocommerce ul.order_details li {
    float: none;
    width: 100%;
    margin-bottom: 10px;
    padding-bottom: 10px;
    border: 0;
    border-bottom: 1px solid #e9e9e9;
  }
  .woocommerce .form-row-first {
    float: none;
    width: 100%;
    margin-right: 0;
    margin-left: 0 !important;
  }
  .woocommerce .form-row-last {
    float: none;
    width: 100%;
  }
  .woocommerce .cart-collaterals .cross-sells {
    display: none;
  }
  .woocommerce .cart-collaterals .cart_totals {
    float: none;
    width: 100%;
    margin-bottom: 20px;
  }
  .woocommerce div.product div.images {
    float: none;
    width: 100% !important;
    text-align: center;
  }
  .woocommerce div.product div.summary {
    float: none;
    width: 100% !important;
  }
  .woocommerce div.product .woocommerce-tabs ul.tabs li {
    display: block;
  }
  .woocommerce.content-full-width div.product div.images {
    float: none;
    width: 100%;
  }
  .woocommerce.content-full-width div.product div.summary {
    float: none;
    width: 100%;
  }
  .woocommerce #customer_login .form-row label[for=rememberme] {
    margin: 0 0 0 4px;
  }
  .woocommerce .order_details li:last-of-type {
    padding: 0;
    margin: 0;
  }
  .col2-set .col-1 {
    float: none;
    width: 100%;
  }
  .col2-set .col-2 {
    float: none;
    width: 100%;
  }
  .col2-set > div:first-child {
    margin-bottom: 30px;
  }
  .woocommerce-page .cart-collaterals .cart_totals {
    float: none;
    width: 100%;
    margin-bottom: 20px;
  }
  .woocommerce-cart .cart-collaterals .cart_totals table td {
    text-align: right;
  }
  .woocommerce-cart table.cart td.actions .coupon .input-text {
    max-width: 150px;
  }
  .woocommerce-message:before {
    display: none;
  }
  .woocommerce-cart .woocommerce table.shop_table thead {
    display: none;
  }
  .woocommerce-cart .woocommerce table.shop_table tbody th {
    display: none;
  }
  .woocommerce-cart .woocommerce table.shop_table tr td {
    display: inline-block;
    width: 100%;
    text-align: right;
    clear: both;
  }
  .woocommerce-cart .woocommerce table.shop_table tr td:before {
    content: attr(data-title) ": ";
    font-weight: 600;
    float: left;
    font-size: 14.5px;
    letter-spacing: 0.8px;
    color: #525252;
  }
  .woocommerce-cart .woocommerce table.shop_table tr td.product-remove:before, .woocommerce-cart .woocommerce table.shop_table tr td.product-thumbnail:before {
    display: none;
  }
  .woocommerce-cart .woocommerce table.shop_table tr td.product-thumbnail {
    text-align: center;
  }
  .woocommerce-cart .woocommerce table.shop_table tr td.product-quantity .quantity {
    float: right;
  }
  .woocommerce-cart .woocommerce table.shop_table tr td.product-subtotal span.woocommerce-Price-amount.amount {
    font-size: 14px;
    font-weight: 600;
    letter-spacing: 0.5px;
  }
  .woocommerce-cart .woocommerce table.shop_table tr td.actions:before, .woocommerce-cart .woocommerce table.shop_table tr td.download-actions:before {
    display: none;
  }
  .woocommerce-cart .woocommerce table.shop_table tr td.download-actions .button {
    display: block;
    text-align: center;
  }
  .woocommerce-cart .woocommerce table.shop_table.my_account_orders .order-actions {
    text-align: right;
  }
  .woocommerce-cart .woocommerce table.shop_table.my_account_orders .order-actions:before {
    display: none;
  }
  .distraction-free #site-header.center-header #site-logo {
    text-align: -webkit-center;
  }
  .distraction-free #site-header.vertical-header #site-header-inner {
    width: fit-content;
  }
}
@media only screen and (max-width: 767px) {
  ul#shipping_method {
    display: inline-block;
    width: 100%;
    text-align: left;
    padding-top: 20px;
  }
  ul#shipping_method li {
    padding-bottom: 20px;
  }
  .woocommerce .cart-collaterals p {
    text-align: left;
  }
  .woocommerce .cart-collaterals .cart_totals .shipping-calculator-button {
    float: left;
  }
}
@media only screen and (max-width: 580px) {
  .woocommerce-cart table.cart td.actions .coupon {
    float: none;
    width: 100%;
    text-align: center;
    padding-bottom: 1em;
    border-bottom: 1px solid rgba(0, 0, 0, 0.05);
  }
  .woocommerce-cart table.cart td.actions .coupon .input-text {
    width: 100%;
    max-width: 100%;
    margin: 0 0 10px;
  }
  .woocommerce-cart table.cart td.actions .coupon input {
    width: 100%;
  }
  .woocommerce-cart table.cart td.actions .coupon button[name=apply_coupon] {
    width: 100%;
    display: inline-block;
    float: none;
  }
  .woocommerce-cart table.cart td.actions button[name=update_cart] {
    display: inline-block;
    float: none;
    width: 100%;
    margin-top: 15px;
  }
}
@media only screen and (max-width: 480px) {
  .woocommerce .result-count {
    display: none;
  }
  .woocommerce .oceanwp-toolbar {
    text-align: center;
  }
  .woocommerce .oceanwp-off-canvas-filter,
.woocommerce .oceanwp-grid-list {
    display: inline-block;
    float: none;
  }
  .woocommerce .oceanwp-grid-list {
    margin: 0;
  }
  .woocommerce .woocommerce-ordering {
    float: none;
    margin-top: 14px;
    text-align: left;
  }
  .woocommerce .woocommerce-ordering .orderby {
    width: 100% !important;
  }
  .woocommerce .woocommerce-ordering .orderby span {
    width: 100% !important;
  }
  .woocommerce-checkout form.login .lost_password {
    float: none;
    line-height: 1;
    margin: 10px 0 0;
  }
}
@media only screen and (max-width: 320px) {
  .woocommerce .woocommerce-ordering .orderby {
    width: 175px !important;
  }
  .woocommerce .woocommerce-ordering .orderby span {
    width: 175px !important;
  }
  .woocommerce div.product .product-thumbnails {
    width: 215px;
  }
  .woocommerce #reviews #comments ol.commentlist li .comment_container {
    padding: 0;
  }
  .woocommerce #reviews #comments ol.commentlist li img.avatar {
    display: none;
  }
  .woocommerce-cart table.cart td.actions input {
    width: 100%;
  }
  .woocommerce-cart table.cart td.actions .coupon .input-text {
    width: 100%;
    max-width: 100%;
    margin: 0 0 10px !important;
  }
}