#respond {
	margin-bottom: 20px;

	form {
		display: inline-block;
		width: 100%;
	}

	.comment-textarea,
	.comment-form-author,
	.comment-form-email,
	.comment-form-url {
		margin-bottom: 20px;
	}

	.comment-form-author,
	.comment-form-email,
	.comment-form-url {
		float: left;
		width: 33.33%;
	}

	.comment-form-author {
		padding-right: 10px;
	}

	.comment-form-email {
		padding: 0 10px;
	}

	.comment-form-url {
		padding-left: 10px;
	}

	input[type="text"] {
		width: 100%;
	}

	#wp-comment-cookies-consent:focus {
		outline: 1px solid;
	}

	.form-submit {
		float: right;
    	margin-bottom: 0;
	}
}

#comments {
	margin-top: 30px;
	padding-top: 30px;
	border-top: 1px solid $color-9;

	ol {
		margin: 0;
		list-style: none;

		&.children {
			margin-left: 30px;
		}
	}

	&.empty-closed-comments {
		display: none;
	}
}

.comment-body {
	@include display();
	margin-bottom: 30px;
	padding-bottom: 30px;
	border-bottom: 1px solid $color-9;

	img.avatar {
		width: 80px;
		height: 80px;
		margin-right: 30px;
		@include border-radius( 50% );
	}

	.comment-content {
		position: relative;
		width: 100%;
	}
}

.comment-author {
	display: inline-block;
	width: 100%;

	.comment-link, .comment-meta {
		font-weight: 600;
		margin: 5px 0 8px;
	}

	.comment-link {
		float: left;
		font-size: 18px;
	}

	.comment-meta {
		float: right;
		text-align: right;
		font-size: 10px;
		line-height: 2.5;
		text-transform: uppercase;
		letter-spacing: 0.1em;

		.comment-reply-link, .comment-edit-link {
			margin-left: 15px;
		}
	}
}

.comment-author .comment-meta .comment-reply-link {
	color: $color-5;
}

.comment-author .comment-meta .comment-reply-link:hover {
	color: $color-2;
}

#respond #cancel-comment-reply-link {
	font-size: 10px;
    color: $color-4;
    float: right;
    border: 2px solid $color-9;
    padding: 3px 10px;
    @include border-radius( 3px );
    text-transform: uppercase;
    letter-spacing: 0.1em;

    &:hover {
    	color: $color-5;
    	border-color: $color-5;
    }
}

span.required {
	position: relative;
	top: -4px;
	font-size: 10px;
	margin-left: 3px;
	color: #F00;
}

.comment-body p {
	margin: 0;
}

.no-comments {
	text-align: right;

	i {
		margin-right: 8px;
	}
}

.comment-navigation {
	display: inline-block;
    width: 100%;

	.nav-links {

		a {
			display: inline-block;
		    font-size: 12px;
		    line-height: 1.2;
		    padding-bottom: 3px;
		    border-bottom: 1px solid;
		    text-transform: uppercase;
		}

		.nav-previous {
			float: left;
	    	margin-right: 1.5em;

		    i {
				margin-right: 5px;
			}
		}

		.nav-next {
			float: right;
	    	margin-left: 1.5em;

			i {
				margin-left: 5px;
			}
		}
	}
}

/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {

	#comments ol.children {
		margin-left: 0;
		margin-right: 0;
	}
	
	#respond {
		.comment-form-author,
		.comment-form-email,
		.comment-form-url {
			float: none;
			width: 100%;
			padding-right: 0;
			padding: 0;
			padding-left: 0;
		}
	}
	
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {

	.comment-body img {
		display: none;
	}

	.comment-author {
		margin-bottom: 16px;

		.comment-link,
		.comment-meta {
			float: none;
		}
	}

}