/*------------------------------------------------------------------
Woo Multi-Step Checkout
-------------------------------------------------------------------*/
#owp-checkout-timeline {
  margin-bottom: 40px;
}
#owp-checkout-timeline li {
  float: left;
  width: 33.33%;
}
#owp-checkout-timeline.step-4 li {
  width: 25%;
}
#owp-checkout-timeline .timeline-wrapper {
  position: relative;
  display: block;
  padding: 10px;
  background-color: #eee;
  color: #333;
  font-size: 15px;
  line-height: 40px;
  -webkit-transition: all 0.1s ease;
  -moz-transition: all 0.1s ease;
  -ms-transition: all 0.1s ease;
  -o-transition: all 0.1s ease;
  transition: all 0.1s ease;
}
#owp-checkout-timeline .active .timeline-wrapper {
  background-color: #13aff0;
  color: #fff;
}
#owp-checkout-timeline .timeline-step {
  display: inline-block;
  font-size: 14px;
  text-align: center;
  width: 26px;
  height: 26px;
  line-height: 22px;
  margin-right: 8px;
  background-color: #fff;
  color: #ccc;
  border: 2px solid #ccc;
  border-radius: 20px;
}
#owp-checkout-timeline .timeline-label {
  font-weight: 600;
}
#owp-checkout-timeline.arrow li {
  padding-right: 50px;
}
#owp-checkout-timeline.arrow .timeline-wrapper:before, #owp-checkout-timeline.arrow .timeline-wrapper:after {
  content: "";
  position: absolute;
  top: 0;
  width: 0;
  height: 0;
  -webkit-transition: all 0.1s ease;
  -moz-transition: all 0.1s ease;
  -ms-transition: all 0.1s ease;
  -o-transition: all 0.1s ease;
  transition: all 0.1s ease;
}
#owp-checkout-timeline.arrow .timeline-wrapper:before {
  left: -20px;
  border-top: 30px solid #eee;
  border-bottom: 30px solid #eee;
  border-left: 20px solid transparent;
}
#owp-checkout-timeline.arrow .timeline-wrapper:after {
  right: -20px;
  border-top: 30px solid transparent;
  border-bottom: 30px solid transparent;
  border-left: 20px solid #eee;
  border-right-color: #eee;
}
#owp-checkout-timeline.arrow .active .timeline-wrapper:before {
  border-top-color: #13aff0;
  border-bottom-color: #13aff0;
}
#owp-checkout-timeline.arrow .active .timeline-wrapper:after {
  border-left-color: #13aff0;
  border-right-color: #13aff0;
}
#owp-checkout-timeline.square li {
  text-align: center;
}

#checkout-wrapper .woocommerce-billing-fields h3,
#checkout-wrapper #customer_shipping_details,
#checkout-wrapper #order_review,
#checkout-wrapper #customer_billing_details.show-login-reminder.not-logged-in,
#checkout-wrapper #checkout_coupon {
  display: none;
}
#checkout-wrapper #checkout_coupon,
#checkout-wrapper #checkout_login,
#checkout-wrapper form.checkout {
  max-width: 850px;
  margin: 0 auto;
}
#checkout-wrapper #order_review {
  max-width: 650px;
  margin: 0 auto;
}
#checkout-wrapper form.checkout {
  display: block;
}
#checkout-wrapper form.checkout #billing_phone_field,
#checkout-wrapper form.checkout #billing_email_field {
  width: 48%;
  clear: none;
}
#checkout-wrapper form.checkout #billing_phone_field {
  float: left;
}
#checkout-wrapper form.checkout #billing_email_field {
  float: right;
}
#checkout-wrapper form.checkout #order_review {
  float: none;
  width: 100%;
}
#checkout-wrapper form.login {
  margin-bottom: 0;
}
#checkout-wrapper .woocommerce-billing-fields__field-wrapper:after,
#checkout-wrapper .woocommerce-shipping-fields__field-wrapper:after {
  content: "";
  display: block;
  visibility: hidden;
  clear: both;
  zoom: 1;
  height: 0;
}
#checkout-wrapper #form_actions {
  display: inline-block;
  width: 100%;
  margin-top: 35px;
}
#checkout-wrapper #form_actions p.form-row.notes {
  margin: 0;
}
#checkout-wrapper #form_actions a {
  float: left;
  font-size: 12px;
  font-weight: 600;
  padding-bottom: 1px;
  border-bottom: 2px solid;
  margin-top: 6px;
  text-transform: uppercase;
  letter-spacing: 0.6px;
}
#checkout-wrapper #form_actions a i {
  font-size: 16px;
  margin-right: 5px;
}
#checkout-wrapper #form_actions .buttons {
  float: right;
}
#checkout-wrapper #form_actions .buttons input {
  -webkit-border-radius: 30px;
  -moz-border-radius: 30px;
  -ms-border-radius: 30px;
  border-radius: 30px;
}
#checkout-wrapper #form_actions .buttons input.prev {
  display: none;
}
#checkout-wrapper #form_actions .buttons input.next {
  margin-left: 10px;
}

.ow-invalid input,
.ow-invalid select,
.ow-invalid .select2-selection,
.ow-invalid textarea {
  border: 1px solid #dc3545 !important;
}

/* Responsive */
@media only screen and (max-width: 959px) {
  #owp-checkout-timeline li {
    padding: 0 !important;
    margin-bottom: 15px;
  }
  #owp-checkout-timeline li, #owp-checkout-timeline.step-4 li {
    float: none;
    width: 100%;
  }
}