.search-results article {
    position: relative;
    width: 100%;
    margin-bottom: 20px;
    padding-bottom: 20px;
    border-bottom: 1px solid $border-color;

    .search-entry-inner {
    	@include display();
        @include align-items( center );
    }

    .thumbnail {
    	min-width: 120px;
    	margin-right: 20px;

    	img {
    		@include border-radius( 5px );
    		@include box-shadow( 0 0 5px rgba(0,0,0,0.3) );
    	}
    }

    .search-entry-title {
    	font-size: 24px;
    	margin: 0 0 6px;
    }

    .search-entry-summary p:last-child {
        margin-bottom: 0;
    }

    .search-entry-readmore a {
        display: inline-block;
        font-size: 12px;
        font-weight: 600;
        line-height: 1;
        padding-bottom: 3px;
        border-bottom: 1px solid;
        text-transform: uppercase;
        letter-spacing: 0.6px;
    }

    ul {
    	list-style: none;
    }
}

/*------------------------------------*
    Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {

    .search-results article .thumbnail {
        display: none;
    }

}