.customize-control-oceanwp-heading { margin-top: 30px; }
.oceanwp-customizer-heading { display: block; margin: 0 -12px; padding: 13px 12px; background-color: #fff; color: #555; border: 1px solid #ddd; border-left: 0; border-right: 0; font-size: 11px; font-weight: 600; letter-spacing: 2px; line-height: 1; text-transform: uppercase; }
.customize-control-oceanwp-heading .description { margin-top: 10px; }