.customize-control-oceanwp-dimensions > ul { display: inline-block; width: 100%; }
.customize-control-oceanwp-dimensions .dimension-wrap { float: left; width: 20%; margin: 0; }
.customize-control-oceanwp-dimensions .dimension-wrap input,
.customize-control-oceanwp-dimensions .dimension-wrap button { display: block; font-size: 12px; padding: 4px 0; width: 100%; height: 28px; border: 1px solid; border-color: #a4afb7; border-left-width: 0; border-radius: 0; text-align: center; }
.customize-control-oceanwp-dimensions .dimension-wrap:first-child input { border-left-width: 1px; border-radius: 3px 0 0 3px; }
.customize-control-oceanwp-dimensions .dimension-wrap .dimension-label { display: block; color: #949698; font-size: 10px; padding-top: 5px; font-style: normal; text-transform: uppercase; text-align: center; }
.customize-control-oceanwp-dimensions .dimension-wrap input:focus + .dimension-label { color: #42474a; }
.customize-control-oceanwp-dimensions .dimension-wrap .link-dimensions { background-color: #fff; border: 1px solid #a4afb7; border-left-width: 0; padding: 0; outline: none; border-radius: 0 3px 3px 0; cursor: pointer; }
.customize-control-oceanwp-dimensions .dimension-wrap .link-dimensions span { display: block; width: 100%; height: 28px; line-height: 28px; font-size: 16px; }
.customize-control-oceanwp-dimensions .dimension-wrap .link-dimensions .oceanwp-linked { background-color: #a4afb7; color: #fff; }
.customize-control-oceanwp-dimensions .dimension-wrap .link-dimensions.unlinked .oceanwp-unlinked { display: none; }
.customize-control-oceanwp-dimensions .dimension-wrap .link-dimensions.unlinked .oceanwp-linked { display: block; }
.customize-control-oceanwp-dimensions .dimension-wrap .link-dimensions .oceanwp-linked { display: none; }