/**
 *  Quote format
 */
.post-quote-content,
.post-quote-author {
	position: relative;
    background-color: #13aff0;
    color: #fff;
    font-size: 20px;
    padding: 20px 30px;
    line-height: 1.6;
    z-index: 1;
}

.post-quote-icon {
    position: absolute;
    right: 20px;
    bottom: 10px;
    font-size: 48px;
    @include opacity( 0.2 );
    z-index: -1;

    svg.owp-icon {
        width: 45px;
        height: 45px;
    }
}

.post-quote-author {
    background-color: #0b7cac;
	font-size: 12px;
    font-weight: 600;
    padding: 10px 30px;
    margin-top: 1px;
    text-transform: uppercase;
    letter-spacing: 0.6px;
}

.single-post .post-quote-wrap {
	margin-bottom: 30px;
}