/* bbPress */
.bbpress .social-share-title,
.bbpress .social-share-buttons {
    display: none
}

#bbpress-forums hr {
    margin: 0 0 24px 0
}

#bbpress-forums {
    background: transparent;
    clear: both;
    margin-bottom: 20px;
    overflow: hidden;
    font-size: 12px
}

#bbpress-forums ul.bbp-lead-topic,
#bbpress-forums ul.bbp-topics,
#bbpress-forums ul.bbp-forums,
#bbpress-forums ul.bbp-search-results {
    border: 0;
}

body.reply-edit .reply {
    float: none
}

#bbpress-forums div.reply {
    height: auto;
    width: 100%
}

#bbpress-forums div.bbp-forum-header,
#bbpress-forums div.bbp-topic-header,
#bbpress-forums div.bbp-reply-header {
    background-color: #f4f4f4
}

#bbpress-forums .status-trash.even,
#bbpress-forums .status-spam.even {
    background-color: #fee
}

#bbpress-forums .status-trash.odd,
#bbpress-forums .status-spam.odd {
    background-color: #fdd
}

#bbpress-forums ul {
    background: 0;
    list-style: none;
    margin: 0;
    padding: 0
}

#bbpress-forums ul.bbp-threaded-replies {
    margin-left: 50px
}

#bbpress-forums li {
    background: 0;
    margin: 0;
    list-style: none
}

#bbpress-forums li.bbp-header,
#bbpress-forums li.bbp-body,
#bbpress-forums li.bbp-footer {
    clear: both
}

#bbpress-forums li.bbp-header,
#bbpress-forums li.bbp-footer {
    background: transparent;
}

#bbpress-forums li.bbp-header ul {
    overflow: hidden
}

.single-topic #bbpress-forums li.bbp-header,
.single-topic #bbpress-forums li.bbp-footer {
    background: #f9f9f9;
}

.single-topic #bbpress-forums li.bbp-header {
    border-bottom: 0
}

#bbpress-forums .bbp-forums-list {
    margin: 0 0 0 5px;
    padding-left: 15px;
    border-left: 1px solid #ddd
}

#bbpress-forums .bbp-forums-list li {
    display: inline;
    font-size: 11px
}

#bbpress-forums li.bbp-footer p {
    margin: 0;
    line-height: 1em
}

li.bbp-forum-info,
li.bbp-topic-title {
    float: left;
    text-align: left;
    width: 55%
}

li.bbp-forum-topic-count,
li.bbp-topic-voice-count,
li.bbp-forum-reply-count,
li.bbp-topic-reply-count {
    float: left;
    text-align: center;
    width: 10%
}

li.bbp-forum-freshness,
li.bbp-topic-freshness {
    text-align: right;
    float: left;
    width: 22%
}

li.bbp-header div.bbp-topic-content span#subscription-toggle,
li.bbp-header div.bbp-topic-content span#favorite-toggle,
li.bbp-header div.bbp-reply-content span#subscription-toggle,
li.bbp-header div.bbp-reply-content span#favorite-toggle {
    float: right
}

#bbpress-forums li .bbp-forum-title,
#bbpress-forums li .bbp-topic-permalink {
    margin-bottom: 9px;
    display: inline-block;
    font-weight: 500
}

#bbpress-forums ul.topic.sticky li.bbp-topic-title:before,
#bbpress-forums ul.topic.super-sticky li.bbp-topic-title:before {
    color: #ffa406;
    content: '\72';
}

#bbpress-forums ul.topic.resolved-topic li.bbp-topic-title:before {
    color: #169e59;
    content: '\52';
}

#bbpress-forums ul.topic.not-resolved-topic li.bbp-topic-title:before {
    color: #d31111;
    content: '\51';
}

#bbpress-forums li .bbp-topic-permalink {
    font-size: 13px;
    margin-bottom: 0 !important
}

#bbpress-forums div.bbp-forum-title h3,
#bbpress-forums div.bbp-topic-title h3,
#bbpress-forums div.bbp-reply-title h3 {
    background: 0;
    border: 0;
    font-size: 16px;
    line-height: 1em;
    margin: 8px 0;
    padding: 0;
    text-transform: none
}

#bbpress-forums div.bbp-forum-author,
#bbpress-forums div.bbp-topic-author,
#bbpress-forums div.bbp-reply-author {
    float: left;
    text-align: center;
    width: 115px
}

#bbpress-forums div.bbp-forum-author img.avatar,
#bbpress-forums div.bbp-topic-author img.avatar,
#bbpress-forums div.bbp-reply-author img.avatar {
    border: 0;
    max-width: 80px;
    padding: 0;
    margin: 12px auto 0 auto;
    float: none
}

#bbpress-forums div.bbp-forum-author a.bbp-author-name,
#bbpress-forums div.bbp-topic-author a.bbp-author-name,
#bbpress-forums div.bbp-reply-author a.bbp-author-name {
    margin: 0 12px;
    word-break: break-word;
    display: inline-block
}

#bbpress-forums div.bbp-topic-author a.bbp-author-name,
#bbpress-forums div.bbp-reply-author a.bbp-author-name {
    clear: left;
    display: block
}

#bbpress-forums div.bbp-forum-author .bbp-author-role,
#bbpress-forums div.bbp-topic-author .bbp-author-role,
#bbpress-forums div.bbp-reply-author .bbp-author-role {
    font-size: 11px;
    font-style: italic
}

#bbpress-forums li.bbp-header .bbp-search-author,
#bbpress-forums li.bbp-footer .bbp-search-author,
#bbpress-forums li.bbp-header .bbp-forum-author,
#bbpress-forums li.bbp-footer .bbp-forum-author,
#bbpress-forums li.bbp-header .bbp-topic-author,
#bbpress-forums li.bbp-footer .bbp-topic-author,
#bbpress-forums li.bbp-header .bbp-reply-author,
#bbpress-forums li.bbp-footer .bbp-reply-author {
    float: left;
    margin: 0;
    padding: 0;
    width: 120px
}

div.bbp-forum-header,
div.bbp-topic-header,
div.bbp-reply-header {
    border-top: 1px solid #ddd;
    clear: both
}

#bbpress-forums div.bbp-reply-to {
    margin-left: 130px;
    padding: 12px 12px 12px 0;
    text-align: right
}

#bbpress-forums div#bbp-cancel-reply-to {
    text-align: right
}

div.bbp-breadcrumb {
    display: block;
}

div.bbp-breadcrumb,
div.bbp-topic-tags {
    font-size: 12px
}

#bbp-topic-hot-tags {
    clear: both
}

#bbpress-forums #bbp-search-form {
    clear: left
}

#bbpress-forums #bbp-search-form .hidden {
    height: 0;
    width: 0;
    overflow: hidden;
    position: absolute;
    background: 0;
    left: -999em
}

#bbpress-forums #bbp-search-form #bbp_search {
    max-height: 50px;
    padding: 0 15px;
}

span.bbp-admin-links {
    float: right;
    color: #ddd
}

span.bbp-admin-links a {
    color: #bbb;
    font-weight: normal;
    font-size: 10px;
    text-transform: uppercase;
    text-decoration: none
}

fieldset span.bbp-admin-links {
    float: left
}

tr td span.bbp-admin-links a:hover {
    color: #ff4b33
}

td.bbp-topic-admin-links,
td.bbp-topic-counts {
    width: 50%
}

.bbp-forum-header a.bbp-forum-permalink,
.bbp-topic-header a.bbp-topic-permalink,
.bbp-reply-header a.bbp-reply-permalink {
    float: right;
    margin-left: 10px;
    color: #ccc
}

.bbp-row-actions #favorite-toggle a {
    text-decoration: none;
    padding: 0 3px 1px;
    color: #7c7;
    border: 1px solid #aca;
    background-color: #dfd;
    font-weight: bold;
    font-size: 13px
}

.bbp-row-actions #favorite-toggle a:hover {
    color: #5a5;
    border-color: #7c7;
    background-color: #beb
}

.bbp-row-actions #favorite-toggle span.is-favorite a {
    color: #faa;
    border: 1px solid #faa;
    background-color: #fee
}

.bbp-row-actions #favorite-toggle span.is-favorite a:hover {
    color: #c88;
    border-color: #c88;
    background-color: #fdd
}

.bbp-row-actions #subscription-toggle a {
    text-decoration: none;
    padding: 0 3px 1px;
    color: #7c7;
    border: 1px solid #aca;
    background-color: #dfd;
    font-weight: bold;
    font-size: 13px
}

.bbp-row-actions #subscription-toggle a:hover {
    color: #5a5;
    border-color: #7c7;
    background-color: #beb
}

.bbp-row-actions #subscription-toggle span.is-subscribed a {
    color: #faa;
    border: 1px solid #faa;
    background-color: #fee
}

.bbp-row-actions #subscription-toggle span.is-subscribed a:hover {
    color: #c88;
    border-color: #c88;
    background-color: #fdd
}

#bbpress-forums .bbp-forum-info .bbp-forum-content,
#bbpress-forums p.bbp-topic-meta {
    font-size: 11px;
    margin: 0;
    padding: 0;
    word-wrap: break-word
}

#bbpress-forums p.bbp-topic-meta {
    font-size: 11px;
    line-height: 30px;
    position: relative
}

#bbpress-forums p.bbp-topic-meta .freshness_link {
    display: block
}

#bbpress-forums p.bbp-topic-meta span {
    white-space: nowrap
}

.bbp-pagination-count {
    float: left;
    border: 1px solid transparent
}

.bbp-pagination-links {
    float: right;
    list-style: none;
    display: inline
}

.bbp-pagination-links a,
.bbp-pagination-links span.current {
    display: block;
    float: left;
    padding: 0 5px;
    margin-left: 5px;
    border: 1px solid #efefef;
    text-decoration: none
}

.bbp-pagination-links a:hover,
.bbp-pagination-links span.current {
    background: #eee;
    opacity: .8;
    border: 1px solid #ddd
}

.bbp-pagination-links span.dots {
    display: block;
    float: left;
    padding: 1px 4px;
    margin-left: 5px
}

.bbp-pagination {
    float: left;
    width: 100%;
    text-align: right;
    margin-top: 6px
}

.bbp-topic-pagination {
    display: inline-block;
    margin-left: 5px;
}

.bbp-topic-pagination a {
    font-size: 10px;
    line-height: 10px;
    padding: 1px 3px;
    border: 1px solid #ddd;
    text-decoration: none
}

#bbpress-forums fieldset.bbp-form {
    clear: left
}

#bbpress-forums fieldset.bbp-form {
    border: 1px solid #ddd;
    padding: 10px 20px;
    margin-bottom: 10px
}

#bbpress-forums fieldset.bbp-form legend {
    padding: 5px
}

#bbpress-forums fieldset.bbp-form label {
    margin: 0;
    display: inline-block
}

#bbp-edit-topic-tag.bbp-form fieldset.bbp-form label,
#bbp-login fieldset label,
#bbp-register fieldset label,
#bbp-lost-pass fieldset label {
    width: 100px
}

#bbpress-forums fieldset.bbp-form p,
#bbpress-forums fieldset.bbp-form textarea,
#bbpress-forums fieldset.bbp-form select,
#bbpress-forums fieldset.bbp-form input {
    margin: 0 0 8px
}

textarea#bbp_reply_content,
textarea#bbp_topic_content,
textarea#bbp_forum_content {
    width: 97%;
    box-sizing: border-box
}

textarea#bbp_forum_content {
    height: 210px
}

#bbpress-forums fieldset.bbp-forum-form-attributes {
    width: 200px;
    float: right;
    clear: none;
    margin-left: 25px
}

.bbp-topic-form,
.bbp-reply-form,
.bbp-topic-tag-form {
    clear: left
}

body.topic-edit .bbp-topic-form div.avatar img,
body.reply-edit .bbp-reply-form div.avatar img,
body.single-forum .bbp-topic-form div.avatar img,
body.single-reply .bbp-reply-form div.avatar img {
    margin-right: 0;
    padding: 10px;
    border: 1px solid #ddd;
    line-height: 0;
    background-color: #efefef
}

body.page .bbp-reply-form code,
body.page .bbp-topic-form code,
body.single-topic .bbp-reply-form code,
body.single-forum .bbp-topic-form code,
body.topic-edit .bbp-topic-form code,
body.reply-edit .bbp-reply-form code {
    font-size: 10px;
    background-color: #f0fff8;
    border: 1px solid #ceefe1;
    display: block;
    padding: 8px;
    margin-top: 5px;
    width: 369px
}

#merge_tag,
#delete_tag {
    display: inline
}

div.bbp-submit-wrapper {
    margin-top: 15px;
    float: right;
    clear: both
}

p.form-allowed-tags {
    max-width: 100%
}

#bbpress-forums div.bbp-the-content-wrapper {
    margin-bottom: 10px
}

#bbpress-forums div.bbp-the-content-wrapper textarea.bbp-the-content {
    width: 100%;
    margin: 0;
    font-size: 12px
}

#bbpress-forums div.bbp-the-content-wrapper table,
#bbpress-forums div.bbp-the-content-wrapper tbody,
#bbpress-forums div.bbp-the-content-wrapper tr,
#bbpress-forums div.bbp-the-content-wrapper td {
    border: 0;
    padding: 0;
    margin: 0;
    width: auto;
    line-height: 1em
}

#bbpress-forums div.bbp-the-content-wrapper input {
    font-size: 12px;
    padding: 5px;
    margin: 0 2px 0 0;
    line-height: 1em
}

#bbpress-forums div.bbp-the-content-wrapper div.quicktags-toolbar {
    padding: 5px;
    min-height: 26px
}

#bbpress-forums div.bbp-the-content-wrapper td.mceToolbar {
    padding: 4px 4px 8px
}

#bbpress-forums div.wp-editor-container {
    margin: 0;
    padding: 0;
    line-height: 0
}

#bbpress-forums div.bbp-the-content-wrapper td.mceStatusbar {
    line-height: 16px
}

#bbpress-forums #bbp-your-profile fieldset {
    padding: 20px 20px 0 20px
}

#bbpress-forums #bbp-your-profile fieldset div {
    margin-bottom: 20px;
    float: left;
    width: 100%;
    clear: left
}

#bbpress-forums #bbp-your-profile fieldset select {
    width: 60%;
}

#bbpress-forums #bbp-your-profile fieldset textarea {
    resize: vertical
}

#bbpress-forums #bbp-your-profile fieldset input,
#bbpress-forums #bbp-your-profile fieldset textarea {
    margin-bottom: 0;
    width: 60%;
    background: #f9f9f9;
    border: 1px solid #ddd;
    box-shadow: none;
    padding: 5px 8px;
    border-radius: 0
}

#bbpress-forums #bbp-your-profile fieldset input:focus,
#bbpress-forums #bbp-your-profile fieldset textarea:focus {
    border: 1px solid #ccc;
    box-shadow: inset 1px 1px 1px rgba(0, 0, 0, 0.1);
    outline-color: rgba(240, 255, 240, 0.1)
}

#bbpress-forums #bbp-your-profile fieldset.bbp-form input.checkbox {
    width: auto
}

#bbpress-forums #bbp-your-profile fieldset legend {
    display: none
}

#bbpress-forums #bbp-your-profile fieldset label[for] {
    float: left;
    width: 20%;
    padding: 5px 20px 5px 0;
    cursor: pointer
}

#bbpress-forums #bbp-your-profile fieldset dl label[for] {
    text-align: left;
    width: 60%
}

#bbpress-forums #bbp-your-profile fieldset fieldset {
    margin: 0;
    border: 0;
    padding: 0;
    clear: none;
    float: none
}

#bbpress-forums #bbp-your-profile fieldset fieldset.password {
    width: 60%;
    display: inline
}

#bbpress-forums #bbp-your-profile fieldset fieldset.password input {
    width: 100%
}

#bbpress-forums #bbp-your-profile fieldset fieldset.capabilities dl {
    margin: 0
}

#bbpress-forums #bbp-your-profile fieldset.submit button {
    float: right
}

.bbp-no-topic,
.bbp-no-reply {
    display: inline-block;
    width: 100%;
    margin-top: 15px;
}

div.bbp-template-notice,
div.indicator-hint {
    border-width: 1px;
    border-style: solid;
    padding: 0 .6em;
    margin: 5px 0 15px;
    border-radius: 3px;
    background-color: #ffffe0;
    border-color: #e6db55;
    color: #000;
    clear: both
}

div.bbp-template-notice a {
    color: #555;
    text-decoration: none
}

div.bbp-template-notice a:hover {
    color: #000
}

div.bbp-template-notice.info {
    border: #cee1ef 1px solid;
    background-color: #f0f8ff
}

div.bbp-template-notice.important {
    border: #e6db55 1px solid;
    background-color: #fffbcc
}

div.bbp-template-notice.error,
div.bbp-template-notice.warning {
    background-color: #ffebe8;
    border-color: #c00
}

div.bbp-template-notice.error a,
div.bbp-template-notice.warning a {
    color: #c00
}

div.bbp-template-notice p {
    margin: .5em 0 6px 0 !important;
    padding: 2px;
    font-size: 12px;
    line-height: 140%
}

.bbp-topics-front ul.super-sticky,
.bbp-topics ul.super-sticky,
.bbp-topics ul.sticky,
.bbp-forum-content ul.sticky {
    background-color: transparent !important;
}

#bbpress-forums .bbp-topic-content ul.bbp-topic-revision-log,
#bbpress-forums .bbp-reply-content ul.bbp-topic-revision-log,
#bbpress-forums .bbp-reply-content ul.bbp-reply-revision-log {
    border-top: 1px dotted #ddd;
    width: 100%;
    margin: 0;
    padding: 8px 0 0 0;
    font-size: 11px;
    color: #aaa
}

#bbpress-forums .bbp-topic-content ul.bbp-topic-revision-log li,
#bbpress-forums .bbp-reply-content ul.bbp-topic-revision-log li,
#bbpress-forums .bbp-reply-content ul.bbp-reply-revision-log li {
    list-style-type: none
}

.bbp-login-form fieldset legend {
    display: none
}

.bbp-login-form .bbp-username input,
.bbp-login-form .bbp-email input,
.bbp-login-form .bbp-password input {
    width: 100%;
    padding: 5px
}

#sidebar .bbp-login-form label {
    display: block
}

.bbp-login-form .bbp-username,
.bbp-login-form .bbp-email,
.bbp-login-form .bbp-password,
.bbp-login-form .bbp-remember-me,
.bbp-login-form .bbp-submit-wrapper {
    margin-top: 10px
}

.bbp-login-form .bbp-remember-me input[type="checkbox"] {
    position: relative;
    top: 2px
}

.bbp-login-form .bbp-submit-wrapper {
    text-align: right
}

.bbp-login-form .bbp-login-links a {
    float: left;
    clear: left
}

.bbp-logged-in img.avatar {
    float: left;
    margin: 0 20px 0 0
}

.bbp-logged-in h4 {
    font-weight: bold;
    font-size: 1.3em;
    clear: none;
    margin-bottom: 10px
}

#bbpress-forums p.bbp-topic-meta img.avatar,
#bbpress-forums ul.bbp-reply-revision-log img.avatar,
#bbpress-forums ul.bbp-topic-revision-log img.avatar,
#bbpress-forums div.bbp-template-notice img.avatar,
#bbpress-forums .widget_display_topics img.avatar,
#bbpress-forums .widget_display_replies img.avatar {
    margin-right: 6px;
    margin-bottom: 0;
}

fieldset div.avatar {
    float: right
}

.activity-list li.bbp_topic_create .activity-content .activity-inner,
.activity-list li.bbp_reply_create .activity-content .activity-inner {
    border-left: 2px solid #eaeaea;
    margin-left: 5px;
    padding-left: 10px
}

#bbpress-forums h1 {
    clear: none;
    font-size: 1.8em;
    line-height: 1em;
    padding-bottom: 10px
}

#bbpress-forums #bbp-user-wrapper h2.entry-title,
#bbpress-forums #bbp-user-wrapper h3 {
    font-size: 1.4em;
    margin: 0;
    padding-bottom: 10px;
    padding-top: 0;
    margin: 0 0 20px;
    clear: none
}

#bbpress-forums #bbp-user-wrapper ul.bbp-topics {
    clear: both;
}

#bbpress-forums #bbp-single-user-details {
    margin: 0;
    width: 150px;
    float: left;
    overflow: hidden
}

#bbpress-forums #bbp-single-user-details #bbp-user-avatar {
    margin: 0;
    width: 150px
}

#bbpress-forums #bbp-single-user-details #bbp-user-avatar img.avatar {
    border: 0;
    height: 150px;
    padding: 0;
    margin: 0 0 20px 0;
    width: 150px
}

#bbpress-forums #bbp-single-user-details #bbp-user-description {
    float: none;
    margin-left: 180px
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation {
    float: none;
    margin: 0
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation li {
    float: left;
    width: 40%;
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation a {
    padding: 5px 8px;
    display: block;
    border: 1px solid transparent;
    text-decoration: none
}

#bbpress-forums #bbp-user-body {
    margin-left: 180px
}

body.my-account #bbpress-forums {
    border-top: 0;
    padding-top: 0;
    margin-bottom: 0
}

#bbpress-forums dl.bbp-user-capabilities {
    display: inline-block;
    vertical-align: top
}

#bbpress-forums dl.bbp-user-capabilities dt {
    margin: 0 0 10px;
    text-transform: capitalize
}

#bbpress-forums dl.bbp-user-capabilities dd {
    margin: 0;
    padding: 0
}

#bbpress-forums div.row-actions {
    font-size: 11px;
    visibility: hidden
}

#bbpress-forums li:hover>div.row-actions {
    visibility: visible
}

@media only screen and (max-width:480px) {
    #bbpress-forums li {
        font-size: 12px;
    }
    #bbpress-forums li.bbp-body ul.forum .bbp-forum-topic-count,
    #bbpress-forums li.bbp-body ul.topic .bbp-forum-topic-count,
    #bbpress-forums li.bbp-header ul .bbp-forum-topic-count {
        width: 20%!important
    }
    div.bbp-search-form input,
    div.bbp-search-form button {
        font-size: 11px;
        padding: 2px
    }
    li.bbp-forum-info,
    li.bbp-topic-title,
    #bbpress-forums li.bbp-topic-freshness {
        width: 35%!important;
    }
    li.bbp-forum-topic-count,
    li.bbp-forum-reply-count,
    li.bbp-topic-voice-count,
    li.bbp-topic-reply-count {
        width: 15%
    }
    #bbpress-forums li.single-forum-info .bbp-forum-title,
    #bbpress-forums li.single-forum-info .bbp-topic-permalink {
        margin-left: 0;
    }
    #bbpress-forums li.single-forum-info {
        padding-left: 0;
    }
    span.bbp-reply-post-date {
        float: left
    }
    span.bbp-admin-links {
        clear: left;
        float: left
    }
    #bbpress-forums .bbp-forums-list li {
        display: block;
        font-size: 11px
    }
    #bbpress-forums .bbp-body div.bbp-reply-author {
        min-height: 100px;
        padding-left: 80px;
        position: relative;
        text-align: left;
        width: 100%;
        margin-bottom: 15px;
    }
    #bbpress-forums div.bbp-reply-author a.bbp-author-name {
        word-wrap: break-word
    }
    #bbpress-forums div.bbp-reply-author img.avatar {
        position: absolute;
        top: 15px;
        left: 0;
        width: 60px;
        height: auto
    }
    #bbpress-forums div.bbp-reply-author .bbp-author-role {
        font-size: 12px;
        font-style: normal
    }
    #bbpress-forums .bbp-body div.bbp-reply-content {
        clear: both;
        margin: 10px;
        padding: 0
    }
    #bbpress-forums fieldset.bbp-form {
        padding: 0 10px 10px
    }
    #bbpress-forums #bbp-user-body {
        clear: both;
        margin-left: 0;
        word-wrap: break-word
    }
    #bbpress-forums #bbp-single-user-details #bbp-user-avatar {
        float: none!important;
        width: 100%!important;
        text-align: center;
    }
    #bbpress-forums #bbp-single-user-details #bbp-user-navigation {
        margin-left: 0!important;
    }
    #bbpress-forums #bbp-your-profile fieldset {
        padding: 0!important;
    }
    #bbpress-forums #bbp-your-profile fieldset label[for],
    #bbpress-forums #bbp-your-profile fieldset input,
    #bbpress-forums #bbp-your-profile fieldset textarea {
        width: 100%!important;
    }
    #bbpress-forums #bbp-your-profile fieldset label[for] {
        float: none!important;
    }
}

@media only screen and (max-width:320px) {
    #bbpress-forums div.bbp-search-form {
        margin-bottom: 10px
    }
    #bbpress-forums li.bbp-header li.bbp-forum-topic-count,
    #bbpress-forums li.bbp-header li.bbp-forum-reply-count,
    #bbpress-forums li.bbp-body li.bbp-forum-topic-count,
    #bbpress-forums li.bbp-body li.bbp-forum-reply-count,
    #bbpress-forums li.bbp-header li.bbp-topic-voice-count,
    #bbpress-forums li.bbp-header li.bbp-topic-reply-count,
    #bbpress-forums li.bbp-body li.bbp-topic-voice-count,
    #bbpress-forums li.bbp-body li.bbp-topic-reply-count {
        width: 20%!important
    }
    #bbpress-forums li.bbp-body li.bbp-forum-topic-count,
    #bbpress-forums li.bbp-body li.bbp-forum-reply-count,
    #bbpress-forums li.bbp-body li.bbp-forum-freshness,
    #bbpress-forums li.bbp-body li.bbp-topic-voice-count,
    #bbpress-forums li.bbp-body li.bbp-topic-reply-count,
    #bbpress-forums li.bbp-body li.bbp-topic-freshness {
        margin-top: 7px
    }
    #bbpress-forums li.bbp-header,
    #bbpress-forums li.bbp-footer {
        font-size: 10px
    }
    #bbpress-forums li.bbp-header div.bbp-reply-author {
        text-align: left;
        width: 25%
    }
    #bbpress-forums li.bbp-header div.bbp-reply-content {
        margin-left: 25%
    }
    #bbpress-forums div.bbp-template-notice img.avatar,
    #bbpress-forums p.bbp-topic-meta img.avatar {
        width: 14px;
        height: auto
    }
    #bbpress-forums div.bbp-the-content-wrapper td.mceToolbar {
        padding: 1px
    }
    #bbpress-forums div.bbp-the-content-wrapper td.mceToolbar td {
        width: 20px;
        height: 20px
    }
    #bbpress-forums div.wp-editor-container {
        width: 100%;
        overflow: auto
    }
    #bbpress-forums input#bbp_topic_title,
    #bbpress-forums input#bbp_topic_tags {
        width: 95%
    }
}

@media only screen and (max-width:240px) {
    #bbpress-forums li.bbp-header ul .bbp-forum-topic-count,
    #bbpress-forums li.bbp-body ul.forum .bbp-forum-topic-count,
    #bbpress-forums li.bbp-topic-voice-count {
        display: none;
    }
    #bbpress-forums li.bbp-header ul .bbp-forum-info,
    #bbpress-forums li.bbp-body ul.forum .bbp-forum-freshness,
    #bbpress-forums li.bbp-body ul.topic .bbp-forum-freshness,
    #bbpress-forums li.bbp-header ul .bbp-forum-freshness,
    li.bbp-topic-title,
    #bbpress-forums li.bbp-topic-freshness {
        width: 40%!important;
    }
    #bbpress-forums li.bbp-header li.bbp-forum-topic-count,
    #bbpress-forums li.bbp-header li.bbp-forum-reply-count,
    #bbpress-forums li.bbp-body li.bbp-forum-topic-count,
    #bbpress-forums li.bbp-body li.bbp-forum-reply-count,
    #bbpress-forums li.bbp-header li.bbp-topic-reply-count,
    #bbpress-forums li.bbp-body li.bbp-topic-reply-count {
        width: 20%!important
    }
    #bbpress-forums li.bbp-footer div.bbp-reply-author,
    #bbpress-forums li.bbp-footer div.bbp-reply-content {
        width: 45%
    }
    #bbpress-forums li.bbp-header div.bbp-reply-author,
    #bbpress-forums li.bbp-header div.bbp-reply-content {
        clear: both;
        width: 100%
    }
    #bbpress-forums li.bbp-header div.bbp-reply-content {
        margin-left: 0;
        text-align: left
    }
    #bbpress-forums li.bbp-body li.bbp-topic-freshness p.bbp-topic-meta {
        display: inline-block
    }
    #bbpress-forums li.bbp-header {
        overflow: hidden
    }
    #bbpress-forums li.bbp-footer div.bbp-reply-content {
        display: inline-block;
        margin-left: 0
    }
    #bbpress-forums li.bbp-body div.bbp-reply-author {
        min-height: 60px;
        padding-left: 60px
    }
    #bbpress-forums div.bbp-reply-author img.avatar {
        width: 40px;
        height: auto
    }
}

#bbpress-forums {
    overflow: visible
}

#bbpress-forums .wp-editor-container,
#wp-bbp_topic_content-editor-container,
#wp-bbp_reply_content-editor-container {
    border: 1px solid #d2d2d2
}

#bbpress-forums div.bbp-search-form {
    float: none;
    margin-bottom: 40px;
    text-align: right;
}

#bbpress-forums form.bbp-search-form {
    display: inline-block;
    -webkit-border-radius: 22px;
    -moz-border-radius: 22px;
    border-radius: 22px;
    border: 1px solid #e4e4e4;
    height: 35px;
    line-height: 35px;
    padding: 0 10px;
    min-width: 420px;
    text-align: left;
    -webkit-box-shadow: 0 0 0 4px #f3f3f3;
    -moz-box-shadow: 0 0 0 4px #f3f3f3;
    box-shadow: 0 0 0 4px #f3f3f3;
}

#bbpress-forums .bbp-search-form .hidden {
    height: 0;
    width: 0;
    overflow: hidden;
    position: absolute;
    background: 0;
    left: -999em
}

.bbp-search-form .search-table {
    display: table;
    width: 100%
}

.bbp-search-form .search-field,
.bbp-search-form .search-button {
    display: table-cell;
    vertical-align: top;
}

.bbp-search-form .search-field {
    vertical-align: top
}

.bbp-search-form .search-field #bbp_search {
    width: 100%;
}

#bbpress-forums .bbp-search-form .search-field #bbp_search {
    float: left;
    width: 100%;
    height: 33px;
    min-height: 100%;
    padding: 0 10px;
    background: transparent;
    border: none;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    min-width: 420px;
    -webkit-transition: .7s;
    -moz-transition: .7s;
    -o-transition: .7s;
    transition: .7s;
}

#bbpress-forums .bbp-search-form .search-field #bbp_search:focus {
    min-width: 530px;
}

.bbp-search-form input {
    display: inline-block
}

.bbp-search-form input[type="submit"] {
    float: right;
    width: 100%;
    height: 40px;
    line-height: 40px;
    font-size: 14px;
    border: none;
    margin: 0;
    padding: 0 10px;
    margin-bottom: 20px;
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    display: inline-block;
    cursor: pointer;
    text-indent: 0;
    font-family: 'Font Awesome 5 Free';
    font-weight: 600;
}

#bbpress-forums .bbp-search-form input[type="submit"] {
    width: 150px;
    margin-left: 12px;
    margin-bottom: 0;
}

#bbpress-forums .wp-core-ui input[type="button"] {
    background: #fff;
    font-weight: 400;
    text-transform: none;
}

#bbpress-forums .wp-core-ui input[type="button"]:hover {
    background: #fafafa;
    border-color: #999;
    color: #222
}

#bbpress-forums .custom_select_box .dd-container .dd-selected {
    padding: 0 15px 0 0 !important;
    text-indent: 5px
}

#bbpress-forums .custom_select_box .dd-options li a:hover {
    background: #eee !important
}

#bbpress-forums li.bbp-header {
    border-top: 0;
    background: 0;
    border-bottom: 2px solid #c9c9c9
}

#bbpress-forums li.bbp-header ul {
    font-size: 15px
}

#bbpress-forums li.bbp-body ul.forum,
#bbpress-forums li.bbp-body ul.topic {
    border-bottom: 1px solid #eee;
    padding: 15px 0;
    overflow: hidden
}

#bbpress-forums li.bbp-body ul.forum .bbp-forum-info,
#bbpress-forums li.bbp-body ul.topic .bbp-forum-info,
#bbpress-forums li.bbp-header ul .bbp-forum-info {
    width: 45%
}

#bbpress-forums li.bbp-body ul.forum .bbp-forum-topic-count,
#bbpress-forums li.bbp-body ul.topic .bbp-forum-topic-count,
#bbpress-forums li.bbp-header ul .bbp-forum-topic-count {
    width: 13%
}

#bbpress-forums li.bbp-body ul.forum .bbp-forum-reply-count,
#bbpress-forums li.bbp-body ul.topic .bbp-forum-reply-count,
#bbpress-forums li.bbp-header ul .bbp-forum-reply-count {
    width: 13%
}

#bbpress-forums li.bbp-body ul.forum .bbp-forum-freshness,
#bbpress-forums li.bbp-body ul.topic .bbp-forum-freshness,
#bbpress-forums li.bbp-header ul .bbp-forum-freshness {
    width: 29%
}

#bbpress-forums li.bbp-topic-freshness {
    width: 25%
}

#bbpress-forums div.odd,
#bbpress-forums ul.odd,
#bbpress-forums div.even,
#bbpress-forums ul.even {
    background: transparent
}

.single-topic #bbpress-forums div.odd,
.single-topic #bbpress-forums ul.odd {
    background-color: #fbfbfb;
}

.bbp-topic-freshness>a,
.bbp-forum-freshness>a {
    font-size: 12px;
    line-height: 7px
}

#bbpress-forums fieldset.bbp-form textarea,
#bbpress-forums fieldset.bbp-form select,
#bbpress-forums fieldset.bbp-form input {
    margin: 0
}

#bbpress-forums fieldset.bbp-form input[type="checkbox"] {
    margin: 0 5px 4px 0
}

#bbpress-forums fieldset.bbp-form p {
    margin-bottom: 16px
}

#bbpress-forums fieldset.bbp-form {
    border: 0;
    padding: 0
}

#bbpress-forums fieldset.bbp-form legend {
    padding: 0;
    padding-bottom: 10px;
    margin-bottom: 20px;
    font-size: 15px;
    font-weight: bold
}

#bbpress-forums fieldset.bbp-form label {
    font-size: 13px;
    margin-bottom: 5px
}

.bbp-topic-form input#bbp_topic_title,
.bbp-topic-form input#bbp_topic_tags,
.bbp-topic-form select#bbp_stick_topic_select,
.bbp-topic-form select#bbp_topic_status_select {
    font-size: 13px;
    padding: 8px 2%;
    width: 100%
}

.bbp-topic-form select#bbp_stick_topic_select,
.bbp-topic-form select#bbp_topic_status_select {
    padding-right: 0
}

.bbp-submit-wrapper button {
    cursor: pointer
}

#bbpress-forums .topic-checkboxes {
    float: left;
    width: 50%;
    margin-top: 30px;
}

#bbpress-forums .bbp-form .bbp-template-notice {
    display: none;
}

#bbpress-forums fieldset.bbp-form p.bbp-attachments-form {
    float: right;
    width: 50%;
    margin-top: 30px;
}

#bbpress-forums fieldset.bbp-form p.bbp-attachments-form input[type='file'] {
    margin: 10px 0;
}

#bbpress-forums ul.bbp-replies {
    margin-bottom: 0
}

.topic-meta-wrap {
    display: inline-block;
    width: 100%
}

.topic-meta-wrap .topic-meta {
    float: left;
}

.bbp-header-single {
    display: inline-block;
    margin-left: 10px;
}

#bbpress-forums div.bbp-reply-favs {
    display: inline-block;
    font-size: 13px;
    font-weight: 600;
    vertical-align: bottom;
}

.top_pagination {
    float: right;
}

.top_pagination .bbp-pagination-count {
    display: none;
}

#bbpress-forums ul.bbp-replies {
    margin-top: 30px;
}

#bbpress-forums div.bbp-reply-author img.avatar {
    margin-top: 0
}

#bbpress-forums div.bbp-reply-author {
    font-size: 13px
}

#bbpress-forums div.bbp-reply-author a.bbp-author-name {
    margin: 10px 0 0 0
}

#bbpress-forums div.bbp-reply-author .bbp-author-role {
    font-size: 13px;
    font-style: normal;
    margin-bottom: 10px
}

#bbpress-forums div.bbp-reply-author .bbp-reply-post-date {
    padding: 12px 0;
    border-top: 1px solid #ddd;
    border-bottom: 1px solid #ddd;
    margin-bottom: 10px
}

#bbpress-forums div.bbp-reply-header {
    background: #f5f5f5;
    font-size: 12px;
    border-top: 0;
    clear: none;
    border-bottom: 1px solid #ddd
}

.bbp-reply-header a.bbp-reply-permalink {
    padding-left: 2px !important;
    font-size: 12px
}

span.bbp-admin-links a,
span.bbp-admin-links {
    font-size: 11px
}

span.bbp-admin-links a {
    padding: 0 2px !important
}

#bbpress-forums .bbp-reply-form fieldset label {
    font-size: 13px;
    margin-bottom: 5px
}

.bbp-reply-form input#bbp_topic_tags {
    font-size: 13px;
    padding: 8px 2%;
    width: 100%
}

#bbpress-forums input#bbp_reply_move_destination_title,
#bbpress-forums input#bbp_topic_split_destination_title,
#bbpress-forums input#bbp_topic_edit_reason,
#bbpress-forums input#bbp_reply_edit_reason {
    font-size: 13px;
    padding: 8px 2%;
    width: 100%
}

a.bbp-author-avatar,
#bbpress-forums div.bbp-reply-author a.bbp-author-name,
#bbpress-forums div.bbp-reply-author .bbp-author-role,
#bbpress-forums div.bbp-reply-author .bbp-reply-post-date,
#bbpress-forums div.bbp-reply-author .bbps-post-count,
#bbpress-forums div.bbp-reply-author .bbp-reply-ip {
    text-align: center;
}

#bbpress-forums #bbp-single-user-details {
    float: none!important;
    width: auto;
    padding-bottom: 30px;
    border-bottom: 1px solid #ddd;
    margin-bottom: 30px
}

#bbpress-forums #bbp-single-user-details #bbp-user-avatar {
    float: left;
    width: 100px
}

#bbpress-forums #bbp-single-user-details #bbp-user-avatar img.avatar {
    width: 100px;
    height: 100px
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation {
    margin-left: 130px
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation .first-col {
    float: left;
    width: 40%
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation .second-col {
    margin-left: 45%;
    width: 40%
}

#bbpress-forums #bbp-user-body {
    margin-left: 0!important;
    margin-right: 0!important;
}

#bbpress-forums .bbp-user-section .bold {
    font-weight: bold
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation li.current a {
    background: #eee;
    opacity: 1
}

.bbp-user-section .bbp-pagination {
    text-align: left
}

.bbp-user-section .pagination {
    float: none
}

#bbpress-forums .pagination {
    display: inline-block;
}

.bbp-topic-pagination .page-numbers:after {
    display: none
}

.bbp-topic-pagination .current {
    border: 1px solid #a0ce4e;
    display: inline-block;
    height: 15px;
    line-height: 15px;
    color: #fff;
    padding: 0 5px;
    margin-left: 5px;
    background: #a0ce4e
}

.bbp-topic-pagination .prev {
    margin-right: 8px;
    font-size: 12px
}

.bbp-topic-pagination .next {
    margin-left: 8px;
    font-size: 12px
}

#bbpress-forums .status-trash.odd,
#bbpress-forums .status-spam.odd {
    background-color: transparent
}

#bbpress-forums .status-trash.odd .bbp-reply-content,
#bbpress-forums .status-spam.odd .bbp-reply-content {
    background-color: #fdd
}

#bbpress-forums .status-trash.odd .bbp-arrow,
#bbpress-forums .status-spam.odd .bbp-arrow {
    background-color: #fdd
}

div.bbp-template-notice,
div.indicator-hint {
    background: #f6f6f6;
    border: 1px solid #ddd;
    padding: 8px 20px
}

.bbp-forum {
    font-size: 13px
}

.bbp-forum-title .bbp-forum-post-date {
    float: right
}

.bbp-forum-search a.bbp-reply-permalink {
    margin-left: 0
}

#bbpress-forums .bbp-forum-search div.bbp-reply-content {
    margin: 0
}

.bbp-topic-title-meta {
    float: right
}

#bbpress-forums ul.bbp-search-results {
    border: 0
}

.bbp-reply-to {
    float: right
}