.customize-control-oceanwp-multiple-select .select2-container--default .select2-selection--multiple { border: 1px solid rgba(0,0,0,.05); padding: 1px 0 0; border-radius: 0; line-height: 1; }
.customize-control-oceanwp-multiple-select .select2-container--default.select2-container--focus .select2-selection--multiple { border-color: rgba(0,0,0,0.08); }
.customize-control-oceanwp-multiple-select .select2-container--default .select2-selection--multiple .select2-selection__rendered { padding: 0; }
.customize-control-oceanwp-multiple-select .select2-container--default .select2-selection--multiple .select2-selection__choice { background-color: #f1f1f1; color: #666; border: rgba(0,0,0,0.06); line-height: 1.5; padding: 0 6px; border-radius: 0; margin: 7px 0 0 6px; }
.customize-control-oceanwp-multiple-select .select2-container--default .select2-selection--multiple .select2-search { line-height: 1.5; margin: 0 0 0 6px; }
.customize-control-oceanwp-multiple-select .select2-container--default .select2-search--inline .select2-search__field { margin: 0; }

/* RTL */
body.rtl .customize-control-oceanwp-multiple-select .select2-container--default .select2-selection--multiple .select2-selection__choice { margin: 5px 6px 0 0; }
body.rtl .customize-control-oceanwp-multiple-select .select2-container--default .select2-selection--multiple .select2-search { margin: 0 6px 0 0; }
