.has-blog-grid {
	.blog-grid {
		display: -webkit-box;
		display: -ms-flexbox;
		display: flex;
		-webkit-flex-wrap: wrap;
		flex-wrap: wrap;
		margin: 0 auto;
		height: auto!important;
	}
}

.blog-entry.grid-entry {
	justify-content: flex-start;

	.blog-entry-inner {
		padding: 0 1.25rem 1.25rem;
		border: 1px solid $color-7;
	}

	.thumbnail {
		margin: 0 -1.25rem;
	}

	.blog-entry-header {
		margin: 1rem 0 1rem;

		.entry-title {
			font-size: 18px;
		}
	}

	.blog-entry-summary {
		line-height: 1.6;
		margin-top: 0.625rem;
	}

	.blog-entry-readmore {
		margin-top: 1rem;

		a {
			display: inline-block;
		    font-size: 12px;
		    line-height: 1.2;
		    padding-bottom: 0.19rem;
		    border-bottom: 1px solid;
		    text-transform: capitalize;

		    i {
		    	margin-left: 0.5rem;
		    }

			svg.owp-icon {
				margin-left: 0.7rem;
			}
		}
	}
}