.customize-control-oceanwp-iconmulti { display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-flex-wrap: wrap; flex-wrap: wrap; border: 1px solid #ddd; max-height: 216px; }
.customize-control-oceanwp-iconmulti label { display: -webkit-box; display: -ms-flexbox; display: flex; width: 20%; -webkit-box-sizing: border-box; -moz-box-sizing: border-box; box-sizing: border-box; }
.customize-control-oceanwp-iconmulti .icon-select-input { display: none; }
.customize-control-oceanwp-iconmulti .icon-select-label { display: block; width: 100%; background-color: #f5f5f5; color: #555; border: 1px solid #ddd; margin: 0; font-size: 16px; height: 53px; line-height: 53px; text-align: center; transition: all .3s ease; -webkit-transition: all .3s ease; -moz-transition: all .3s ease; -o-transition: all .3s ease; -ms-transition: all .3s ease; }
.customize-control-oceanwp-iconmulti .icon-select-label:hover,
.customize-control-oceanwp-iconmulti .icon-select-input:checked + .icon-select-label { background-color: #3498DB; color: #fff; border-color: #3498DB; }

.customize-control-oceanwp-iconmulti svg.icon-select-label {
	width: 20px;
    height: 20px;
    margin: 0 auto;
    padding: 18px;
	stroke: #333;
}

.customize-control-oceanwp-iconmulti svg.icon-select-label:hover use,
.customize-control-oceanwp-iconmulti .icon-select-input:checked + svg.icon-select-label use {
	stroke: #fff;
}

#owp-svg-icons path,
#owp-svg-icons rect,
#owp-svg-icons circle,
#owp-svg-icons line,
#owp-svg-icons polygon,
#owp-svg-icons polyline {
    stroke: inherit;
}