/*------------------------------------------------------------------
Woo Quantity Buttons
-------------------------------------------------------------------*/
.quantity {
	position: relative;
	float: left;
	overflow: hidden;
	zoom: 1;
	min-width: 110px;

	.qty,
	.minus,
	.plus {
		display: block;
		float: left;
		width: 36px;
		min-height: 36px;
		background-color: transparent;
		border: 1px solid #e4e4e4;
		margin: 0;
		padding: 0;
		text-align: center;
		vertical-align: middle;
		font-size: 12px;
		color: #777;
		-moz-appearance: textfield; /* hack firefox */
		-webkit-appearance: none;
		@include border-radius(0);
	}

	.minus,
	.plus {
		font-size: 13px;
		line-height: 34px;
	}

	.minus {
		border-right-width: 0;
	}

	.plus {
		border-left-width: 0;
	}

	input::-webkit-outer-spin-button {
		display: none;
	}

	input::-webkit-inner-spin-button {
		display: none;
	}

}

.woocommerce form input[type="number"] {
	max-width: 58px;
	min-height: 36px;
}

.woocommerce form input.qty[type="number"]{
	-moz-appearance: textfield; /* hack firefox */
}