/**
 * Single Post Next Prev
 */
.single nav.post-navigation {
	margin-top: 30px;
    padding-top: 30px;
    border-top: 1px solid $color-9;

    &:after {
	    content: '';
	    display: block;
	    visibility: hidden;
	    clear: both;
	    zoom: 1;
	    height: 0;
	}

    .nav-links {
    	.title {
		    display: block;
		    color: $color-5;
		    line-height: 20px;
		}

		a {
			display: block;
		}

	    i {
	    	font-size: 20px;
	    	line-height: 20px;
	    }

	    .post-title {
	    	display: block;
	    	font-size: 16px;
	    	margin: 5px 0 0;
	    }
    }

	.nav-previous {
	    float: left;
	    width: 50%;
	    text-align: left;
	    border-right-width: 1px;
	    border-style: solid;
	    border-color: $color-9;
	    padding-right: 20px;

	    i,
		.owp-icon {
	    	float: left;
			margin-right: 20px;
	    }

		.owp-icon {
			margin-top: 4px;
		}
	}

	.nav-next {
	    float: right;
	    width: 50%;
	    text-align: right;
	    padding-left: 20px;

	    i,
		.owp-icon {
	    	float: right;
			margin-left: 20px;
	    }

		.owp-icon {
			margin-top: 4px;
		}

	}
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
	
	.single nav.post-navigation .nav-links {
		.nav-previous,
		.nav-next {
			float: none;
			width: 100%;
			padding: 0;
		}

		.nav-previous {
			border-right-width: 0;
			border-left-width: 0;
		}
	}

}