/* Fix for the tabs under the header in the edit mode */
.fl-builder-edit #site-header,
.fl-builder-edit.has-transparent-header #site-header,
.elementor-editor-active #site-header { z-index: 1; }
.fl-builder-edit #main,
.elementor-editor-active #main { z-index: inherit !important; }

/* Fix the height automatically in the custom header style */
#site-header .elementor-section-wrap {
    height: auto !important;
}

/* Fix image alignment with caption issue */
.elementor-widget-image .elementor-image img {
    display: inline-block;
}

/* Fix carousel next/prev bug in Elementor */
.elementor-slick-slider .slick-prev,
.elementor-slick-slider .slick-next {
    height: auto;
}

/* Fix background hover color on the photoswipe buttons */
.pswp__button:hover {
    background-color: transparent;
}

/* Fix bug with MotoPress */
div.motopress-bootstrap-dropdown .dropdown-menu {
	display: block !important;
	position: static !important;
}

/* Fix problem with Geolocation addon of Caldera form in the Ocean Modal Window */
.pac-container {
    z-index: 100003;
}

/* Remove the Elementor section min height if the no-height class is added */
.no-height .elementor-column {
    min-height: 0;
}

/* WooCommerce issues with Elementor Pro */
body .elementor-element.elementor-wc-products ul.products li.product .onsale {
    padding: 8px 12px;
}

body .elementor-element.elementor-wc-products ul.products li.product.circle-sale .onsale {
    padding: 0;
}

@media only screen and (max-width: 959px) {
    .elementor-element.elementor-wc-products ul.products li.product {
        width: auto !important;
    }
}

/* Fix parallax footer issue in the Elementor editor */
.elementor-editor-active .parallax-footer { z-index: -1; }

/* Fix checkbox issue in Elementor */
.elementor-field-type-acceptance .elementor-field-subgroup .elementor-field-option input[type="checkbox"] {
    display: inline-block;
}