/**
 * Scroll top
 */
#scroll-top {
    display: none;
    opacity: 0;
    position: fixed;
    right: 20px;
    bottom: 20px;
    width: 40px;
    height: 40px;
    line-height: 40px;
    background-color: rgba(0, 0, 0, 0.4);
    color: $color-1;
    font-size: 18px;
    cursor: pointer;
    @include border-radius(2px);
    text-align: center;
    z-index: 100;
    @include box-sizing(content-box);

    > span {
        line-height: inherit;
        vertical-align: top;
    }

    &:hover {
        background-color: rgba(0, 0, 0, 0.8);
    }

    &.scroll-top-left {
        left: 20px;
        right: auto;
    }

    .owp-icon {
        vertical-align: initial;

        use {
            stroke: $color-1;
        }
    }
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
    #scroll-top {
        right: 10px;
        bottom: 10px;
        width: 26px;
        height: 26px;
        line-height: 24px;
        font-size: 14px;
    }
}
