/**
 * Link Format
 */
.link-entry {
    position: absolute;
    top: 20px;
    right: 20px;

	i {
		display: inline-block;
	    width: 60px;
	    height: 60px;
	    font-size: 22px;
	    line-height: 60px;
	    background-color: $color-2;
	    color: $color-1;
	    text-align: center;
		@include border-radius( 50% );
	    @include transition( all .3s ease );
	}

}

.thumbnail:hover i {
    background-color: $color-5;
}

.link-post-svg-icon {
	width: 60px;
    height: 60px;
    border-radius: 50%;
    background-color: #333;
    text-align: center;
    padding-top: 18px;

	.owp-icon {
		width: 22px;
		height: 22px;

		use {
			stroke: #fff;
		}
	}
}