.post-pagination-wrap {
    position: fixed;
    top: 30%;
    left: 50px;

    .post-pagination {
        margin: 0;

        li a {
            display: inline-block;
            height: 50px;
            width: 50px;
            line-height: 46px;
            font-size: 20px;
            color: $color-11;
            border: 2px solid $color-9;
            @include border-radius( 50% );
            text-align: center;
            z-index: 100;

            &:hover {
                color: $color-5;
                border-color: $color-5;
            }
        }

        li:last-child {
            margin-top: 12px;
        }
    }
}