/**
 * Single Post Author bio
 */
#author-bio {
	position: relative;
	margin-top: 30px;
	padding-top: 30px;
	border-top-width: 1px;
	border-style: solid;
	border-color: $color-9;

	#author-bio-inner {
		@include display();
	}

	.author-bio-avatar,
	.author-bio-avatar img {
	    @include border-radius( 50% );
	}

	.author-bio-avatar {
	    min-width: 80px;
    	margin-right: 30px;

		img {
		    width: 80px;
			height: 80px;
			border: 3px solid $border-color;
		}
	}

	.author-bio-content {
	    position: relative;
	}

	.author-bio-title {
		display: inline-block;
	    font-size: 18px;
	    margin: 0 0 10px;
	    text-transform: capitalize;
	}

	.author-bio-description p:last-child {
	    margin: 0;
	}
}

.author #author-bio {
	margin: 0 0 30px;
    padding-bottom: 30px;
    border-bottom-width: 1px;
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {

	#author-bio .author-bio-avatar {
		display: none;
	}

}