/* WooCommerce Sensei */
.oceanwp-sensei header {
    margin: 0 0 20px;
}
    
.oceanwp-sensei .course-lessons article {
    margin: 0 0 50px;
}

.oceanwp-sensei .post-entries {
    display: inline-block;
    width: 100%;
}

.single-lesson .oceanwp-sensei .post-entries {
    margin-top: 30px;
}