@charset "UTF-8";
.editor-post-title__block .editor-post-title__input {
  font-size: 2rem;
  font-weight: 600;
}

.block-editor-block-list__layout {
  font-size: 14px;
  line-height: 1.8;
  color: #4a4a4a;
  overflow-wrap: break-word;
  word-wrap: break-word;
}

.block-editor-block-list__layout h1,
.block-editor-block-list__layout h2,
.block-editor-block-list__layout h3,
.block-editor-block-list__layout h4,
.block-editor-block-list__layout h5,
.block-editor-block-list__layout h6 {
  font-weight: 600;
  color: #333;
  line-height: 1.4;
}
.block-editor-block-list__layout h1 {
  font-size: 23px;
}
.block-editor-block-list__layout h2 {
  font-size: 20px;
}
.block-editor-block-list__layout h3 {
  font-size: 18px;
}
.block-editor-block-list__layout h4 {
  font-size: 17px;
}
.block-editor-block-list__layout h5 {
  font-size: 15px;
}
.block-editor-block-list__layout h6 {
  font-size: 14px;
}
.block-editor-block-list__layout abbr[title],
.block-editor-block-list__layout dfn[title] {
  cursor: help;
}
.block-editor-block-list__layout del {
  vertical-align: baseline;
  text-decoration: line-through;
  color: #aaa;
}
.block-editor-block-list__layout code,
.block-editor-block-list__layout kbd,
.block-editor-block-list__layout pre,
.block-editor-block-list__layout samp {
  font-size: 16px;
}
.block-editor-block-list__layout pre {
  margin: 20px 0;
  padding: 20px;
  color: #2080ad;
  background-color: #fafafa;
}
.block-editor-block-list__layout code {
  color: #2080ad;
}
.block-editor-block-list__layout blockquote {
  font-style: italic;
  padding-left: 20px;
  border-left-width: 0.25em;
  border-style: solid;
  border-color: #13aff0;
}
.block-editor-block-list__layout blockquote cite {
  position: relative;
  display: block;
  padding: 10px 0 0 20px;
  color: #555;
}
.block-editor-block-list__layout blockquote cite:before {
  position: absolute;
  left: 0;
  content: "—";
}
.block-editor-block-list__layout q:before,
.block-editor-block-list__layout q:after,
.block-editor-block-list__layout blockquote:before,
.block-editor-block-list__layout blockquote:after {
  content: "";
}
.block-editor-block-list__layout blockquote .wp-block-quote__citation {
  padding: 10px 0 0 20px;
}
.block-editor-block-list__layout blockquote .wp-block-quote__citation:before {
  position: absolute;
  left: 0;
  content: "—";
}
.block-editor-block-list__layout address {
  display: block;
}
.block-editor-block-list__layout ol {
  list-style-type: decimal;
}
.block-editor-block-list__layout ol ol {
  list-style: upper-alpha;
}
.block-editor-block-list__layout ol ol ol {
  list-style: lower-roman;
}
.block-editor-block-list__layout ol ol ol ol {
  list-style: lower-alpha;
}
.block-editor-block-list__layout li ul,
.block-editor-block-list__layout li ol {
  margin: 0 0 0 25px;
}
.block-editor-block-list__layout dl {
  margin: 20px;
}
.block-editor-block-list__layout dt {
  font-weight: 700;
}
.block-editor-block-list__layout dd {
  margin-bottom: 20px;
}

a {
  color: #333;
  cursor: pointer;
  text-underline-offset: 3px;
  text-decoration: underline;
  text-decoration-skip-ink: all;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
a:hover {
  color: #13aff0;
  text-decoration: underline;
  text-decoration-style: dotted;
  text-decoration-skip-ink: none;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
a:focus:not(.wp-block-button__link):not(.wp-block-file__button) {
  /* Only visible in Windows High Contrast mode */
  outline: 2px solid transparent;
  text-decoration: underline 1px dotted #13aff0;
  text-decoration-skip-ink: none;
  background: rgba(255, 255, 255, 0.9);
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.editor-writing-flow {
  height: fit-content;
}

@media (min-width: 600px) {
  [data-align=full] .wp-block-group > .wp-block {
    max-width: none;
  }
}