/*!
 * Project   : OceanWP WordPress Theme
 * Purpose   : LearnDash LMS Tweaks
 * Author    : OceanWP
 */
/** Buttons **/
.btn-join,
#btn-join,
.learndash_checkout_buttons input.btn-join[type=button],
a#quiz_continue_link {
  display: inline-block;
  font-family: inherit;
  background-color: #13aff0;
  color: #fff;
  font-size: 12px;
  font-weight: 600;
  text-transform: uppercase;
  margin: 0;
  padding: 14px 20px;
  border: 0;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  border-radius: 3px;
  cursor: pointer;
  text-align: center;
  letter-spacing: 0.1em;
  line-height: 1;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.btn-join:hover,
.btn-join:focus,
.btn-join:active,
.btn-join:visited,
.btn-join.active,
#btn-join:hover,
#btn-join:focus,
a#quiz_continue_link:hover,
.learndash_checkout_buttons input.btn-join[type=button]:hover,
a#quiz_continue_link:focus {
  background-color: #0b7cac;
  color: #fff;
  border: 0;
}

#learndash_lessons #lesson_heading,
#learndash_profile .learndash_profile_heading,
#learndash_quizzes #quiz_heading,
#learndash_lesson_topics_list div > strong {
  background: #2295ff;
  color: #fff;
  padding: 10px;
  font-weight: 600;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-transform: uppercase;
}

#learndash_lessons h4 > a:hover,
#learndash_quizzes h4 > a:hover,
#learndash_lesson_topics_list ul > li > span.topic_item:hover {
  background: none;
}

.learndash .completed,
.learndash .notcompleted,
#learndash_profile .completed,
#learndash_profile .notcompleted {
  position: relative;
  background: 0 0;
  line-height: 1.8;
}
.learndash .completed:before,
.learndash .notcompleted:before,
#learndash_profile .completed:before,
#learndash_profile .notcompleted:before {
  position: absolute;
  top: 10px;
  right: 20px;
  display: inline-block;
  font: normal normal 900 14px/1 "Font Awesome 5 free";
  font-size: 20px;
  text-rendering: auto;
  content: "\f058";
  text-indent: 0;
  color: #068806;
}
.learndash .notcompleted:before,
#learndash_profile .notcompleted:before {
  content: "\f111";
  color: #777;
}

.learndash_navigation_lesson_topics_list .topic-completed span,
.learndash_navigation_lesson_topics_list .topic-notcompleted span,
.learndash_navigation_lesson_topics_list ul .topic-completed span,
.learndash_navigation_lesson_topics_list ul .topic-notcompleted span,
.learndash_topic_dots .topic-completed span,
.learndash_topic_dots .topic-notcompleted span,
.learndash_topic_dots ul .topic-completed span,
.learndash_topic_dots ul .topic-notcompleted span {
  background: 0 0;
}
.learndash_navigation_lesson_topics_list .topic-completed span:before,
.learndash_navigation_lesson_topics_list .topic-notcompleted span:before,
.learndash_navigation_lesson_topics_list ul .topic-completed span:before,
.learndash_navigation_lesson_topics_list ul .topic-notcompleted span:before,
.learndash_topic_dots .topic-completed span:before,
.learndash_topic_dots .topic-notcompleted span:before,
.learndash_topic_dots ul .topic-completed span:before,
.learndash_topic_dots ul .topic-notcompleted span:before {
  font: normal normal 900 14px/1 "Font Awesome 5 free";
  font-size: 20px;
  text-rendering: auto;
  content: "\f058";
  margin-right: 10px;
}

#learndash_course_content .learndash_topic_dots ul > li,
#learndash_course_content .learndash_topic_dots ul > li.nth-of-type-odd,
#learndash_course_content .learndash_topic_dots ul > li:hover {
  background: 0 0;
}

.learndash_topic_dots ul .topic-completed span,
.learndash_topic_dots ul .topic-notcompleted span {
  margin: 5px 0;
}

#learndash_lessons a,
#learndash_quizzes a,
.expand_collapse a,
.learndash_topic_dots a,
.learndash_topic_dots a > span,
#learndash_lesson_topics_list span a,
#learndash_profile a,
#learndash_profile .profile_edit_profile a,
#learndash_profile a span,
#learndash_profile div,
#learndash_profile .expand_collapse a {
  font-family: inherit;
  font-weight: 400;
  font-size: 14px;
}

#lessons_list > div > div,
#course_list > div > div,
#quiz_list > div > div,
.single-sfwd-lessons #learndash_lesson_topics_list ul > li > span.sn,
.singular-sfwd-lessons #learndash_lesson_topics_list ul > li > span.sn {
  border-right: none;
}

#learndash_profile .list_arrow.collapse,
#learndash_profile .list_arrow.expand {
  background: 0 0;
  padding: 10px;
  vertical-align: top;
  color: #777;
}
#learndash_profile .list_arrow.collapse:before,
#learndash_profile .list_arrow.expand:before {
  font: normal normal 900 14px/1 "Font Awesome 5 free";
  font-size: 20px;
  text-rendering: auto;
  content: "\f152";
}
#learndash_profile .list_arrow.expand:before {
  content: "\f150";
}
#learndash_profile .learndash-course-link a,
#learndash_profile .learndash-course-status a,
#learndash_profile .learndash-course-certificate a {
  line-height: inherit;
  padding: 10px 0;
}
#learndash_profile .course_progress {
  margin: 15px 0;
}
#learndash_profile .flip {
  padding-top: 10px;
}

#lessons_list > div h4 > a,
#course_list > div h4 > a,
#quiz_list > div h4 > a {
  padding-left: 0;
}

.ld-course-list-content .ld-entry-content img {
  margin: 0 auto 20px;
}

/** Shortcodes **/
body .thumbnail.course .ld_course_grid_price.ribbon-enrolled {
  background-color: #13aff0;
}
body dd.course_progress {
  margin-left: 0;
  width: 100%;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  border-radius: 3px;
}
body #ld_course_list .btn {
  display: inline-block;
  font-family: inherit;
  background-color: #13aff0;
  color: #fff;
  font-size: 12px;
  font-weight: 600;
  text-transform: uppercase;
  margin: 0;
  padding: 14px 20px;
  border: 0;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  border-radius: 3px;
  cursor: pointer;
  text-align: center;
  letter-spacing: 0.1em;
  line-height: 1;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
body #ld_course_list .btn-primary:hover,
body #ld_course_list .btn-primary:focus,
body #ld_course_list .btn-primary:active,
body #ld_course_list .btn-primary.active,
body #ld_course_list .open .dropdown-toggle.btn-primary {
  background-color: #0b7cac;
  color: #fff;
  border: 0;
}

/* RTL */
body.rtl {
  /** Shortcodes **/
}
body.rtl .learndash .completed:before,
body.rtl .learndash .notcompleted:before,
body.rtl #learndash_profile .completed:before,
body.rtl #learndash_profile .notcompleted:before {
  left: 20px;
  right: auto;
}
body.rtl .learndash_navigation_lesson_topics_list .topic-completed span:before,
body.rtl .learndash_navigation_lesson_topics_list .topic-notcompleted span:before,
body.rtl .learndash_navigation_lesson_topics_list ul .topic-completed span:before,
body.rtl .learndash_navigation_lesson_topics_list ul .topic-notcompleted span:before,
body.rtl .learndash_topic_dots .topic-completed span:before,
body.rtl .learndash_topic_dots .topic-notcompleted span:before,
body.rtl .learndash_topic_dots ul .topic-completed span:before,
body.rtl .learndash_topic_dots ul .topic-notcompleted span:before {
  margin-left: 10px;
  margin-right: 0;
}
body.rtl body dd.course_progress {
  margin-right: 0;
}