#site-header.center-header {
	#site-logo {
		display: none;
	}

	#site-navigation-wrap {
		float: none;
	    width: 100%;
	    right: auto;

	    .navigation {
	    	@include display();
			@include align-items( center );
	    }

		.middle-site-logo {
		    width: 24%;
		    text-align: center;

		    a img {
				width: auto;
				vertical-align: middle;
			    @include transition( all .3s ease-in-out );
			}

			&:hover img {
			    @include opacity( 0.6 );
			}
		}

	    .left-menu,
	    .right-menu {
	    	position: relative;
		    width: 38%;
	    }

	    .left-menu {
	    	float: left;
	    }

	    .right-menu {
	    	float: right;
	    }

	    .dropdown-menu > li {
	    	float: none;
    		display: inline-block;
	    }
	}

    .centered {
	    .left-menu,
	    .right-menu {
		    text-align: center;
	    }
	}

    .wider .left-menu {
    	text-align: left;
	}

    .wider .right-menu {
    	text-align: right;
	}

    .closer .left-menu {
    	text-align: right;
	}

    .closer .right-menu {
    	text-align: left;
	}

	#searchform-header-replace.show {
		max-width: 100% !important;
	}

	&.header-replace {
		#site-navigation .middle-site-logo {
		    @include transition( opacity .3s );
		}

		#site-navigation.hide .middle-site-logo {
			visibility: hidden;
		    @include opacity( 0 );
		}
	}
}