/* General */
body.rtl .customize-control-checkbox input[type=checkbox] { margin: 0 0 0 6px; }
body.rtl .customize-control-checkbox input[type="checkbox"]:checked:before,
body.rtl .customize-control-ocean-multi-check input[type="checkbox"]:checked:before { right: 0; left: auto; }
body.rtl .customize-control .responsive-switchers,
body.rtl .customize-control .responsive-switchers li button { margin-right: 5px; margin-left: 0; }
body.rtl .customize-control .responsive-switchers li { float: right; }

/* Buttonset */
body.rtl .customize-control-oceanwp-buttonset .buttonset .switch-label { float: right; border-left: 1px solid rgba(0, 0, 0, 0.2); border-right: 0; }
body.rtl .customize-control-oceanwp-buttonset .buttonset .switch-label:last-child { border-left: none; }

/* Color */
body.rtl .wp-core-ui .wp-picker-default, .wp-core-ui .wp-picker-clear { margin-right: 10%; margin-left: 0; }
body.rtl .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control { float: right; }
body.rtl .wp-picker-input-wrap .button { margin-right: 0; float: left; }
body.rtl .alpha-color-picker-container .ui-widget-content .ui-state-default { margin-right: -14px; margin-left: 0; }
body.rtl .alpha-color-picker-container .click-zone { right: 10px; left: auto; }
body.rtl .alpha-color-picker-container .max-click-zone { left: 10px; right: auto; }

/* Dimensions */
body.rtl .customize-control-oceanwp-dimensions .dimension-wrap { float: right; }
body.rtl .customize-control-oceanwp-dimensions .dimension-wrap input,
body.rtl .customize-control-oceanwp-dimensions .dimension-wrap button { border-left-width: 1px; border-right-width: 0; }
body.rtl .customize-control-oceanwp-dimensions .dimension-wrap:first-child input { border-right-width: 1px; border-radius: 3px 3px 0 0; }
body.rtl .customize-control-oceanwp-dimensions .dimension-wrap .link-dimensions { border-left-width: 1px; border-right-width: 0; border-radius: 0 0 3px 3px; }

/* Icon Select */
body.rtl .customize-control-oceanwp-icon .icon-select label { float: right; }

/* Radio Image */
body.rtl .customize-control-oceanwp-radio-image label { margin-left: 3%; margin-right: 0; }
body.rtl .customize-control-oceanwp-radio-image label:nth-child(3n) { margin-left: 0; }

/* Range */
body.rtl .customize-control-oceanwp-range input.oceanwp-range-input { margin-right: 8px; margin-left: 0; }
body.rtl .customize-control-oceanwp-range span.oceanwp-reset-slider { margin-right: 5px; margin-left: 0; }

/* Sortable */
body.rtl .customize-control-oceanwp-sortable ul li .dashicons.dashicons-menu { float: left; }
body.rtl .customize-control-oceanwp-sortable ul li .dashicons.visibility { margin-left: 10px; margin-right: 0; }