/*------------------------------------------------------------------
Woo Mini Cart
-------------------------------------------------------------------*/
.current-shop-items-dropdown {
  position: absolute;
  top: 100%;
  right: -20px;
  background-color: #fff;
  z-index: 10000;
  border-top: 3px solid transparent;
  text-align: left;
  -webkit-box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
  width: 350px;
  visibility: hidden;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  -webkit-transition: all 0.25s ease-in-out;
  -moz-transition: all 0.25s ease-in-out;
  -ms-transition: all 0.25s ease-in-out;
  -o-transition: all 0.25s ease-in-out;
  transition: all 0.25s ease-in-out;
}
.current-shop-items-dropdown ul.woocommerce-mini-cart {
  max-height: 50vh;
  overflow-y: auto;
}
.current-shop-items-dropdown .widgettitle {
  display: none;
}
.current-shop-items-dropdown li:first-child {
  border-top: none;
}
.current-shop-items-dropdown p.woocommerce-mini-cart__empty-message {
  padding: 20px;
  margin: 0;
}

.wcmenucart-toggle-drop_down:hover .current-shop-items-dropdown,
.show-cart .wcmenucart-toggle-drop_down .current-shop-items-dropdown {
  visibility: visible;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}

.boxed-layout .current-shop-items-dropdown {
  right: 0;
}

.widget_shopping_cart ul.cart_list li {
  padding: 0;
  border-bottom-width: 1px;
  border-style: solid;
  border-color: #e6e6e6;
  min-height: 100%;
}
.widget_shopping_cart ul.cart_list li:first-child, .widget_shopping_cart ul.cart_list li:last-child {
  min-height: 100%;
}
.widget_shopping_cart ul.cart_list li:first-child {
  border-top-width: 0;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
  -webkit-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-align-items: center;
  align-items: center;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid {
  width: 100%;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid.thumbnail {
  width: 25%;
  margin: 0;
  border-right-width: 1px;
  border-style: solid;
  border-color: #e6e6e6;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid.thumbnail img {
  position: relative;
  top: 0;
  width: auto;
  height: auto;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid.content {
  position: relative;
  width: 75%;
  padding-left: 10px;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid > div {
  padding-right: 60px;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid h3 {
  display: block;
  font-size: 14px;
  font-weight: normal;
  margin: 0;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid .quantity {
  color: #b2b2b2;
  font-weight: normal;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid a.remove {
  right: 20px;
  margin-top: -17px;
  width: 32px;
  height: 32px;
  line-height: 30px;
  color: #b3b3b3;
  border: 1px solid #e6e6e6;
}
.widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid a.remove:hover {
  color: #13aff0;
  border-color: #13aff0;
}
.widget_shopping_cart .total {
  background-color: #fafafa;
  border-width: 1px 0;
  border-style: solid;
  border-color: #e6e6e6;
  padding: 20px;
  margin: 0;
}
.widget_shopping_cart .total strong {
  float: left;
  font-size: 12px;
  font-weight: normal;
  color: #797979;
  text-transform: uppercase;
  letter-spacing: 1px;
}
.widget_shopping_cart .total .amount {
  float: right;
  font-size: 16px;
  line-height: 1.3;
  font-weight: 600;
  letter-spacing: 1px;
}
.widget_shopping_cart .total:after {
  content: "";
  display: table;
  clear: both;
}

.widget_shopping_cart_content .buttons {
  margin: 0;
  padding: 20px;
}
.widget_shopping_cart_content .buttons .button {
  float: left;
  width: 48%;
  padding: 14px 8px;
  text-align: center;
  letter-spacing: 2px;
}
.widget_shopping_cart_content .buttons .button:first-child {
  background-color: transparent;
  border: 1px solid #e6e6e6;
  color: #666;
}
.widget_shopping_cart_content .buttons .button:first-child:hover {
  border-color: #13aff0;
}
.widget_shopping_cart_content .buttons .checkout {
  float: right;
}
.widget_shopping_cart_content .buttons:after {
  content: "";
  display: table;
  clear: both;
}

/* Cart spacious style */
.spacious .owp-mini-cart {
  padding: 20px;
}
.spacious .owp-mini-cart .widget_shopping_cart ul.cart_list li {
  padding-bottom: 10px;
  margin-bottom: 10px;
}
.spacious .owp-mini-cart .widget_shopping_cart ul.cart_list li .owp-grid-wrap .owp-grid.thumbnail {
  border-width: 0;
}
.spacious .owp-mini-cart .widget_shopping_cart .total {
  background-color: transparent;
  padding: 14px 20px;
}
.spacious .owp-mini-cart .widget_shopping_cart_content .buttons {
  padding: 20px 0 0;
}
.spacious .owp-mini-cart p.woocommerce-mini-cart__empty-message {
  padding: 0;
}

/* Cart bag style */
.bag-style {
  position: relative;
  display: inline-block;
}

.wcmenucart-total {
  margin-right: 7px;
}
.wcmenucart-total span {
  color: #333;
}

.wcmenucart-cart-icon {
  display: inline-block;
}
.wcmenucart-cart-icon .wcmenucart-count {
  position: relative;
  display: inline-block;
  min-width: 2em;
  height: 2em;
  font-size: 1em;
  line-height: 1.7em;
  font-weight: bold;
  border: 2px solid #333;
  color: #333;
  padding: 0 3px;
  vertical-align: middle;
  text-align: center;
  -webkit-transition: all 0.2s ease-in-out;
  -moz-transition: all 0.2s ease-in-out;
  -ms-transition: all 0.2s ease-in-out;
  -o-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out;
}
.wcmenucart-cart-icon .wcmenucart-count:after {
  content: "";
  position: absolute;
  bottom: 100%;
  left: 50%;
  width: 14px;
  height: 8px;
  margin-left: -7px;
  margin-bottom: 0;
  border: 2px solid #333;
  border-top-left-radius: 100px;
  border-top-right-radius: 100px;
  border-bottom: 0;
  -webkit-transition: all 0.2s ease-in-out;
  -moz-transition: all 0.2s ease-in-out;
  -ms-transition: all 0.2s ease-in-out;
  -o-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out;
}

.bag-style:hover .wcmenucart-cart-icon .wcmenucart-count,
.show-cart .wcmenucart-cart-icon .wcmenucart-count {
  background-color: #13aff0;
  color: #fff;
  border-color: #13aff0;
}
.bag-style:hover .wcmenucart-cart-icon .wcmenucart-count:after,
.show-cart .wcmenucart-cart-icon .wcmenucart-count:after {
  border-color: #13aff0;
  height: 10px;
}

/* Fix for some conflict with default Woo css if custom features are disabled */
.woocommerce .widget_shopping_cart .cart_list li, .woocommerce.widget_shopping_cart .cart_list li {
  padding: 0;
}

.woocommerce .widget_shopping_cart .cart_list li a.remove, .woocommerce.widget_shopping_cart .cart_list li a.remove {
  top: 50%;
  left: auto;
  right: 0;
}

.woocommerce .widget_shopping_cart .total, .woocommerce.widget_shopping_cart .total {
  padding: 20px;
}