.oceanwp-social-menu {
	float: right;
    position: relative;
    z-index: 10;

    &.simple-social {
		right: -8px;
	}

	&.social-with-style {
		right: -2px;
	}

    .social-menu-inner {
    	@include display();
		@include align-items( center );
    	height: 74px;
    }

    ul {
	    margin: 0;
	    padding: 0;
	    list-style: none;

	    li {
	    	float: left;
    		position: relative;

    		a {
    			display: inline-block;
			    background-color: transparent;
			    color: $color-4;
			    padding: 0 8px;
			    line-height: 1;
			    text-align: center;
			    letter-spacing: 0;

			    span {
			    	width: 1em;
   					height: 1em;
			    	text-align: center;
			    }

			    &:hover {
			    	background-color: transparent;
			    }
    		}

    		&:first-child a {
    			margin-left: 0;
    		}

    		&:last-child a {
    			margin-right: 0;
    		}

		    &.oceanwp-twitter a:hover { color: #46d4fe; }
		    &.oceanwp-facebook a:hover { color: #37589b; }
		    &.oceanwp-googleplus a:hover { color: #de5a49; }
		    &.oceanwp-pinterest a:hover { color: #cb2027; }
		    &.oceanwp-dribbble a:hover { color: #ea4c89; }
		    &.oceanwp-vk a:hover { color: #597BA5; }
		    &.oceanwp-instagram a:hover { color: #3F729B; }
		    &.oceanwp-linkedin a:hover { color: #3399CC; }
		    &.oceanwp-tumblr a:hover { color: #2C4762; }
		    &.oceanwp-github a:hover { color: #60b044; }
		    &.oceanwp-flickr a:hover { color: #fa4086; }
		    &.oceanwp-skype a:hover { color: #00AFF0; }
		    &.oceanwp-youtube a:hover { color: #C4302B; }
		    &.oceanwp-vimeo a:hover { color: #1ab7ea; }
		    &.oceanwp-vine a:hover { color: #00bf8f; }
		    &.oceanwp-xing a:hover { color: #006464; }
		    &.oceanwp-yelp a:hover { color: #C41200; }
		    &.oceanwp-tripadvisor a:hover { color: #589442; }
		    &.oceanwp-rss a:hover { color: #ff7900; }
		    &.oceanwp-email a:hover { color: #13aff0; }
			&.oceanwp-tiktok a:hover { color: #000000; }
			&.oceanwp-medium a:hover { color: #00ab6c; }
			&.oceanwp-telegram a:hover { color: #0088cc; }
			&.oceanwp-twitch a:hover { color: #6441a5; }
			&.oceanwp-line a:hover { color: #00c300; }
			&.oceanwp-qq a:hover { color: #febf1b; }
			&.oceanwp-facebook_group a:hover { color: #37589b; }
			&.oceanwp-slack a:hover { color: #4a154b; }
			&.oceanwp-threads a:hover { color: #000000; }
			&.oceanwp-mastodon a:hover { color: #563acc; }
			&.oceanwp-discord a:hover { color: #5865f2; }
	    }
	}

	.colored ul li {
		a {
	    	position: relative;
		    display: inline-block;
		    font-size: 12px;
		    color: $color-1;
		    line-height: 1;
    		padding: 1em;
		    @include border-radius( 50% );
		    vertical-align: middle;
		    @include transition( all .3s ease-out );

		    &:hover {
		    	color: $color-1;
		    }

			.owp-icon use {
				stroke: $color-1;
			}
		}

	    &.oceanwp-twitter a { background-color: #46d4fe; }
	    &.oceanwp-twitter a:hover { background-color: #39b4d8; }
	    &.oceanwp-facebook a{ background-color: #37589b; }
	    &.oceanwp-facebook a:hover{ background-color: #2d477c; }
	    &.oceanwp-googleplus a{ background-color: #de5a49; }
	    &.oceanwp-googleplus a:hover { background-color: #bb4c3e; }
	    &.oceanwp-pinterest a { background-color: #cb2027; }
	    &.oceanwp-pinterest a:hover { background-color: #a91d23; }
	    &.oceanwp-dribbble a { background-color: #ea4c89; }
	    &.oceanwp-dribbble a:hover { background-color: #c64174; }
	    &.oceanwp-vk a { background-color: #597BA5; }
	    &.oceanwp-vk a:hover { background-color: #486384; }
	    &.oceanwp-instagram a { background-color: #3F729B; }
	    &.oceanwp-instagram a:hover { background-color: #315a7c; }
	    &.oceanwp-linkedin a{ background-color: #3399CC; }
	    &.oceanwp-linkedin a:hover { background-color: #2678a1; }
	    &.oceanwp-tumblr a { background-color: #2C4762; }
	    &.oceanwp-tumblr a:hover { background-color: #1d3042; }
	    &.oceanwp-github a { background-color: #60b044; }
	    &.oceanwp-github a:hover { background-color: #4f9237; }
	    &.oceanwp-flickr a { background-color: #fa4086; }
	    &.oceanwp-flickr a:hover { background-color: #c63169; }
	    &.oceanwp-skype a { background-color: #00AFF0; }
	    &.oceanwp-skype a:hover { background-color: #0291c6; }
	    &.oceanwp-youtube a { background-color: #C4302B; }
	    &.oceanwp-youtube a:hover { background-color: #982420; }
	    &.oceanwp-vimeo a { background-color: #1ab7ea; }
	    &.oceanwp-vimeo a:hover { background-color: #1494bd; }
	    &.oceanwp-vine a { background-color: #00bf8f; }
	    &.oceanwp-vine a:hover { background-color: #01906c; }
	    &.oceanwp-xing a { background-color: #006464; }
	    &.oceanwp-xing a:hover { background-color: #014646; }
	    &.oceanwp-yelp a { background-color: #C41200; }
	    &.oceanwp-yelp a:hover { background-color: #940f01; }
	    &.oceanwp-tripadvisor a { background-color: #589442; }
	    &.oceanwp-tripadvisor a:hover { background-color: #426f32; }
	    &.oceanwp-rss a { background-color: #ff7900; }
	    &.oceanwp-rss a:hover { background-color: #d46603; }
	    &.oceanwp-email a { background-color: #13aff0; }
	    &.oceanwp-email a:hover { background-color: #0f8dc2; }
		&.oceanwp-tiktok a { background-color: #000000; }
	    &.oceanwp-tiktok a:hover { background-color: #141414; }
		&.oceanwp-medium a { background-color: #00ab6c; }
	    &.oceanwp-medium a:hover { background-color: #03945f; }
		&.oceanwp-telegram a { background-color: #0088cc; }
	    &.oceanwp-telegram a:hover { background-color: #0da4f0; }
		&.oceanwp-twitch a { background-color: #6441a5; }
		&.oceanwp-twitch a:hover { background-color: #702cee; }
		&.oceanwp-line a { background-color: #00c300; }
		&.oceanwp-line a:hover { background-color: #09f309; }
		&.oceanwp-qq a { background-color: #febf1b; }
		&.oceanwp-qq a:hover { background-color: #db9f07; }
		&.oceanwp-facebook_group a { background-color: #37589b; }
		&.oceanwp-facebook_group a:hover { background-color: #2d477c; }
		&.oceanwp-slack a { background-color: #4a154b; }
		&.oceanwp-slack a:hover { background-color: #3d0a3e; }
		&.oceanwp-threads a { background-color: #000000; }
		&.oceanwp-threads a:hover { background-color: #191919; }
		&.oceanwp-mastodon a { background-color: #6364ff; }
		&.oceanwp-mastodon a:hover { background-color: #563acc; }
		&.oceanwp-discord a { background-color: #5865f2; }
		&.oceanwp-discord a:hover { background-color: #7289da; }
	}

	.minimal ul li {
		a {
	    	position: relative;
		    display: inline-block;
		    font-size: 12px;
		    background-color: transparent;
		    color: #bbb;
		    border: 1px solid #ccc;
		    line-height: 1;
    		padding: 1em;
		    @include border-radius( 50% );
		    vertical-align: middle;
		    @include transition( all .3s ease-out );

		    &:hover {
		    	background-color: transparent;
		    }
		}

	    &.oceanwp-twitter a:hover { color: #46d4fe; border-color: #46d4fe; }
	    &.oceanwp-facebook a:hover { color: #37589b; border-color: #37589b; }
	    &.oceanwp-googleplus a:hover { color: #de5a49; border-color: #de5a49; }
	    &.oceanwp-pinterest a:hover { color: #cb2027; border-color: #cb2027; }
	    &.oceanwp-dribbble a:hover { color: #ea4c89; border-color: #ea4c89; }
	    &.oceanwp-vk a:hover { color: #597BA5; border-color: #597BA5; }
	    &.oceanwp-instagram a:hover { color: #3F729B; border-color: #3F729B; }
	    &.oceanwp-linkedin a:hover { color: #3399CC; border-color: #3399CC; }
	    &.oceanwp-tumblr a:hover { color: #2C4762; border-color: #2C4762; }
	    &.oceanwp-github a:hover { color: #60b044; border-color: #60b044; }
	    &.oceanwp-flickr a:hover { color: #fa4086; border-color: #fa4086; }
	    &.oceanwp-skype a:hover { color: #00AFF0; border-color: #00AFF0; }
	    &.oceanwp-youtube a:hover { color: #C4302B; border-color: #C4302B; }
	    &.oceanwp-vimeo a:hover { color: #1ab7ea; border-color: #1ab7ea; }
	    &.oceanwp-vine a:hover { color: #00bf8f; border-color: #00bf8f; }
	    &.oceanwp-xing a:hover { color: #006464; border-color: #006464; }
	    &.oceanwp-yelp a:hover { color: #C41200; border-color: #C41200; }
	    &.oceanwp-tripadvisor a:hover { color: #589442; border-color: #589442; }
	    &.oceanwp-rss a:hover { color: #ff7900; border-color: #ff7900; }
	    &.oceanwp-email a:hover { color: #13aff0; border-color: #13aff0; }
	    &.oceanwp-tiktok a:hover { color: #000000; border-color: #000000; }
	    &.oceanwp-medium a:hover { color: #00ab6c; border-color: #00ab6c; }
	    &.oceanwp-telegram a:hover { color: #0088cc; border-color: #0088cc;}
		&.oceanwp-twitch a:hover { color: #702cee; border-color: #702cee; }
		&.oceanwp-line a:hover { color: #00c300; border-color: #00c300; }
		&.oceanwp-qq a:hover { color: #febf1b; border-color: #febf1b; }
		&.oceanwp-facebook_group a:hover { color: #37589b; border-color: #37589b; }
		&.oceanwp-slack a:hover { color: #4a154b; border-color: #4a154b; }
		&.oceanwp-threads a:hover { color: #000000; border-color: #000000; }
		&.oceanwp-mastodon a:hover { color: #563acc; border-color: #563acc; }
		&.oceanwp-discord a:hover { color: #5865f2; border-color: #7289da; }
	}

	.dark ul li a {
    	position: relative;
	    display: inline-block;
	    font-size: 12px;
	    background-color: $color-2;
	    color: $color-1;
	    line-height: 1;
		padding: 1em;
	    @include border-radius( 50% );
	    vertical-align: middle;
	    @include transition( all .3s ease-out );

	    &:hover {
	    	background-color: #000;
	    	color: $color-1;
	    }

		.owp-icon use {
			stroke: $color-1;
		}
	}
}