/*------------------------------------------------------------------
Woo Mobile Mini Cart Sidebar
-------------------------------------------------------------------*/
#oceanwp-cart-sidebar-wrap {
	display: none;
	visibility: hidden;
	@include opacity( 0 );
	@include transition( all 0.25s ease-in-out );

	&,
	.oceanwp-cart-sidebar-overlay {
		position: fixed;
	    top: 0;
	    left: 0;
	    width: 100%;
	    height: 100%;
    	z-index: 9999;
	}

	.oceanwp-cart-sidebar-overlay {
	    background-color: rgba(0,0,0,.5);
	    cursor: pointer;
	}

	.oceanwp-cart-sidebar {
		position: absolute;
	    top: 0;
	    right: -100%;
	    background-color: #fff;
	    width: 325px;
	    height: 100%;
	    padding: 20px 0 0;
	    overflow: auto;
    	z-index: 10000;
		@include box-shadow( 0 0 12px 0 rgba(0,0,0,.4) );
		@include transition( all 0.3s ease-in-out );
	}

	.owp-cart-title {
		font-size: 18px;
		font-weight: 600;
	    color: #555;
	    line-height: 1.2;
	    text-transform: uppercase;
	    padding: 0 20px;
	    margin: 0;
	    text-align: center;
	}

	.divider {
	    display: block;
	    width: 30px;
		height: 2px;
	    background-color: rgba(0,0,0,0.1);
	    margin: 10px auto 20px;
	}

	.oceanwp-cart-close {
    	position: absolute;
	    top: 0;
	    right: 0;
	    color: #333;
	    opacity: .5;
	    font-weight: 300;
	    font-size: 40px;
	    width: 40px;
	    height: 40px;
	    line-height: 40px;
	    text-align: center;
	    z-index: 1001;

	    &:hover {
	    	opacity: 1;
	    }
    }

	.widget_shopping_cart ul.cart_list li:first-child {
		border-top-width: 1px;
	}

	.woocommerce-mini-cart__empty-message {
		padding: 0 20px 20px;
    	margin: 0;
	}

	.spacious .owp-mini-cart {
		padding-top: 0;

		.widget_shopping_cart ul.cart_list li:first-child {
			padding-top: 10px;
		}
	}
}

.admin-bar #oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar {
    top: 32px;
    height: -webkit-calc(100% - 32px);
    height: calc(100% - 32px);
}

@media screen and (max-width: 782px) {
	.admin-bar #oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar {
	    top: 46px;
	    height: -webkit-calc(100% - 46px);
	    height: calc(100% - 46px);
	}
}

@media screen and (max-width: 600px) {
	.admin-bar #oceanwp-cart-sidebar-wrap .oceanwp-cart-sidebar {
	    top: 0;
	    height: 100%;
	}
}

.show-cart,
.show-cart-sidebar {
	#oceanwp-cart-sidebar-wrap {
	    visibility: visible;
		@include opacity( 1 );

		.oceanwp-cart-sidebar {
		    right: 0;
		}
	}
}

@media only screen and (max-width: 959px) {
	#oceanwp-cart-sidebar-wrap {
		display: block;
	}
}