/**
 *  Gallery Format
 */
.gallery-format {
    opacity: 0;
    visibility: hidden;
    height: 0;

    img,
    a.gallery-lightbox {
        display: block;
        position: relative;
        width: 100%;
        margin-bottom: 0;
    }

    .flickity-button {
        top: calc(100% - 18px);
        width: 30px;
        height: 36px;
        border-radius: 0;
        background-color: rgba(0, 0, 0, 0.6);
        display: flex;
        justify-content: center;
        align-items: center;

        &:hover {
            background-color: rgba(0, 0, 0, 0.8);
        }

        &:disabled {
            pointer-events: unset;
        }

        &.next {
            right: 0;
        }

        &.previous {
            left: auto;
            right: 30px;
        }

        svg {
            fill: #fff;
            width: 12px;
            height: auto;
            position: static;
        }
    }
}
