<?php
/**
 * Single Product title
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/title.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 4.4.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

// Heading tag.
$heading = get_theme_mod( 'ocean_woo_product_title_tag', 'h2' );
$heading = $heading ? $heading : 'h2';
$heading = apply_filters( 'ocean_woo_product_title_tag', $heading ); ?>

<<?php echo esc_attr( $heading ); ?> class="single-post-title product_title entry-title"<?php oceanwp_schema_markup( 'author_name' ); ?>><?php the_title(); ?></<?php echo esc_attr( $heading ); ?>>
