.customize-control-oceanwp-slider .control-wrap { display: inline-block; width: 100%; }
.customize-control-oceanwp-slider .oceanwp-slider { display: inline-block; position: relative; width: 67%; height: 4px; margin-top: 12px; background-color: rgba(0,0,0,.15); border-radius: 5px; cursor: pointer; -webkit-transition: background .5s; -moz-transition: background .5s; transition: background .5s; }
.customize-control-oceanwp-slider .oceanwp-slider:hover { background-color: rgba(0,0,0,.2); }
.customize-control-oceanwp-slider .oceanwp-slider .ui-slider-range { display: inline-block; position: absolute; top: 0; height: 100%; background-color: #13a1dc; }
.customize-control-oceanwp-slider .oceanwp-slider .ui-slider-handle { height: 16px; width: 16px; background-color: #fff; display: inline-block; position: absolute; top: 50%; -webkit-transform: translateY(-50%) translateX(-4px); transform: translateY(-50%) translateX(-4px); box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.3); border-radius: 50%; cursor: pointer; }
.customize-control-oceanwp-slider .oceanwp-slider-input { float: right; width: 33%; }
.customize-control-oceanwp-slider input.slider-input { float: right; width: 80%; height: 28px; text-align: center; border-radius: 4px; padding: 3px; font-size: 12px; font-weight: 600; color: #555; }