/** Buttons **/
.btn-join, 
#btn-join, 
.learndash_checkout_buttons input.btn-join[type="button"], 
a#quiz_continue_link{
	display: inline-block;
	font-family: inherit;
	background-color: $color-5;
	color: $color-1;
	font-size: 12px;
	font-weight: 600;
	text-transform: uppercase;
	margin: 0;
	padding: 14px 20px;
	border: 0;
	@include border-radius(3px);
	cursor: pointer;
	text-align: center;
	letter-spacing: 0.1em;
	line-height: 1;
	@include transition( all .3s ease );
}

.btn-join:hover, 
.btn-join:focus, 
.btn-join:active, 
.btn-join:visited, 
.btn-join.active, 
#btn-join:hover, 
#btn-join:focus, 
a#quiz_continue_link:hover, 
.learndash_checkout_buttons input.btn-join[type="button"]:hover, 
a#quiz_continue_link:focus{
	background-color: $color-6;
	color: $color-1;
	border: 0;
}

#learndash_lessons #lesson_heading, 
#learndash_profile .learndash_profile_heading, 
#learndash_quizzes #quiz_heading, 
#learndash_lesson_topics_list div > strong{
	background: #2295ff;
    color: #fff;
    padding: 10px;
    font-weight: $heading-font-weight;
    @include border-radius(0);
	text-transform: uppercase;
}

#learndash_lessons h4 > a:hover, 
#learndash_quizzes h4 > a:hover, 
#learndash_lesson_topics_list ul > li > span.topic_item:hover{
	background: none;
}

.learndash,
#learndash_profile {

	.completed,
	.notcompleted{
		position: relative;
		background: 0 0;
		line-height: 1.8;
	}

	.completed:before,
	.notcompleted:before {
		position: absolute;
		top: 10px;
		right: 20px;
		display: inline-block;
		font: normal normal 900 14px/1 'Font Awesome 5 free';
		font-size: 20px;
		text-rendering: auto;
		content: "\f058";
		text-indent: 0;
		color: #068806;
	}

	.notcompleted:before{
		content: "\f111";
		color: $color-15;
	}
}

.learndash_navigation_lesson_topics_list .topic-completed span, 
.learndash_navigation_lesson_topics_list .topic-notcompleted span, 
.learndash_navigation_lesson_topics_list ul .topic-completed span, 
.learndash_navigation_lesson_topics_list ul .topic-notcompleted span, 
.learndash_topic_dots .topic-completed span, 
.learndash_topic_dots .topic-notcompleted span, 
.learndash_topic_dots ul .topic-completed span, 
.learndash_topic_dots ul .topic-notcompleted span{
	background: 0 0;

	&:before{
		font: normal normal 900 14px/1 'Font Awesome 5 free';
		font-size: 20px;
		text-rendering: auto;
		content: "\f058";
		margin-right: 10px;
	}
}

#learndash_course_content .learndash_topic_dots ul>li, 
#learndash_course_content .learndash_topic_dots ul>li.nth-of-type-odd, 
#learndash_course_content .learndash_topic_dots ul>li:hover{
	background: 0 0;
}

.learndash_topic_dots ul .topic-completed span, 
.learndash_topic_dots ul .topic-notcompleted span{
	margin: 5px 0;
}

#learndash_lessons a, 
#learndash_quizzes a, 
.expand_collapse a, 
.learndash_topic_dots a, 
.learndash_topic_dots a > span, 
#learndash_lesson_topics_list span a, 
#learndash_profile a, 
#learndash_profile .profile_edit_profile a,
#learndash_profile a span,
#learndash_profile div,
#learndash_profile .expand_collapse a {
	font-family: inherit;
	font-weight: $body-font-weight;
	font-size: $base-font-size;
}

#lessons_list > div > div, 
#course_list > div > div, 
#quiz_list > div > div, 
.single-sfwd-lessons #learndash_lesson_topics_list ul > li > span.sn, 
.singular-sfwd-lessons #learndash_lesson_topics_list ul > li > span.sn{
	border-right: none;	
}

#learndash_profile{
	.list_arrow.collapse,
	.list_arrow.expand{
		background: 0 0;
		padding: 10px;
		vertical-align: top;
		color: $color-15;
	
		&:before{
			font: normal normal 900 14px/1 'Font Awesome 5 free';
			font-size: 20px;
			text-rendering: auto;
			content: "\f152";
		}
	}

	.list_arrow.expand{
		&:before{
			content: "\f150";
		}
	}

	.learndash-course-link,
	.learndash-course-status,
	.learndash-course-certificate{
		a{
			line-height: inherit;
			padding: 10px 0;
		}
	}

	.course_progress{
		margin: 15px 0;
	}

	.flip{
		padding-top: 10px;
	}
}

#lessons_list > div h4 > a, 
#course_list > div h4 > a, 
#quiz_list > div h4 > a {
	padding-left: 0;
}

.ld-course-list-content{
	.ld-entry-content img{
		margin: 0 auto 20px;
	}
}

/** Shortcodes **/
body{
	.thumbnail.course .ld_course_grid_price.ribbon-enrolled{
		background-color: $color-5;
	}

	dd.course_progress{
		margin-left: 0;
		width: 100%;
		@include border-radius(3px);
	}

	#ld_course_list .btn{
		display: inline-block;
	    font-family: inherit;
	    background-color: $color-5;
	    color: $color-1;
	    font-size: 12px;
	    font-weight: 600;
	    text-transform: uppercase;
	    margin: 0;
	    padding: 14px 20px;
	    border: 0;
	    @include border-radius(3px);
	    cursor: pointer;
	    text-align: center;
	    letter-spacing: 0.1em;
	    line-height: 1;
	    @include transition( all .3s ease );
	}

	#ld_course_list .btn-primary:hover, 
	#ld_course_list .btn-primary:focus, 
	#ld_course_list .btn-primary:active, 
	#ld_course_list .btn-primary.active, 
	#ld_course_list .open .dropdown-toggle.btn-primary{
		background-color: $color-6;
		color: $color-1;
		border: 0;
	}
}

/* RTL */
body.rtl {
	.learndash,
	#learndash_profile {
		.completed:before,
		.notcompleted:before {
			left: 20px;
			right: auto;
		}
	}

	.learndash_navigation_lesson_topics_list .topic-completed span, 
	.learndash_navigation_lesson_topics_list .topic-notcompleted span, 
	.learndash_navigation_lesson_topics_list ul .topic-completed span, 
	.learndash_navigation_lesson_topics_list ul .topic-notcompleted span, 
	.learndash_topic_dots .topic-completed span, 
	.learndash_topic_dots .topic-notcompleted span, 
	.learndash_topic_dots ul .topic-completed span, 
	.learndash_topic_dots ul .topic-notcompleted span{
		&:before{
			margin-left: 10px;
			margin-right: 0;
		}
	}

	/** Shortcodes **/
	body{
		dd.course_progress{
			margin-right: 0;
		}
	}
}