#searchform-dropdown,
#icon-searchform-dropdown {
	position: absolute;
	right: 0;
	background-color: $color-1;
	border-top: 3px solid $color-5;
	top: 100%;
	padding: 15px;
	width: 260px;
	@include box-shadow( 0 2px 7px rgba(0,0,0,0.1) );
	visibility: hidden;
	@include opacity( 0 );
	transition: all 0.25s ease-in-out;
	z-index: 10000;

	input {
		display: block;
		background-color: transparent;
		@include border-radius( 0 );
		margin: 0;
	}
}

.no-top-border #searchform-dropdown,
.no-top-border #icon-searchform-dropdown {
	border: none;
}

/* display search on click */
#searchform-dropdown.show,
#icon-searchform-dropdown.show {
	visibility: visible;
	@include opacity( 1 );
}

#icon-searchform-dropdown {
	width: 100%;
}