#customize-theme-controls #accordion-section-oceanwp_upsell_section {
	display: block !important;
	border-top: 1px solid #5277fe;
	border-bottom: 1px solid #5277fe;
}

#accordion-section-oceanwp_upsell_section h3 {
    background-color: #5277fe;
    padding: 0;
    margin: 0;
    border-left: 4px solid #5277fe;
    transition: .15s background-color ease-in-out,.15s border-color ease-in-out;
    outline: none;
}

#accordion-section-oceanwp_upsell_section h3:hover {
    background-color: #3d5ac3;
    border-left-color: #000c65;
}

#accordion-section-oceanwp_upsell_section h3 a {
    display: block;
    position: relative;
    color: #fff;
    padding: 10px 10px 11px 14px;
    line-height: 21px;
    text-decoration: none;
    box-shadow: none !important;
}

#accordion-section-oceanwp_upsell_section h3 a:after {
    content: '\f345';
    color: #fff;
    position: absolute;
    top: 12px;
    right: 10px;
    z-index: 1;
    font: 400 20px/1 dashicons;
    speak: none;
    display: block;
    text-decoration: none !important;
}

.rtl #accordion-section-oceanwp_upsell_section h3 {
    border-left: none;
    border-right: 4px solid #5277fe;
}

.rtl #accordion-section-oceanwp_upsell_section h3:hover {
    border-right-color: #000c65;
}

.rtl #accordion-section-oceanwp_upsell_section h3 a:after {
    content: '\f341';
    right: auto;
    left: 10px;
}