#site-header.transparent-header {
	position: absolute;
	top: 0;
	background-color: transparent;
	height: auto;
	z-index: 9999;

	#site-logo.has-transparent-logo {
		.custom-logo-link {
			display: none;
		}

		.transparent-logo-link {
			display: block;
		}
	}
}

.is-sticky #site-header.transparent-header #site-logo.has-transparent-logo {
	.custom-logo-link {
		display: block;
	}

	.transparent-logo-link {
		display: none;
	}
}