.field-megamenu,
.field-megamenu-auto-width,
.field-megamenu-columns,
.field-megamenu-heading,
.field-megamenu-widgetarea,
.field-template,
.field-mega_template {
	display: none;
}

.menu-item-depth-0 .field-megamenu,
.menu-item-depth-0 .field-megamenu-auto-width,
.menu-item-depth-0 .field-megamenu-columns,
.menu-item-depth-0 .field-megamenu-heading,
.menu-item-depth-1 .field-megamenu-widgetarea,
.menu-item-depth-1 .field-template,
.menu-item-depth-1 .field-mega_template {
	display: block;
}