#blog-entries {
	padding-bottom: 0;
}

.blog-entry.post {
	position: relative;

	.thumbnail {
		position: relative;

		a:not(.mejs-volume-slider) {
			display: inline-block;
			position: relative;
			width: 100%;
		}

		.overlay {
		    position: absolute;
		    top: 0;
		    left: 0;
		    width: 100%;
		    height: 100%;
		    background-color: rgba(0, 0, 0, 0.2);
			@include opacity( 0 );
		    text-align: center;
		    @include transition( all .3s ease );
	    }

		&:hover .overlay {
			@include opacity( 1 );
		}

		img {
			width: 100%;
		}
	}

	ul.meta {
		margin: 0 0 12px;
	}

	.blog-entry-header {
		margin-bottom: 20px;

		.entry-title {
			font-size: 24px;
			margin: 0;

			a {
				font-weight: 600;
			    letter-spacing: 0.6px;
			}
		}
	}

	.blog-entry-summary {
		margin-bottom: 20px;

		p:last-child {
			margin-bottom: 0;
		}
	}
}

// Caption
.thumbnail-caption {
    font-size: 13px;
	margin-top: 0.5em;
    text-align: center;
}